searchData={"items":[{"type":"module","title":"Timex","doc":"","ref":"Timex.html"},{"type":"module","title":"Timex - Timex","doc":"[![Master](https://github.com/bitwalker/timex/workflows/elixir/badge.svg?branch=master)](https://github.com/bitwalker/timex/actions?query=workflow%3A%22elixir%22+branch%3Amaster)\n[![Hex.pm Version](https://img.shields.io/hexpm/v/timex.svg?style=flat)](https://hex.pm/packages/timex)\n[![Coverage Status](https://coveralls.io/repos/github/bitwalker/timex/badge.svg?branch=master)](https://coveralls.io/github/bitwalker/timex?branch=master)\n\nTimex is a rich, comprehensive Date/Time library for Elixir projects, with full timezone support via the `:tzdata` package. If\nyou need to manipulate dates, times, datetimes, timestamps, etc., then Timex is for you! It is very easy to use Timex types\nin place of default Erlang types, as well as Ecto types via the `timex_ecto` package.\n\nThe complete documentation for Timex is located [here](https://hexdocs.pm/timex).","ref":"Timex.html#module-timex"},{"type":"module","title":"Migrating to Timex 3.x - Timex","doc":"If you are coming from an earlier version of Timex, it is recommended that you evaluate whether or not the functionality provided\nby the standard library `Calendar` API is sufficient for your needs, as you may be able to avoid the dependency entirely.\n\nFor those that require Timex for one reason or another, Timex now delegates to the standard library where possible, and provides\nbackward compatibility to Elixir 1.8 for APIs which are used. This is to avoid duplicating effort, and to ease the maintenance of\nthis library in the future. Take a look at the documentation to see what APIs are available and how to use them. Many of them may have\nchanged, been removed/renamed, or have had their semantics improved since early versions of the library, so if you are coming from\nan earlier version, you will need to review how you are using various APIs. The CHANGELOG is a helpful document to sort through what\nhas changed in general.\n\nTimex is primarily oriented around the Olson timezone database, and so you are encouraged to use those timezones in favor of alternatives. \nTimex does provide compatibility with the POSIX-TZ standard, which allows specification of custom timezones, see \n[this document](https://pubs.opengroup.org/onlinepubs/9699919799/) for more information. Timex does not provide support\nfor timezones which do not adhere to one of those two standards. While Timex attempted to support timezone abbreviations without context\nin prior versions, this was broken, and has been removed.","ref":"Timex.html#module-migrating-to-timex-3-x"},{"type":"module","title":"Getting Started - Timex","doc":"There are some brief examples on usage below, but I highly recommend you review the\nAPI docs [here](https://hexdocs.pm/timex), there are many examples, and some extra pages with\nricher documentation on specific subjects such as custom formatters/parsers, etc.","ref":"Timex.html#module-getting-started"},{"type":"module","title":"Quickfast introduction - Timex","doc":"To use Timex, I recommend you add `use Timex` to the top of the module where you will be working with Timex modules,\nall it does is alias common types so you can work with them more comfortably. If you want to see the specific aliases\nadded, check the top of the `Timex` module, in the `__using__/1` macro definition.\n\nHere's a few simple examples:\n\n```elixir\n> use Timex\n> Timex.today()\n~D[2016-02-29]\n\n> datetime = Timex.now()\n#  Timex.now(\"America/Chicago\")\n#  Duration.now()\n# \n\n> {:ok, default_str} = Timex.format(datetime, \"{ISO:Extended}\")\n{:ok, \"2016-02-29T12:30:30.120+00:00\"}\n\n> {:ok, relative_str} = Timex.shift(datetime, minutes: -3) |> Timex.format(\"{relative}\", :relative)\n{:ok, \"3 minutes ago\"}\n\n> strftime_str = Timex.format!(datetime, \"%FT%T%:z\", :strftime)\n\"2016-02-29T12:30:30+00:00\"\n\n> Timex.parse(strftime_str, \"{ISO:Extended}\")\n{:ok, #  Timex.parse!(strftime_str, \"%FT%T%:z\", :strftime)\n#  Duration.diff(Duration.now(), Duration.zero(), :days)\n16850\n\n> Timex.shift(date, days: 3)\n~D[2016-03-03]\n\n> Timex.shift(datetime, hours: 2, minutes: 13)\n# \n\n> timezone = Timezone.get(\"America/Chicago\", Timex.now())\n# \n\n> Timezone.convert(datetime, timezone)\n# \n\n> Timex.before?(Timex.today(), Timex.shift(Timex.today, days: 1))\ntrue\n\n> Timex.before?(Timex.shift(Timex.today(), days: 1), Timex.today())\nfalse\n\n> interval = Timex.Interval.new(from: ~D[2016-03-03], until: [days: 3])\n%Timex.Interval{from: ~N[2016-03-03 00:00:00], left_open: false,\n right_open: true, step: [days: 1], until: ~N[2016-03-06 00:00:00]}\n\n> ~D[2016-03-04] in interval\ntrue\n\n> ~N[2016-03-04 00:00:00] in interval\ntrue\n\n> ~N[2016-03-02 00:00:00] in interval\nfalse\n\n> Timex.Interval.overlaps?(Timex.Interval.new(from: ~D[2016-03-04], until: [days: 1]), interval)\ntrue\n\n> Timex.Interval.overlaps?(Timex.Interval.new(from: ~D[2016-03-07], until: [days: 1]), interval)\nfalse\n\n```\n\nThere are a ton of other functions, all of which work with Erlang datetime tuples, Date, NaiveDateTime, and DateTime. \nThe Duration module contains functions for working with Durations, including Erlang timestamps (such as those returned from `:timer.tc`)","ref":"Timex.html#module-quickfast-introduction"},{"type":"module","title":"Extensibility - Timex","doc":"Timex exposes a number of extension points for you, in order to accommodate different use cases:\n\nTimex itself defines its core operations on the Date, DateTime, and NaiveDateTime types using the `Timex.Protocol` protocol. \nFrom there, all other Timex functionality is derived. If you have custom date/datetime types you want to use with Timex, \nthis is the protocol you would need to implement.\n\nTimex also defines a `Timex.Comparable` protocol, which you can extend to add comparisons to custom date/datetime types.\n\nYou can provide your own formatter/parser for datetime strings by implementing the `Timex.Format.DateTime.Formatter` \nand/or `Timex.Parse.DateTime.Parser` behaviours, depending on your needs.","ref":"Timex.html#module-extensibility"},{"type":"module","title":"Timex with escript - Timex","doc":"If you need to use Timex from within an escript, add `{:tzdata, \"~> 0.1.8\", override: true}` to your deps, more recent versions of :tzdata are unable to work in an escript because of the need to load ETS table files from priv, and due to the way ETS loads these files, it's not possible to do so.\n\nIf your build still throws an error after this, try removing the `_build` and `deps` folder. Then execute `mix deps.unlock tzdata` and `mix deps.get`.","ref":"Timex.html#module-timex-with-escript"},{"type":"module","title":"Automatic time zone updates - Timex","doc":"Timex includes the [Tzdata](https://github.com/lau/tzdata) library for time zone data.\nTzdata has an automatic update capability that fetches updates from IANA and which is enabled by default; \nif you want to disable it, check [the Tzdata documentation](https://github.com/lau/tzdata#automatic-data-updates) for details.","ref":"Timex.html#module-automatic-time-zone-updates"},{"type":"module","title":"License - Timex","doc":"This software is licensed under [the MIT license](LICENSE.md).","ref":"Timex.html#module-license"},{"type":"function","title":"Timex.add/2","doc":"Add time to a date using a Duration\nSame as `shift(date, Duration.from_minutes(5), :duration)`.","ref":"Timex.html#add/2"},{"type":"function","title":"Timex.after?/2","doc":"Returns a boolean indicating whether the first `Timex.Comparable` occurs after the second","ref":"Timex.html#after?/2"},{"type":"function","title":"Timex.before?/2","doc":"Returns a boolean indicating whether the first `Timex.Comparable` occurs before the second","ref":"Timex.html#before?/2"},{"type":"function","title":"Timex.beginning_of_day/1","doc":"Returns a DateTime representing the beginning of the day","ref":"Timex.html#beginning_of_day/1"},{"type":"function","title":"Examples - Timex.beginning_of_day/1","doc":"iex> date = Timex.to_datetime({{2015, 1, 1}, {13, 14, 15}}, \"Etc/UTC\")\n    iex> Timex.beginning_of_day(date)\n    Timex.to_datetime({{2015, 1, 1}, {0, 0, 0}}, \"Etc/UTC\")\n\n    iex> date = ~D[2015-01-01]\n    ...> Timex.beginning_of_day(date)\n    ~D[2015-01-01]","ref":"Timex.html#beginning_of_day/1-examples"},{"type":"function","title":"Timex.beginning_of_month/1","doc":"Given a date returns a date at the beginning of the month.\n\n    iex> date = Timex.to_datetime({{2015, 6, 15}, {12,30,0}}, \"Europe/Paris\")\n    iex> Timex.beginning_of_month(date)\n    Timex.to_datetime({{2015, 6, 1}, {0, 0, 0}}, \"Europe/Paris\")","ref":"Timex.html#beginning_of_month/1"},{"type":"function","title":"Timex.beginning_of_month/2","doc":"Same as beginning_of_month/1, except takes year and month as distinct arguments","ref":"Timex.html#beginning_of_month/2"},{"type":"function","title":"Timex.beginning_of_quarter/1","doc":"Given a date returns a date at the beginning of the quarter.\n\n    iex> date = Timex.to_datetime({{2015, 6, 15}, {12,30,0}}, \"America/Chicago\")\n    iex> Timex.beginning_of_quarter(date)\n    Timex.to_datetime({{2015, 4, 1}, {0, 0, 0}}, \"America/Chicago\")","ref":"Timex.html#beginning_of_quarter/1"},{"type":"function","title":"Timex.beginning_of_week/2","doc":"Shifts the date to the beginning of the week\n\nThe weekstart can between 1..7, an atom e.g. :mon, or a string e.g. \"Monday\"","ref":"Timex.html#beginning_of_week/2"},{"type":"function","title":"Examples - Timex.beginning_of_week/2","doc":"iex> date = ~N[2015-11-30T13:30:30] # Monday 30th November\n    iex> Timex.beginning_of_week(date)\n    ~N[2015-11-30T00:00:00]\n\n    iex> date = ~D[2015-11-30] # Monday 30th November\n    iex> Timex.beginning_of_week(date, :sun)\n    ~D[2015-11-29]","ref":"Timex.html#beginning_of_week/2-examples"},{"type":"function","title":"Timex.beginning_of_year/1","doc":"Given a date or a number create a date at the beginning of that year\n\nExamples\n\n    iex> date = ~N[2015-06-15T00:00:00]\n    iex> Timex.beginning_of_year(date)\n    ~N[2015-01-01T00:00:00]\n\n    iex> Timex.beginning_of_year(2015)\n    ~D[2015-01-01]","ref":"Timex.html#beginning_of_year/1"},{"type":"function","title":"Timex.between?/4","doc":"Returns a boolean indicating whether the first `Timex.Comparable` occurs between the second\nand third.\n\nIf an error occurs, an error tuple will be returned.\n\nBy default, the `start` and `end` bounds are *exclusive*. You can opt for inclusive bounds with the\n`inclusive: true` option.\nTo set just one of the bounds as inclusive, use the\n`inclusive: :start` or `inclusive: :end` option.\n\nAlso, by default, for `Time.t`, if `start` and `end`\nare on different sides of midnight,\nit doesn't count as a continous period. Hence, `23:00 < 00:00, 01:00` would return `false`.\nTo use cycled time, use option `cycled: true`.","ref":"Timex.html#between?/4"},{"type":"type","title":"Timex.between_options/0","doc":"","ref":"Timex.html#t:between_options/0"},{"type":"function","title":"Timex.century/0","doc":"Gets the current century","ref":"Timex.html#century/0"},{"type":"function","title":"Examples - Timex.century/0","doc":"iex> Timex.century\n    21","ref":"Timex.html#century/0-examples"},{"type":"function","title":"Timex.century/1","doc":"Given a date, get the century this date is in.","ref":"Timex.html#century/1"},{"type":"function","title":"Examples - Timex.century/1","doc":"iex> Timex.today |> Timex.century\n    21\n    iex> Timex.now |> Timex.century\n    21\n    iex> Timex.century(2016)\n    21","ref":"Timex.html#century/1-examples"},{"type":"function","title":"Timex.compare/2","doc":"See docs for `compare/3`","ref":"Timex.html#compare/2"},{"type":"function","title":"Timex.compare/3","doc":"Compare two `Timex.Comparable` values, returning one of the following values:\n\n * `-1` -- the first date comes before the second one\n * `0`  -- both arguments represent the same date when coalesced to the same timezone.\n * `1`  -- the first date comes after the second one\n\nYou can provide a few reference constants for the second argument:\n\n- :epoch will compare the first parameter against the Date/DateTime of the first moment of the UNIX epoch\n- :zero will compare the first parameter against the Date/DateTime of the first moment of year zero\n- :distant_past will compare the first parameter against a date/time infinitely in the past (i.e. it will always return 1)\n- :distant_future will compare the first parameter against a date/time infinitely in the future (i.e. it will always return -1)\n\nYou can optionally specify a comparison granularity from the list below.\n\n- :year\n- :years\n- :month\n- :months\n- :week (an alias for 7 days)\n- :weeks\n- :calendar_week (weeks of the calendar as opposed to actual weeks in terms of days)\n- :calendar_weeks\n- :day (an alias for 24 hours)\n- :days\n- :hour\n- :hours\n- :minute\n- :minutes\n- :second\n- :seconds\n- :millisecond\n- :milliseconds\n- :microsecond (default)\n- :microseconds\n- :duration","ref":"Timex.html#compare/3"},{"type":"function","title":"Examples - Timex.compare/3","doc":"iex> date1 = ~D[2014-03-04]\n    iex> date2 = ~D[2015-03-04]\n    iex> Timex.compare(date1, date2, :year)\n    -1\n    iex> Timex.compare(date2, date1, :year)\n    1\n    iex> Timex.compare(date1, date1)\n    0","ref":"Timex.html#compare/3-examples"},{"type":"function","title":"Timex.day/1","doc":"Returns the ordinal day number of the date.","ref":"Timex.html#day/1"},{"type":"function","title":"Examples - Timex.day/1","doc":"iex> Timex.day(~D[2015-06-26])\n    177","ref":"Timex.html#day/1-examples"},{"type":"function","title":"Timex.day_name/1","doc":"Get the name of the day corresponding to the provided number","ref":"Timex.html#day_name/1"},{"type":"function","title":"Examples - Timex.day_name/1","doc":"iex> Timex.day_name(1)\n    \"Monday\"\n    iex> Timex.day_name(0)\n    {:error, :invalid_weekday_number}","ref":"Timex.html#day_name/1-examples"},{"type":"function","title":"Timex.day_shortname/1","doc":"Get the short name of the day corresponding to the provided number","ref":"Timex.html#day_shortname/1"},{"type":"function","title":"Examples - Timex.day_shortname/1","doc":"iex> Timex.day_shortname(1)\n    \"Mon\"\n    iex> Timex.day_shortname(0)\n    {:error, :invalid_weekday_number}","ref":"Timex.html#day_shortname/1-examples"},{"type":"function","title":"Timex.day_to_num/1","doc":"Get the day of the week corresponding to the given name.\n\nThe name can be given as a string of the weekday name or its first three characters\n(lowercase or capitalized) or as a corresponding atom (lowercase only).","ref":"Timex.html#day_to_num/1"},{"type":"function","title":"Examples - Timex.day_to_num/1","doc":"iex> Timex.day_to_num(\"Monday\")\n    1\n    iex> Timex.day_to_num(\"monday\")\n    1\n    iex> Timex.day_to_num(\"Mon\")\n    1\n    iex> Timex.day_to_num(\"mon\")\n    1\n    iex> Timex.day_to_num(:mon)\n    1\n    iex> Timex.day_to_num(:sunday)\n    7","ref":"Timex.html#day_to_num/1-examples"},{"type":"function","title":"Timex.days_in_month/1","doc":"Return the number of days in the month which the date falls on.","ref":"Timex.html#days_in_month/1"},{"type":"function","title":"Examples - Timex.days_in_month/1","doc":"iex> Timex.days_in_month(~D[1970-01-01])\n    31","ref":"Timex.html#days_in_month/1-examples"},{"type":"function","title":"Timex.days_in_month/2","doc":"Same as days_in_month/2, except takes year and month as distinct arguments","ref":"Timex.html#days_in_month/2"},{"type":"function","title":"Timex.days_to_beginning_of_week/2","doc":"Number of days to the beginning of the week\n\nThe weekstart determines which is the first day of the week, defaults to monday. It can be a number\nbetween 1..7 (1 is monday, 7 is sunday), or any value accepted by `day_to_num/1`.","ref":"Timex.html#days_to_beginning_of_week/2"},{"type":"function","title":"Examples - Timex.days_to_beginning_of_week/2","doc":"iex> date = ~D[2015-11-30] # Monday 30th November\n    iex> Timex.days_to_beginning_of_week(date)\n    0\n\n    iex> date = ~D[2015-11-30] # Monday 30th November\n    iex> Timex.days_to_beginning_of_week(date, :sun)\n    1","ref":"Timex.html#days_to_beginning_of_week/2-examples"},{"type":"function","title":"Timex.days_to_end_of_week/2","doc":"Number of days to the end of the week.\n\nThe weekstart can between 1..7, an atom e.g. :mon, or a string e.g. \"Monday\"","ref":"Timex.html#days_to_end_of_week/2"},{"type":"function","title":"Examples - Timex.days_to_end_of_week/2","doc":"Week starting Monday\n    iex> date = ~D[2015-11-30] # Monday 30th November\n    iex> Timex.days_to_end_of_week(date)\n    6\n\n    Week starting Sunday\n    iex> date = ~D[2015-11-30] # Monday 30th November\n    iex> Timex.days_to_end_of_week(date, :sun)\n    5","ref":"Timex.html#days_to_end_of_week/2-examples"},{"type":"function","title":"Timex.diff/2","doc":"See docs for `diff/3`","ref":"Timex.html#diff/2"},{"type":"function","title":"Timex.diff/3","doc":"Calculate time interval between two dates. The result will be a signed integer, negative\nif the first date/time comes before the second, and positive if the first date/time comes\nafter the second.\n\nYou must specify one of the following units:\n\n- :year\n- :years\n- :month\n- :months\n- :week\n- :weeks\n- :calendar_week (weeks of the calendar as opposed to actual weeks in terms of days)\n- :calendar_weeks\n- :day\n- :days\n- :hour\n- :hours\n- :minute\n- :minutes\n- :second\n- :seconds\n- :millisecond\n- :milliseconds\n- :microsecond (default)\n- :microseconds\n- :duration\n\nand the result will be an integer value of those units or a Duration.","ref":"Timex.html#diff/3"},{"type":"function","title":"Timex.end_of_day/1","doc":"Returns a DateTime representing the end of the day","ref":"Timex.html#end_of_day/1"},{"type":"function","title":"Examples - Timex.end_of_day/1","doc":"iex> date = ~N[2015-01-01T13:14:15]\n    ...> Timex.end_of_day(date)\n    ~N[2015-01-01T23:59:59]","ref":"Timex.html#end_of_day/1-examples"},{"type":"function","title":"Timex.end_of_month/1","doc":"Given a date returns a date at the end of the month.\n\n    iex> date = ~N[2015-06-15T12:30:00Z]\n    iex> Timex.end_of_month(date)\n    ~N[2015-06-30T23:59:59Z]","ref":"Timex.html#end_of_month/1"},{"type":"function","title":"Timex.end_of_month/2","doc":"Same as end_of_month/1, except takes year and month as distinct arguments","ref":"Timex.html#end_of_month/2"},{"type":"function","title":"Examples - Timex.end_of_month/2","doc":"iex> Timex.end_of_month(2016, 2)\n    ~D[2016-02-29]","ref":"Timex.html#end_of_month/2-examples"},{"type":"function","title":"Timex.end_of_quarter/1","doc":"Given a date or a year and month returns a date at the end of the quarter.\n\n    iex> date = ~N[2015-06-15T12:30:00]\n    ...> Timex.end_of_quarter(date)\n    ~N[2015-06-30T23:59:59]\n\n    iex> Timex.end_of_quarter(2015, 4)\n    ~D[2015-06-30]","ref":"Timex.html#end_of_quarter/1"},{"type":"function","title":"Timex.end_of_quarter/2","doc":"Same as end_of_quarter/1, except takes year and month as distinct arguments","ref":"Timex.html#end_of_quarter/2"},{"type":"function","title":"Timex.end_of_week/2","doc":"Returns a Date or a DateTime representing the end of the week, depending on the input,\ni.e. if you pass a date/time value which represents just a date, you will get back a Date,\nif both a date and time are present, you will get back a DateTime\n\nThe weekstart can between 1..7, an atom e.g. :mon, or a string e.g. \"Monday\"","ref":"Timex.html#end_of_week/2"},{"type":"function","title":"Examples - Timex.end_of_week/2","doc":"iex> date = ~N[2015-11-30T13:30:30] # Monday 30th November\n    ...> Timex.end_of_week(date)\n    ~N[2015-12-06T23:59:59]\n\n    iex> date = ~D[2015-11-30] # Monday 30th November\n    ...> Timex.end_of_week(date, :sun)\n    ~D[2015-12-05]","ref":"Timex.html#end_of_week/2-examples"},{"type":"function","title":"Timex.end_of_year/1","doc":"Given a date or a number create a date at the end of that year\n\nExamples\n\n    iex> date = ~N[2015-06-15T00:00:00]\n    iex> Timex.end_of_year(date)\n    ~N[2015-12-31T23:59:59]\n\n    iex> Timex.end_of_year(2015)\n    ~D[2015-12-31]","ref":"Timex.html#end_of_year/1"},{"type":"function","title":"Timex.epoch/0","doc":"Returns a Date representing the start of the UNIX epoch","ref":"Timex.html#epoch/0"},{"type":"function","title":"Timex.equal?/3","doc":"Returns a boolean indicating whether the two `Timex.Comparable` values are equivalent.\n\nEquality here implies that the two Comparables represent the same moment in time (with\nthe given granularity), not equality of the data structure.\n\nThe options for granularity is the same as for `compare/3`, defaults to `:seconds`.","ref":"Timex.html#equal?/3"},{"type":"function","title":"Examples - Timex.equal?/3","doc":"iex> date1 = ~D[2014-03-01]\n    ...> date2 = ~D[2014-03-01]\n    ...> Timex.equal?(date1, date2)\n    true\n\n    iex> date1 = ~D[2014-03-01]\n    ...> date2 = Timex.to_datetime({2014, 3, 1}, \"Etc/UTC\")\n    ...> Timex.equal?(date1, date2)\n    true","ref":"Timex.html#equal?/3-examples"},{"type":"function","title":"Timex.format/2","doc":"Formats a date/time value using the given format string (and optional formatter).\n\nSee `Timex.Format.DateTime.Formatters.Default` or `Timex.Format.DateTime.Formatters.Strftime`\nfor documentation on the syntax supported by those formatters.\n\nTo use the Default formatter, simply call `format/2`. To use the Strftime formatter, you\ncan either alias and pass Strftime by module name, or as a shortcut, you can pass :strftime\ninstead.\n\nFormatting will convert other dates than Elixir date types (Date, DateTime, NaiveDateTime)\nto a NaiveDateTime using `to_naive_datetime/1` before formatting.","ref":"Timex.html#format/2"},{"type":"function","title":"Examples - Timex.format/2","doc":"iex> date = ~D[2016-02-29]\n    ...> Timex.format(date, \"{YYYY}-{0M}-{D}\")\n    {:ok, \"2016-02-29\"}\n\n    iex> datetime = Timex.to_datetime({{2016,2,29},{22,25,0}}, \"Etc/UTC\")\n    ...> Timex.format(datetime, \"{ISO:Extended}\")\n    {:ok, \"2016-02-29T22:25:00+00:00\"}","ref":"Timex.html#format/2-examples"},{"type":"function","title":"Timex.format/3","doc":"Same as format/2, except using a custom formatter","ref":"Timex.html#format/3"},{"type":"function","title":"Examples - Timex.format/3","doc":"iex> use Timex\n    ...> datetime = Timex.to_datetime({{2016,2,29},{22,25,0}}, \"America/Chicago\")\n    iex> Timex.format(datetime, \"%FT%T%:z\", :strftime)\n    {:ok, \"2016-02-29T22:25:00-06:00\"}","ref":"Timex.html#format/3-examples"},{"type":"function","title":"Timex.format!/2","doc":"Same as format/2, except it returns only the value (not a tuple) and raises on error.","ref":"Timex.html#format!/2"},{"type":"function","title":"Examples - Timex.format!/2","doc":"iex> date = ~D[2016-02-29]\n    ...> Timex.format!(date, \"{YYYY}-{0M}-{D}\")\n    \"2016-02-29\"","ref":"Timex.html#format!/2-examples"},{"type":"function","title":"Timex.format!/3","doc":"Same as format/3, except it returns only the value (not a tuple) and raises on error.","ref":"Timex.html#format!/3"},{"type":"function","title":"Examples - Timex.format!/3","doc":"iex> use Timex\n    ...> datetime = Timex.to_datetime({{2016,2,29},{22,25,0}}, \"America/Chicago\")\n    iex> Timex.format!(datetime, \"%FT%T%:z\", :strftime)\n    \"2016-02-29T22:25:00-06:00\"","ref":"Timex.html#format!/3-examples"},{"type":"function","title":"Timex.format_duration/1","doc":"Formats an Erlang timestamp using the ISO-8601 duration format, or optionally, with a custom\nformatter of your choosing.\n\nSee Timex.Format.Duration.Formatters.Default or Timex.Format.Duration.Formatters.Humanized\nfor documentation on the specific formatter behaviour.\n\nTo use the Default formatter, simply call format_duration/2.\nTo use the Humanized formatter, you can either alias and pass Humanized by module name,\nor as a shortcut, you can pass :humanized instead.","ref":"Timex.html#format_duration/1"},{"type":"function","title":"Examples - Timex.format_duration/1","doc":"iex> use Timex\n    ...> duration = Duration.from_seconds(Timex.to_unix({2016, 2, 29}))\n    ...> Timex.format_duration(duration)\n    \"P46Y2M10D\"\n\n    iex> use Timex\n    ...> duration = Duration.from_seconds(Timex.to_unix({2016, 2, 29}))\n    ...> Timex.format_duration(duration, :humanized)\n    \"46 years, 2 months, 1 week, 3 days\"\n\n    iex> use Timex\n    ...> datetime = Duration.from_seconds(Timex.to_unix(~N[2016-02-29T22:25:00]))\n    ...> Timex.format_duration(datetime, :humanized)\n    \"46 years, 2 months, 1 week, 3 days, 22 hours, 25 minutes\"","ref":"Timex.html#format_duration/1-examples"},{"type":"function","title":"Timex.format_duration/2","doc":"Same as format_duration/1, except it also accepts a formatter","ref":"Timex.html#format_duration/2"},{"type":"function","title":"Timex.from_iso_day/1","doc":"Convert an iso ordinal day number to the day it represents in the current year.","ref":"Timex.html#from_iso_day/1"},{"type":"function","title":"Examples - Timex.from_iso_day/1","doc":"iex> %Date{:year => year} = Timex.from_iso_day(180)\n    ...> %Date{:year => todays_year} = Timex.today()\n    ...> year == todays_year\n    true","ref":"Timex.html#from_iso_day/1-examples"},{"type":"function","title":"Timex.from_iso_day/2","doc":"Same as from_iso_day/1, except you can expect the following based on the second parameter:\n\n- If an integer year is given, the result will be a Date struct\n- For any date/time value, the result will be in the same format (i.e. Date -> Date)\n\nIn all cases, the resulting value will be the date representation of the provided ISO day in that year","ref":"Timex.html#from_iso_day/2"},{"type":"function","title":"Examples - Timex.from_iso_day/2","doc":"","ref":"Timex.html#from_iso_day/2-examples"},{"type":"function","title":"Creating a Date from the given day - Timex.from_iso_day/2","doc":"iex> use Timex\n    ...> expected = ~D[2015-06-29]\n    ...> (expected === Timex.from_iso_day(180, 2015))\n    true","ref":"Timex.html#from_iso_day/2-creating-a-date-from-the-given-day"},{"type":"function","title":"Creating a Date/DateTime from the given day - Timex.from_iso_day/2","doc":"iex> use Timex\n    ...> expected = Timex.to_datetime({{2015, 6, 29}, {0,0,0}}, \"Etc/UTC\")\n    ...> beginning = Timex.to_datetime({{2015,1,1}, {0,0,0}}, \"Etc/UTC\")\n    ...> (expected === Timex.from_iso_day(180, beginning))\n    true","ref":"Timex.html#from_iso_day/2-creating-a-date-datetime-from-the-given-day"},{"type":"function","title":"Shifting a Date/DateTime to the given day - Timex.from_iso_day/2","doc":"iex> use Timex\n    ...> date = Timex.to_datetime({{2015,6,26}, {12,0,0}}, \"Etc/UTC\")\n    ...> expected = Timex.to_datetime({{2015, 6, 29}, {12,0,0}}, \"Etc/UTC\")\n    ...> (Timex.from_iso_day(180, date) === expected)\n    true","ref":"Timex.html#from_iso_day/2-shifting-a-date-datetime-to-the-given-day"},{"type":"function","title":"Timex.from_iso_triplet/1","doc":"Given an ISO triplet `{year, week number, weekday}`, convert it to a Date struct.","ref":"Timex.html#from_iso_triplet/1"},{"type":"function","title":"Examples - Timex.from_iso_triplet/1","doc":"iex> expected = Timex.to_date({2014, 1, 28})\n    iex> Timex.from_iso_triplet({2014, 5, 2}) === expected\n    true","ref":"Timex.html#from_iso_triplet/1-examples"},{"type":"function","title":"Timex.from_now/1","doc":"Formats a DateTime using a fuzzy relative duration, from now.","ref":"Timex.html#from_now/1"},{"type":"function","title":"Examples - Timex.from_now/1","doc":"iex> use Timex\n    ...> Timex.from_now(Timex.shift(DateTime.utc_now(), days: 2, hours: 1))\n    \"in 2 days\"\n\n    iex> use Timex\n    ...> Timex.from_now(Timex.shift(DateTime.utc_now(), days: -2))\n    \"2 days ago\"","ref":"Timex.html#from_now/1-examples"},{"type":"function","title":"Timex.from_now/2","doc":"Formats a DateTime using a fuzzy relative duration, translated using given locale","ref":"Timex.html#from_now/2"},{"type":"function","title":"Examples - Timex.from_now/2","doc":"iex> use Timex\n    ...> Timex.from_now(Timex.shift(DateTime.utc_now(), days: 2, hours: 1), \"ru\")\n    \"через 2 дня\"\n\n    iex> use Timex\n    ...> Timex.from_now(Timex.shift(DateTime.utc_now(), days: -2), \"ru\")\n    \"2 дня назад\"","ref":"Timex.html#from_now/2-examples"},{"type":"function","title":"Timex.from_now/3","doc":"Formats a DateTime using a fuzzy relative duration, with a reference datetime other than now,\ntranslated using the given locale","ref":"Timex.html#from_now/3"},{"type":"function","title":"Timex.from_unix/2","doc":"Delegates to `DateTime.from_unix!/2`. To recap the docs:\n\nConverts the given Unix time to DateTime.\n\nThe integer can be given in different units according to `System.convert_time_unit/3`\nand it will be converted to microseconds internally. Defaults to `:second`.\n\nUnix times are always in UTC and therefore the DateTime will be returned in UTC.","ref":"Timex.html#from_unix/2"},{"type":"function","title":"Timex.is_leap?/1","doc":"Return a boolean indicating whether the given year is a leap year. You may\npass a date or a year number.","ref":"Timex.html#is_leap?/1"},{"type":"function","title":"Examples - Timex.is_leap?/1","doc":"iex> Timex.epoch() |> Timex.is_leap?\n    false\n    iex> Timex.is_leap?(2012)\n    true","ref":"Timex.html#is_leap?/1-examples"},{"type":"function","title":"Timex.is_valid?/1","doc":"Return a boolean indicating whether the given date is valid.","ref":"Timex.html#is_valid?/1"},{"type":"function","title":"Examples - Timex.is_valid?/1","doc":"iex> use Timex\n    ...> Timex.is_valid?(~N[0001-01-01T01:01:01])\n    true\n\n    iex> use Timex\n    ...> %Date{year: 1, day: 1, month: 13} |> Timex.is_valid?\n    false","ref":"Timex.html#is_valid?/1-examples"},{"type":"function","title":"Timex.is_valid_time?/1","doc":"Returns a boolean indicating whether the provided term represents a valid time,\nvalid times are one of:\n\n- `{hour, min, sec}`\n- `{hour, min, sec, ms}`","ref":"Timex.html#is_valid_time?/1"},{"type":"function","title":"Timex.is_valid_timezone?/1","doc":"Returns a boolean indicating whether the provided term represents a valid timezone,\nvalid timezones are one of:\n\n- TimezoneInfo struct\n- A timezone name as a string\n- `:utc` as a shortcut for the UTC timezone\n- `:local` as a shortcut for the local timezone\n- A number representing an offset from UTC","ref":"Timex.html#is_valid_timezone?/1"},{"type":"function","title":"Timex.iso_triplet/1","doc":"Return a 3-tuple {year, week number, weekday} for the given Date/DateTime.","ref":"Timex.html#iso_triplet/1"},{"type":"function","title":"Examples - Timex.iso_triplet/1","doc":"iex> Timex.iso_triplet(Timex.epoch)\n    {1970, 1, 4}","ref":"Timex.html#iso_triplet/1-examples"},{"type":"function","title":"Timex.iso_week/1","doc":"Return a pair {year, week number} (as defined by ISO 8601) that the given\nDate/DateTime value falls on.","ref":"Timex.html#iso_week/1"},{"type":"function","title":"Examples - Timex.iso_week/1","doc":"iex> Timex.iso_week({1970, 1, 1})\n    {1970,1}","ref":"Timex.html#iso_week/1-examples"},{"type":"function","title":"Timex.iso_week/3","doc":"Same as iso_week/1, except this takes a year, month, and day as distinct arguments.","ref":"Timex.html#iso_week/3"},{"type":"function","title":"Examples - Timex.iso_week/3","doc":"iex> Timex.iso_week(1970, 1, 1)\n    {1970,1}","ref":"Timex.html#iso_week/3-examples"},{"type":"function","title":"Timex.lformat/3","doc":"Same as format/2, except takes a locale name to translate text to.\n\nTranslations only apply to units, relative time phrases, and only for the locales in the\nlist of supported locales in the Timex documentation.","ref":"Timex.html#lformat/3"},{"type":"function","title":"Timex.lformat/4","doc":"Same as lformat/3, except takes a formatter as it's last argument.\n\nTranslations only apply to units, relative time phrases, and only for the locales in the\nlist of supported locales in the Timex documentation.","ref":"Timex.html#lformat/4"},{"type":"function","title":"Timex.lformat!/3","doc":"Same as lformat/3, except local_format! raises on error.\n\nSee lformat/3 docs for usage examples.","ref":"Timex.html#lformat!/3"},{"type":"function","title":"Timex.lformat!/4","doc":"Same as lformat/4, except local_format! raises on error.\n\nSee lformat/4 docs for usage examples","ref":"Timex.html#lformat!/4"},{"type":"function","title":"Timex.lformat_duration/2","doc":"Same as format_duration/1, except takes a locale for use in translation","ref":"Timex.html#lformat_duration/2"},{"type":"function","title":"Timex.lformat_duration/3","doc":"Same as lformat_duration/2, except takes a formatter as an argument","ref":"Timex.html#lformat_duration/3"},{"type":"function","title":"Timex.local/0","doc":"Returns a DateTime representing the current moment in time in the local timezone.","ref":"Timex.html#local/0"},{"type":"function","title":"Example - Timex.local/0","doc":"iex> %DateTime{time_zone: tz} = Timex.local();\n    ...> tz != nil\n    true","ref":"Timex.html#local/0-example"},{"type":"function","title":"Timex.local/1","doc":"Returns a DateTime representing the given date/time in the local timezone","ref":"Timex.html#local/1"},{"type":"function","title":"Example - Timex.local/1","doc":"iex> %DateTime{time_zone: tz} = Timex.local(DateTime.utc_now());\n    ...> tz != nil\n    true","ref":"Timex.html#local/1-example"},{"type":"function","title":"Timex.month_name/1","doc":"Get the name of the month corresponding to the provided number","ref":"Timex.html#month_name/1"},{"type":"function","title":"Examples - Timex.month_name/1","doc":"iex> Timex.month_name(1)\n    \"January\"\n    iex> Timex.month_name(0)\n    {:error, :invalid_month_number}","ref":"Timex.html#month_name/1-examples"},{"type":"function","title":"Timex.month_shortname/1","doc":"Get the short name of the month corresponding to the provided number","ref":"Timex.html#month_shortname/1"},{"type":"function","title":"Examples - Timex.month_shortname/1","doc":"iex> Timex.month_shortname(1)\n    \"Jan\"\n    iex> Timex.month_shortname(0)\n    {:error, :invalid_month_number}","ref":"Timex.html#month_shortname/1-examples"},{"type":"function","title":"Timex.month_to_num/1","doc":"Get the number of the month corresponding to the given name.","ref":"Timex.html#month_to_num/1"},{"type":"function","title":"Examples - Timex.month_to_num/1","doc":"iex> Timex.month_to_num(\"January\")\n    1\n    iex> Timex.month_to_num(\"january\")\n    1\n    iex> Timex.month_to_num(\"Jan\")\n    1\n    iex> Timex.month_to_num(\"jan\")\n    1\n    iex> Timex.month_to_num(:jan)\n    1","ref":"Timex.html#month_to_num/1-examples"},{"type":"function","title":"Timex.normalize/2","doc":"Given a unit to normalize, and the value to normalize, produces a valid\nvalue for that unit, clamped to whatever boundaries are defined for that unit.","ref":"Timex.html#normalize/2"},{"type":"function","title":"Example - Timex.normalize/2","doc":"iex> Timex.normalize(:hour, 26)\n    23","ref":"Timex.html#normalize/2-example"},{"type":"function","title":"Timex.now/0","doc":"Returns a DateTime representing the current moment in time in UTC","ref":"Timex.html#now/0"},{"type":"function","title":"Timex.now/1","doc":"Returns a DateTime representing the current moment in time in the provided\ntimezone.","ref":"Timex.html#now/1"},{"type":"function","title":"Timex.parse/2","doc":"Parses a datetime string into a DateTime struct, using the provided format string (and optional tokenizer).\n\nSee `Timex.Format.DateTime.Formatters.Default` or `Timex.Format.DateTime.Formatters.Strftime`\nfor documentation on the syntax supported in format strings by their respective tokenizers.\n\nTo use the Default tokenizer, simply call `parse/2`. To use the Strftime tokenizer, you\ncan either alias and pass Timex.Parse.DateTime.Tokenizer.Strftime by module name,\nor as a shortcut, you can pass :strftime instead.","ref":"Timex.html#parse/2"},{"type":"function","title":"Examples - Timex.parse/2","doc":"iex> use Timex\n    ...> {:ok, result} = Timex.parse(\"2016-02-29\", \"{YYYY}-{0M}-{D}\")\n    ...> result\n    ~N[2016-02-29T00:00:00]\n\n    iex> use Timex\n    ...> expected = Timex.to_datetime({{2016, 2, 29}, {22, 25, 0}}, \"America/Chicago\")\n    ...> {:ok, result} = Timex.parse(\"2016-02-29T22:25:00-06:00\", \"{ISO:Extended}\")\n    ...> Timex.equal?(expected, result)\n    true\n\n    iex> use Timex\n    ...> expected = Timex.to_datetime({{2016, 2, 29}, {22, 25, 0}}, \"America/Chicago\")\n    ...> {:ok, result} = Timex.parse(\"2016-02-29T22:25:00-06:00\", \"%FT%T%:z\", :strftime)\n    ...> Timex.equal?(expected, result)\n    true","ref":"Timex.html#parse/2-examples"},{"type":"function","title":"Timex.parse/3","doc":"See  Timex.Parse.DateTime.Parser.parse/3 .","ref":"Timex.html#parse/3"},{"type":"function","title":"Timex.parse!/2","doc":"Same as parse/2 and parse/3, except parse! raises on error.\n\nSee parse/2 or parse/3 docs for usage examples.","ref":"Timex.html#parse!/2"},{"type":"function","title":"Timex.parse!/3","doc":"See  Timex.Parse.DateTime.Parser.parse!/3 .","ref":"Timex.html#parse!/3"},{"type":"function","title":"Timex.quarter/1","doc":"Returns what quarter of the year the given date/time falls in.","ref":"Timex.html#quarter/1"},{"type":"function","title":"Examples - Timex.quarter/1","doc":"iex> Timex.quarter(4)\n    2","ref":"Timex.html#quarter/1-examples"},{"type":"function","title":"Timex.set/2","doc":"Return a new date/time value with the specified fields replaced by new values.\n\nValues are automatically validated and clamped to good values by default. If\nyou wish to skip validation, perhaps for performance reasons, pass `validate: false`.\n\nValues are applied in order, so if you pass `[datetime: dt, date: d]`, the date value\nfrom `date` will override `datetime`'s date value.\n\nOptions which do not apply to the input value (for example, `:hour` against a `Date` struct),\nwill be ignored.","ref":"Timex.html#set/2"},{"type":"function","title":"Example - Timex.set/2","doc":"iex> use Timex\n    ...> expected = ~D[2015-02-28]\n    ...> result = Timex.set(expected, [month: 2, day: 30])\n    ...> result == expected\n    true\n\n    iex> use Timex\n    ...> expected = ~N[2016-02-29T23:30:00]\n    ...> result = Timex.set(expected, [hour: 30])\n    ...> result === expected\n    true","ref":"Timex.html#set/2-example"},{"type":"type","title":"Timex.set_options/0","doc":"","ref":"Timex.html#t:set_options/0"},{"type":"function","title":"Timex.shift/2","doc":"A single function for adjusting the date using various units: duration,\nmicroseconds, seconds, minutes, hours, days, weeks, months, years.\n\nThe result of applying the shift will be the same type as that of the input,\nwith the exception of shifting DateTimes, which may result in an AmbiguousDateTime\nif the shift moves to an ambiguous time period for the zone of that DateTime.\n\nShifting by months will always return a date in the expected month. Because months\nhave different number of days, shifting to a month with fewer days may not be\nthe same day of the month as the original date.\n\nIf an error occurs, an error tuple will be returned.","ref":"Timex.html#shift/2"},{"type":"function","title":"Examples - Timex.shift/2","doc":"","ref":"Timex.html#shift/2-examples"},{"type":"function","title":"Shifting across timezone changes - Timex.shift/2","doc":"iex> use Timex\n    ...> datetime = Timex.to_datetime({{2016,3,13}, {1,0,0}}, \"America/Chicago\")\n    ...> # 2-3 AM doesn't exist due to leap forward, shift accounts for this\n    ...> %DateTime{hour: 3} = Timex.shift(datetime, hours: 1)\n    ...> shifted = Timex.shift(datetime, hours: 1)\n    ...> {datetime.zone_abbr, shifted.zone_abbr, shifted.hour}\n    {\"CST\", \"CDT\", 3}","ref":"Timex.html#shift/2-shifting-across-timezone-changes"},{"type":"function","title":"Shifting and leap days - Timex.shift/2","doc":"iex> use Timex\n    ...> date = ~D[2016-02-29]\n    ...> Timex.shift(date, years: -1)\n    ~D[2015-03-01]","ref":"Timex.html#shift/2-shifting-and-leap-days"},{"type":"function","title":"Shifting by months - Timex.shift/2","doc":"iex> date = ~D[2016-01-15]\n    ...> Timex.shift(date, months: 1)\n    ~D[2016-02-15]\n\n    iex> date = ~D[2016-01-31]\n    ...> Timex.shift(date, months: 1)\n    ~D[2016-02-29]\n\n    iex> date = ~D[2016-01-31]\n    ...> Timex.shift(date, months: 2)\n    ~D[2016-03-31]\n    ...> Timex.shift(date, months: 1) |> Timex.shift(months: 1)\n    ~D[2016-03-29]","ref":"Timex.html#shift/2-shifting-by-months"},{"type":"type","title":"Timex.shift_options/0","doc":"","ref":"Timex.html#t:shift_options/0"},{"type":"function","title":"Timex.subtract/2","doc":"Subtract time from a date using a Duration\nSame as `shift(date, Duration.from_minutes(5) |> Duration.invert, :timestamp)`.","ref":"Timex.html#subtract/2"},{"type":"function","title":"Timex.timezone/2","doc":"Get a TimezoneInfo object for the specified offset or name.\n\nWhen offset or name is invalid, exception is raised.\n\nIf no DateTime value is given for the second parameter, the current date/time\nwill be used (in other words, it will return the current timezone info for the\ngiven zone). If one is provided, the timezone info returned will be based on\nthe provided DateTime (or Erlang datetime tuple) value.","ref":"Timex.html#timezone/2"},{"type":"function","title":"Examples - Timex.timezone/2","doc":"iex> date = Timex.to_datetime({2015, 4, 12})\n    ...> tz = Timex.timezone(:utc, date)\n    ...> tz.full_name\n    \"Etc/UTC\"\n\n    iex> tz = Timex.timezone(\"America/Chicago\", {2015,4,12})\n    ...> {tz.full_name, tz.abbreviation}\n    {\"America/Chicago\", \"CDT\"}\n\n    iex> tz = Timex.timezone(+2, {2015, 4, 12})\n    ...> {tz.full_name, tz.abbreviation}\n    {\"Etc/UTC+2\", \"+02\"}","ref":"Timex.html#timezone/2-examples"},{"type":"function","title":"Timex.timezones/0","doc":"Returns a list of all valid timezone names in the Olson database","ref":"Timex.html#timezones/0"},{"type":"function","title":"Timex.to_date/1","doc":"Convert a date/time value to a Date struct.","ref":"Timex.html#to_date/1"},{"type":"function","title":"Timex.to_datetime/1","doc":"Convert a date/time value and timezone name to a DateTime struct.\n\nIf the DateTime did not occur in the timezone, an error will be returned.\n\nIf the DateTime is ambiguous and cannot be resolved, an AmbiguousDateTime will be returned,\nallowing the developer to choose which of the two choices is desired.\n\nIf no timezone is provided, \"Etc/UTC\" will be used.","ref":"Timex.html#to_datetime/1"},{"type":"function","title":"Examples - Timex.to_datetime/1","doc":"iex> Timex.to_datetime(~N[2022-01-01 12:00:00], \"America/New_York\")\n    #DateTime<2022-01-01 12:00:00-05:00 EST America/New_York>\n\n    # This time was skipped as daylight savings started and clocks moved forward\n    iex> Timex.to_datetime(~N[2021-03-14 02:30:00], \"America/New_York\")\n    {:error, {:could_not_resolve_timezone, \"America/New_York\", 63782908200, :wall}}\n\n    # This time occurred twice as daylight savings ended and clocks moved back\n    iex> %AmbiguousDateTime{} = adt = Timex.to_datetime(~N[2021-11-07 01:30:00], \"America/New_York\")\n    ...> match?(%DateTime{zone_abbr: \"EDT\"}, adt.before) && match?(%DateTime{zone_abbr: \"EST\"}, adt.after)\n    true\n\n    iex> Timex.to_datetime(~N[2022-01-01 12:00:00])\n    ~U[2022-01-01 12:00:00Z]","ref":"Timex.html#to_datetime/1-examples"},{"type":"function","title":"Timex.to_datetime/2","doc":"See  Timex.Protocol.to_datetime/2 .","ref":"Timex.html#to_datetime/2"},{"type":"function","title":"Timex.to_erl/1","doc":"Convert a date/time value to it's Erlang representation","ref":"Timex.html#to_erl/1"},{"type":"function","title":"Timex.to_gregorian_microseconds/1","doc":"Convert a date/time value to gregorian microseconds (microseconds since start of year zero)","ref":"Timex.html#to_gregorian_microseconds/1"},{"type":"function","title":"Timex.to_gregorian_seconds/1","doc":"Convert a date/time value to gregorian seconds (seconds since start of year zero)","ref":"Timex.html#to_gregorian_seconds/1"},{"type":"function","title":"Timex.to_julian/1","doc":"Convert a date/time value to a Julian calendar date number","ref":"Timex.html#to_julian/1"},{"type":"function","title":"Timex.to_naive_datetime/1","doc":"Convert a date/time value to a NaiveDateTime struct.","ref":"Timex.html#to_naive_datetime/1"},{"type":"function","title":"Timex.to_unix/1","doc":"Convert a date/time value to seconds since the UNIX epoch","ref":"Timex.html#to_unix/1"},{"type":"function","title":"Timex.today/0","doc":"Returns a Date representing the current day in UTC","ref":"Timex.html#today/0"},{"type":"function","title":"Timex.today/1","doc":"Returns a Date representing the current day in the provided timezone.","ref":"Timex.html#today/1"},{"type":"function","title":"Timex.validate_format/1","doc":"Given a format string, validates that the format string is valid for the Default formatter.\n\nGiven a format string and a formatter, validates that the format string is valid for that formatter.","ref":"Timex.html#validate_format/1"},{"type":"function","title":"Examples - Timex.validate_format/1","doc":"iex> use Timex\n    ...> Timex.validate_format(\"{YYYY}-{M}-{D}\")\n    :ok\n\n    iex> use Timex\n    ...> Timex.validate_format(\"{YYYY}-{M}-{V}\")\n    {:error, \"Expected end of input at line 1, column 11\"}\n\n    iex> use Timex\n    ...> Timex.validate_format(\"%FT%T%:z\", :strftime)\n    :ok","ref":"Timex.html#validate_format/1-examples"},{"type":"function","title":"Timex.validate_format/2","doc":"See  Timex.Format.DateTime.Formatter.validate/2 .","ref":"Timex.html#validate_format/2"},{"type":"function","title":"Timex.week_of_month/1","doc":"Returns the week number of the date provided, starting at 1.","ref":"Timex.html#week_of_month/1"},{"type":"function","title":"Examples - Timex.week_of_month/1","doc":"iex> Timex.week_of_month(~D[2016-03-05])\n    1\n\n    iex> Timex.week_of_month(~N[2016-03-14T00:00:00Z])\n    3","ref":"Timex.html#week_of_month/1-examples"},{"type":"function","title":"Timex.week_of_month/3","doc":"Same as week_of_month/1, except takes year, month, and day as distinct arguments","ref":"Timex.html#week_of_month/3"},{"type":"function","title":"Examples - Timex.week_of_month/3","doc":"iex> Timex.week_of_month(2016, 3, 30)\n    5","ref":"Timex.html#week_of_month/3-examples"},{"type":"function","title":"Timex.weekday/1","doc":"Return weekday number (as defined by ISO 8601) of the specified date.","ref":"Timex.html#weekday/1"},{"type":"function","title":"Examples - Timex.weekday/1","doc":"iex> Timex.epoch |> Timex.weekday\n    4 # (i.e. Thursday)","ref":"Timex.html#weekday/1-examples"},{"type":"function","title":"Timex.weekday/2","doc":"Like `weekday/1`, but accepts a valid starting weekday value.","ref":"Timex.html#weekday/2"},{"type":"function","title":"Examples - Timex.weekday/2","doc":"iex> Timex.epoch() |> Elixir.Timex.weekday(:sunday)\n    5","ref":"Timex.html#weekday/2-examples"},{"type":"function","title":"Timex.weekday!/2","doc":"Provides a version of `weekday/1` and `weekday/2` that raises on error.","ref":"Timex.html#weekday!/2"},{"type":"function","title":"Timex.zero/0","doc":"Returns a Date representing the start of the Gregorian epoch","ref":"Timex.html#zero/0"},{"type":"module","title":"Timex.AmbiguousDateTime","doc":"Represents a DateTime which is ambiguous due to timezone rules.","ref":"Timex.AmbiguousDateTime.html"},{"type":"module","title":"Ambiguity #1 - Non-existent times - Timex.AmbiguousDateTime","doc":"Let's use American daylight savings time rules as our example here,\nusing America/Chicago as our example. Central Standard Time for that\nzone ends at 2:00 AM, but Central Daylight Time does not begin until\n3:00 AM, this is because at 2:00 AM, our clocks \"spring forward\" - which\nis just an easy way of remembering that the offset goes from -6 from UTC,\nto -5 from UTC. Since there is no timezone period associated with the hours\nof 2-3 AM in the America/Chicago zone (it's neither CST nor CDT during that hour),\none has to decide what the intent is. Timex makes the call that shifting to the\nnext period (i.e. \"spring forward\" using our example above) makes the most logical\nsense when working with non-existent time periods.\n\nTL;DR - Timex will \"spring forward\" or \"fall back\", depending on what the zone change\nhappens to be for the non-existent time. Using America/Chicago as an example, if you\ntry to create a DateTime for 2 AM on March 13, 2016, Timex will give you back 3 AM on\nMarch 13, 2016, because the zone is in the middle of changing from CST to CDT, and the\nearliest representable time in CDT is 3 AM.","ref":"Timex.AmbiguousDateTime.html#module-ambiguity-1-non-existent-times"},{"type":"module","title":"Ambiguity #2 - Times with more than one valid zone period - Timex.AmbiguousDateTime","doc":"This one is the reason why this module exists. There are times, though rare, where more\nthan one zone applies to a given date and time. For example, Asia/Taipei, on December 31st,\n1895, from 23:54:00 to 23:59:59, two timezone periods are active LMT, and JWST, because that\nlocale was switching to JWST from LMT. Because of this, it's impossible to know programmatically\nwhich zone is desired. The programmer must make a choice on which zone they want to use.\n\nFor this use case, Timex will return an AmbiguousDateTime any time you try to create a DateTime,\nor shift a DateTime, to an ambiguous time period. It has two fields, :before, containing a DateTime\nconfigured in the timezone occurring before the ambiguous period, and :after, containing a DateTime\nconfigured in the timezone occurring after the ambiguous period. It is up to you as the programmer to\ndecide which DateTime is the one to use, but my recommendation is to choose :after, unless you have a\nspecific reason to use :before.","ref":"Timex.AmbiguousDateTime.html#module-ambiguity-2-times-with-more-than-one-valid-zone-period"},{"type":"type","title":"Timex.AmbiguousDateTime.t/0","doc":"","ref":"Timex.AmbiguousDateTime.html#t:t/0"},{"type":"module","title":"Timex.AmbiguousTimezoneInfo","doc":"Represents a choice of two possible timezone periods for a given\npoint in time.","ref":"Timex.AmbiguousTimezoneInfo.html"},{"type":"function","title":"Timex.AmbiguousTimezoneInfo.new/2","doc":"","ref":"Timex.AmbiguousTimezoneInfo.html#new/2"},{"type":"type","title":"Timex.AmbiguousTimezoneInfo.t/0","doc":"","ref":"Timex.AmbiguousTimezoneInfo.html#t:t/0"},{"type":"module","title":"Timex.Calendar.Julian","doc":"This module contains functions for working with dates in the Julian calendar.","ref":"Timex.Calendar.Julian.html"},{"type":"function","title":"Timex.Calendar.Julian.date_for_day_of_year/3","doc":"Given a Julian day of year, and a year, this function returns the\n`Date` which that day falls on.\n\nIf no options are provided, leap days are disregarded, and the valid range for\nthe day provided is 1-365, i.e. there is no representation\nfor Feb 29.\n\nTo allow representing leap days, you may pass `leaps: true`, which in\nturn expands the range of the day provided to 0-365.\n\nNOTE: This is internally used for POSIX-TZ support, but may be useful\nto others, so it is being made public.","ref":"Timex.Calendar.Julian.html#date_for_day_of_year/3"},{"type":"function","title":"Timex.Calendar.Julian.day_of_week/2","doc":"Returns the day of the week, starting with 0 for Sunday, or 1 for Monday","ref":"Timex.Calendar.Julian.html#day_of_week/2"},{"type":"function","title":"Timex.Calendar.Julian.day_of_week/4","doc":"Same as day_of_week/1, except takes year/month/day as distinct arguments","ref":"Timex.Calendar.Julian.html#day_of_week/4"},{"type":"function","title":"Timex.Calendar.Julian.julian_date/1","doc":"Returns the Julian day number for the given Erlang date (gregorian)\n\nThe Julian date (JD) is a continuous count of days from 1 January 4713 BC (= -4712 January 1),\nGreenwich mean noon (= 12h UT). For example, AD 1978 January 1, 0h UT is JD 2443509.5\nand AD 1978 July 21, 15h UT, is JD 2443711.125.\n\nThis algorithm assumes a proleptic Gregorian calendar (i.e. dates back to year 0),\nunlike the NASA or US Naval Observatory algorithm - however they align perfectly\nfor dates back to October 15th, 1582, which is where it starts to differ, which is\ndue to the fact that their algorithm assumes there is no Gregorian calendar before that\ndate.","ref":"Timex.Calendar.Julian.html#julian_date/1"},{"type":"function","title":"Timex.Calendar.Julian.julian_date/3","doc":"Same as julian_date/1, except takes year/month/day as distinct arguments","ref":"Timex.Calendar.Julian.html#julian_date/3"},{"type":"function","title":"Timex.Calendar.Julian.julian_date/6","doc":"Same as julian_date/1, except takes year/month/day/hour/minute/second as distinct arguments","ref":"Timex.Calendar.Julian.html#julian_date/6"},{"type":"protocol","title":"Timex.Comparable","doc":"This protocol is used for comparing and diffing different date/time representations","ref":"Timex.Comparable.html"},{"type":"type","title":"Timex.Comparable.comparable/0","doc":"","ref":"Timex.Comparable.html#t:comparable/0"},{"type":"function","title":"Timex.Comparable.compare/3","doc":"Compare two date or datetime types.\n\nYou can optionally specify a comparison granularity, any of the following:\n\n- :year\n- :years\n- :month\n- :months\n- :week\n- :weeks\n- :calendar_week (weeks of the calendar as opposed to actual weeks in terms of days)\n- :calendar_weeks\n- :day\n- :days\n- :hour\n- :hours\n- :minute\n- :minutes\n- :second\n- :seconds\n- :millisecond\n- :milliseconds\n- :microsecond (default)\n- :microseconds\n- :duration\n\nand the dates will be compared with the corresponding accuracy.\nThe default granularity is `:microsecond`.\n\n  - 0:  when equal\n  - -1: when the first date/time comes before the second\n  - 1:  when the first date/time comes after the second\n  - {:error, reason}: when there was a problem comparing,\n    perhaps due to a value being passed which is not a valid date/datetime","ref":"Timex.Comparable.html#compare/3"},{"type":"function","title":"Examples - Timex.Comparable.compare/3","doc":"iex> use Timex\n    iex> date1 = ~D[2014-03-04]\n    iex> date2 = ~D[2015-03-04]\n    iex> Timex.compare(date1, date2, :year)\n    -1\n    iex> Timex.compare(date2, date1, :year)\n    1\n    iex> Timex.compare(date1, date1)\n    0","ref":"Timex.Comparable.html#compare/3-examples"},{"type":"type","title":"Timex.Comparable.compare_result/0","doc":"","ref":"Timex.Comparable.html#t:compare_result/0"},{"type":"type","title":"Timex.Comparable.constants/0","doc":"","ref":"Timex.Comparable.html#t:constants/0"},{"type":"function","title":"Timex.Comparable.diff/3","doc":"Get the difference between two date or datetime types.\n\nYou can optionally specify a diff granularity, any of the following:\n\n- :year\n- :years\n- :month\n- :months\n- :week\n- :weeks\n- :calendar_week (weeks of the calendar as opposed to actual weeks in terms of days)\n- :calendar_weeks\n- :day\n- :days\n- :hour\n- :hours\n- :minute\n- :minutes\n- :second\n- :seconds\n- :millisecond\n- :milliseconds\n- :microsecond (default)\n- :microseconds\n- :duration\n\nand the result will be an integer value of those units or a Duration struct.\nThe diff value will be negative if `a` comes before `b`, and positive if `a` comes\nafter `b`. This behaviour mirrors `compare/3`.\n\nWhen using granularity of :months, the number of days in the month varies. This\nbehavior mirrors `Timex.shift/2`.","ref":"Timex.Comparable.html#diff/3"},{"type":"function","title":"Examples - Timex.Comparable.diff/3","doc":"iex> use Timex\n    iex> date1 = ~D[2015-01-28]\n    iex> date2 = ~D[2015-02-28]\n    iex> Timex.diff(date1, date2, :month)\n    -1\n    iex> Timex.diff(date2, date1, :month)\n    1\n\n    iex> use Timex\n    iex> date1 = ~D[2015-01-31]\n    iex> date2 = ~D[2015-02-28]\n    iex> Timex.diff(date1, date2, :month)\n    -1\n    iex> Timex.diff(date2, date1, :month)\n    0","ref":"Timex.Comparable.html#diff/3-examples"},{"type":"type","title":"Timex.Comparable.diff_result/0","doc":"","ref":"Timex.Comparable.html#t:diff_result/0"},{"type":"type","title":"Timex.Comparable.granularity/0","doc":"","ref":"Timex.Comparable.html#t:granularity/0"},{"type":"type","title":"Timex.Comparable.t/0","doc":"All the types that implement this protocol.","ref":"Timex.Comparable.html#t:t/0"},{"type":"module","title":"Timex.Date","doc":"","ref":"Timex.Date.html"},{"type":"module","title":"Timex.DateTime","doc":"","ref":"Timex.DateTime.html"},{"type":"module","title":"Timex.Duration","doc":"This module provides a friendly API for working with Erlang\ntimestamps, i.e. `{megasecs, secs, microsecs}`. In addition,\nit provides an easy way to wrap the measurement of function\nexecution time (via `measure`).","ref":"Timex.Duration.html"},{"type":"function","title":"Timex.Duration.abs/1","doc":"Returns the absolute value of the provided Duration.","ref":"Timex.Duration.html#abs/1"},{"type":"function","title":"Example - Timex.Duration.abs/1","doc":"iex> d = %Timex.Duration{megaseconds: -1, seconds: -2, microseconds: -3}\n    ...> Timex.Duration.abs(d)\n    %Timex.Duration{megaseconds: 1, seconds: 2, microseconds: 3}","ref":"Timex.Duration.html#abs/1-example"},{"type":"function","title":"Timex.Duration.add/2","doc":"Add one Duration to another.","ref":"Timex.Duration.html#add/2"},{"type":"function","title":"Examples - Timex.Duration.add/2","doc":"iex> d = %Timex.Duration{megaseconds: 1, seconds: 1, microseconds: 1}\n    ...> Timex.Duration.add(d, d)\n    %Timex.Duration{megaseconds: 2, seconds: 2, microseconds: 2}\n\n    iex> d = %Timex.Duration{megaseconds: 1, seconds: 750000, microseconds: 750000}\n    ...> Timex.Duration.add(d, d)\n    %Timex.Duration{megaseconds: 3, seconds: 500001, microseconds: 500000}","ref":"Timex.Duration.html#add/2-examples"},{"type":"function","title":"Timex.Duration.diff/3","doc":"This function determines the difference in time between two timestamps\n(represented by Duration structs). If the second timestamp is omitted,\n`Duration.now` will be used as the reference timestamp. If the first\ntimestamp argument occurs before the second, the resulting measurement will\nbe a negative value.\n\nThe type argument is an atom indicating the units the measurement should be\nreturned in. If no type argument is provided, a Duration will be returned.\n\nValid measurement units for this function are:\n\n    :microseconds, :milliseconds, :seconds, :minutes, :hours, :days, or :weeks","ref":"Timex.Duration.html#diff/3"},{"type":"function","title":"Examples - Timex.Duration.diff/3","doc":"iex> alias Timex.Duration\n    ...> d = Duration.from_erl({1457, 136000, 785000})\n    ...> Duration.diff(d, Duration.zero, :days)\n    16865","ref":"Timex.Duration.html#diff/3-examples"},{"type":"function","title":"Timex.Duration.elapsed/3","doc":"An alias for `Duration.diff/3`","ref":"Timex.Duration.html#elapsed/3"},{"type":"function","title":"Timex.Duration.epoch/0","doc":"Returns the duration since the first day of year 0 to Epoch.","ref":"Timex.Duration.html#epoch/0"},{"type":"function","title":"Example - Timex.Duration.epoch/0","doc":"iex> Timex.Duration.epoch()\n    %Timex.Duration{megaseconds: 62_167, seconds: 219_200, microseconds: 0}","ref":"Timex.Duration.html#epoch/0-example"},{"type":"function","title":"Timex.Duration.epoch/1","doc":"Returns the amount of time since the first day of year 0 to Epoch.\n\nThe argument is an atom indicating the type of time units to return.\n\nThe allowed unit type atoms are:\n- :microseconds\n- :milliseconds\n- :seconds\n- :minutes\n- :hours\n- :days\n- :weeks","ref":"Timex.Duration.html#epoch/1"},{"type":"function","title":"Examples - Timex.Duration.epoch/1","doc":"iex> Timex.Duration.epoch(:seconds)\n    62_167_219_200\n\nIf the specified type is nil, a duration since the first day of year 0 to Epoch\nis returned.\n\n    iex> Timex.Duration.epoch(nil)\n    %Timex.Duration{megaseconds: 62_167, seconds: 219_200, microseconds: 0}","ref":"Timex.Duration.html#epoch/1-examples"},{"type":"function","title":"Timex.Duration.from_clock/1","doc":"Converts a clock tuple, i.e. `{hour, minute, second, microsecond}` to a Duration.","ref":"Timex.Duration.html#from_clock/1"},{"type":"function","title":"Example - Timex.Duration.from_clock/1","doc":"iex> Timex.Duration.from_clock({1, 2, 3, 4})\n    %Timex.Duration{megaseconds: 0, seconds: 3723, microseconds: 4}","ref":"Timex.Duration.html#from_clock/1-example"},{"type":"function","title":"Timex.Duration.from_days/1","doc":"Converts an integer value representing days to a Duration","ref":"Timex.Duration.html#from_days/1"},{"type":"function","title":"Timex.Duration.from_erl/1","doc":"Converts an Erlang timestamp to a Duration","ref":"Timex.Duration.html#from_erl/1"},{"type":"function","title":"Example - Timex.Duration.from_erl/1","doc":"iex> Timex.Duration.from_erl({1, 2, 3})\n    %Timex.Duration{megaseconds: 1, seconds: 2, microseconds: 3}","ref":"Timex.Duration.html#from_erl/1-example"},{"type":"function","title":"Timex.Duration.from_hours/1","doc":"Converts an integer value representing hours to a Duration","ref":"Timex.Duration.html#from_hours/1"},{"type":"function","title":"Timex.Duration.from_microseconds/1","doc":"Converts an integer value representing microseconds to a Duration","ref":"Timex.Duration.html#from_microseconds/1"},{"type":"function","title":"Timex.Duration.from_milliseconds/1","doc":"Converts an integer value representing milliseconds to a Duration","ref":"Timex.Duration.html#from_milliseconds/1"},{"type":"function","title":"Timex.Duration.from_minutes/1","doc":"Converts an integer value representing minutes to a Duration","ref":"Timex.Duration.html#from_minutes/1"},{"type":"function","title":"Timex.Duration.from_seconds/1","doc":"Converts an integer value representing seconds to a Duration","ref":"Timex.Duration.html#from_seconds/1"},{"type":"function","title":"Timex.Duration.from_time/1","doc":"Converts a Time to a Duration","ref":"Timex.Duration.html#from_time/1"},{"type":"function","title":"Example - Timex.Duration.from_time/1","doc":"iex> Timex.Duration.from_time(~T[01:01:30])\n    %Timex.Duration{megaseconds: 0, seconds: 3690, microseconds: 0}","ref":"Timex.Duration.html#from_time/1-example"},{"type":"function","title":"Timex.Duration.from_weeks/1","doc":"Converts an integer value representing weeks to a Duration","ref":"Timex.Duration.html#from_weeks/1"},{"type":"function","title":"Timex.Duration.invert/1","doc":"Invert a Duration, i.e. a positive duration becomes a negative one, and vice versa","ref":"Timex.Duration.html#invert/1"},{"type":"function","title":"Example - Timex.Duration.invert/1","doc":"iex> d = %Timex.Duration{megaseconds: -1, seconds: -2, microseconds: -3}\n    ...> Timex.Duration.invert(d)\n    %Timex.Duration{megaseconds: 1, seconds: 2, microseconds: 3}","ref":"Timex.Duration.html#invert/1-example"},{"type":"function","title":"Timex.Duration.measure/1","doc":"Evaluates fun() and measures the elapsed time.\n\nReturns `{Duration.t, result}`.","ref":"Timex.Duration.html#measure/1"},{"type":"function","title":"Example - Timex.Duration.measure/1","doc":"iex> {_timestamp, result} = Duration.measure(fn -> 2 * 2 end)\n    ...> result == 4\n    true","ref":"Timex.Duration.html#measure/1-example"},{"type":"function","title":"Timex.Duration.measure/2","doc":"Evaluates `apply(fun, args)`, and measures execution time.\n\nReturns `{Duration.t, result}`.","ref":"Timex.Duration.html#measure/2"},{"type":"function","title":"Example - Timex.Duration.measure/2","doc":"iex> {_timestamp, result} = Duration.measure(fn x, y -> x * y end, [2, 4])\n    ...> result == 8\n    true","ref":"Timex.Duration.html#measure/2-example"},{"type":"function","title":"Timex.Duration.measure/3","doc":"Evaluates `apply(module, fun, args)`, and measures execution time.\n\nReturns `{Duration.t, result}`.","ref":"Timex.Duration.html#measure/3"},{"type":"function","title":"Example - Timex.Duration.measure/3","doc":"iex> {_timestamp, result} = Duration.measure(Enum, :map, [[1,2], &(&1*2)])\n    ...> result == [2, 4]\n    true","ref":"Timex.Duration.html#measure/3-example"},{"type":"type","title":"Timex.Duration.measurement_units/0","doc":"","ref":"Timex.Duration.html#t:measurement_units/0"},{"type":"function","title":"Timex.Duration.normalize/1","doc":"","ref":"Timex.Duration.html#normalize/1"},{"type":"function","title":"Timex.Duration.now/1","doc":"Returns the amount of time since Epoch.\n\nThe argument is an atom indicating the type of time units to return.\n\nThe allowed unit type atoms are:\n- :microsecond(s)\n- :millisecond(s)\n- :second(s)\n- :minutes\n- :hours\n- :days\n- :weeks","ref":"Timex.Duration.html#now/1"},{"type":"function","title":"Examples - Timex.Duration.now/1","doc":"iex> Timex.Duration.now(:seconds)\n    1483141644\n\nWhen the argument is omitted or nil, a Duration is returned.\n\n    iex> Timex.Duration.now\n    %Timex.Duration{megaseconds: 1483, seconds: 141562, microseconds: 536938}","ref":"Timex.Duration.html#now/1-examples"},{"type":"function","title":"Timex.Duration.parse/1","doc":"Parses a duration string (in ISO-8601 format) into a Duration struct.","ref":"Timex.Duration.html#parse/1"},{"type":"function","title":"Timex.Duration.parse/2","doc":"Parses a duration string into a Duration struct, using the provided parser module.","ref":"Timex.Duration.html#parse/2"},{"type":"function","title":"Timex.Duration.parse!/1","doc":"Same as parse/1, but returns the Duration unwrapped, and raises on error","ref":"Timex.Duration.html#parse!/1"},{"type":"function","title":"Timex.Duration.parse!/2","doc":"Same as parse/2, but returns the Duration unwrapped, and raises on error","ref":"Timex.Duration.html#parse!/2"},{"type":"function","title":"Timex.Duration.scale/2","doc":"Scale a Duration by some coefficient value, i.e. a scale of 2 is twice is long.","ref":"Timex.Duration.html#scale/2"},{"type":"function","title":"Example - Timex.Duration.scale/2","doc":"iex> d = %Timex.Duration{megaseconds: 1, seconds: 1, microseconds: 1}\n    ...> Timex.Duration.scale(d, 2)\n    %Timex.Duration{megaseconds: 2, seconds: 2, microseconds: 2}","ref":"Timex.Duration.html#scale/2-example"},{"type":"function","title":"Timex.Duration.sub/2","doc":"Subtract one Duration from another.","ref":"Timex.Duration.html#sub/2"},{"type":"function","title":"Example - Timex.Duration.sub/2","doc":"iex> d1 = %Timex.Duration{megaseconds: 3, seconds: 3, microseconds: 3}\n    ...> d2 = %Timex.Duration{megaseconds: 2, seconds: 2, microseconds: 2}\n    ...> Timex.Duration.sub(d1, d2)\n    %Timex.Duration{megaseconds: 1, seconds: 1, microseconds: 1}","ref":"Timex.Duration.html#sub/2-example"},{"type":"type","title":"Timex.Duration.t/0","doc":"","ref":"Timex.Duration.html#t:t/0"},{"type":"function","title":"Timex.Duration.to_clock/1","doc":"Converts a Duration to a clock tuple, i.e. `{hour,minute,second,microsecond}`.","ref":"Timex.Duration.html#to_clock/1"},{"type":"function","title":"Example - Timex.Duration.to_clock/1","doc":"iex> d = %Timex.Duration{megaseconds: 1, seconds: 1, microseconds: 50}\n    ...> Timex.Duration.to_clock(d)\n    {277, 46, 41, 50}","ref":"Timex.Duration.html#to_clock/1-example"},{"type":"function","title":"Timex.Duration.to_days/1","doc":"Converts a Duration to its value in days","ref":"Timex.Duration.html#to_days/1"},{"type":"function","title":"Example - Timex.Duration.to_days/1","doc":"iex> Duration.to_days(Duration.from_hours(6))\n    0.25\n    iex> Duration.to_days(Duration.from_hours(25), truncate: true)\n    1","ref":"Timex.Duration.html#to_days/1-example"},{"type":"function","title":"Timex.Duration.to_days/2","doc":"","ref":"Timex.Duration.html#to_days/2"},{"type":"function","title":"Timex.Duration.to_erl/1","doc":"Converts a Duration to an Erlang timestamp","ref":"Timex.Duration.html#to_erl/1"},{"type":"function","title":"Example - Timex.Duration.to_erl/1","doc":"iex> d = %Timex.Duration{megaseconds: 1, seconds: 2, microseconds: 3}\n    ...> Timex.Duration.to_erl(d)\n    {1, 2, 3}","ref":"Timex.Duration.html#to_erl/1-example"},{"type":"function","title":"Timex.Duration.to_hours/1","doc":"Converts a Duration to its value in hours","ref":"Timex.Duration.html#to_hours/1"},{"type":"function","title":"Example - Timex.Duration.to_hours/1","doc":"iex> Duration.to_hours(Duration.from_minutes(105))\n    1.75\n    iex> Duration.to_hours(Duration.from_minutes(105), truncate: true)\n    1","ref":"Timex.Duration.html#to_hours/1-example"},{"type":"function","title":"Timex.Duration.to_hours/2","doc":"","ref":"Timex.Duration.html#to_hours/2"},{"type":"function","title":"Timex.Duration.to_microseconds/1","doc":"Converts a Duration to its value in microseconds","ref":"Timex.Duration.html#to_microseconds/1"},{"type":"function","title":"Example - Timex.Duration.to_microseconds/1","doc":"iex> Duration.to_microseconds(Duration.from_milliseconds(10.5))\n    10_500","ref":"Timex.Duration.html#to_microseconds/1-example"},{"type":"function","title":"Timex.Duration.to_microseconds/2","doc":"","ref":"Timex.Duration.html#to_microseconds/2"},{"type":"function","title":"Timex.Duration.to_milliseconds/1","doc":"Converts a Duration to its value in milliseconds","ref":"Timex.Duration.html#to_milliseconds/1"},{"type":"function","title":"Example - Timex.Duration.to_milliseconds/1","doc":"iex> Duration.to_milliseconds(Duration.from_seconds(1))\n    1000.0\n    iex> Duration.to_milliseconds(Duration.from_seconds(1.543))\n    1543.0\n    iex> Duration.to_milliseconds(Duration.from_seconds(1.543), truncate: true)\n    1543","ref":"Timex.Duration.html#to_milliseconds/1-example"},{"type":"function","title":"Timex.Duration.to_milliseconds/2","doc":"","ref":"Timex.Duration.html#to_milliseconds/2"},{"type":"function","title":"Timex.Duration.to_minutes/1","doc":"Converts a Duration to its value in minutes","ref":"Timex.Duration.html#to_minutes/1"},{"type":"function","title":"Example - Timex.Duration.to_minutes/1","doc":"iex> Duration.to_minutes(Duration.from_seconds(90))\n    1.5\n    iex> Duration.to_minutes(Duration.from_seconds(65), truncate: true)\n    1","ref":"Timex.Duration.html#to_minutes/1-example"},{"type":"function","title":"Timex.Duration.to_minutes/2","doc":"","ref":"Timex.Duration.html#to_minutes/2"},{"type":"type","title":"Timex.Duration.to_options/0","doc":"","ref":"Timex.Duration.html#t:to_options/0"},{"type":"function","title":"Timex.Duration.to_seconds/1","doc":"Converts a Duration to its value in seconds","ref":"Timex.Duration.html#to_seconds/1"},{"type":"function","title":"Example - Timex.Duration.to_seconds/1","doc":"iex> Duration.to_seconds(Duration.from_milliseconds(1500))\n    1.5\n    iex> Duration.to_seconds(Duration.from_milliseconds(1500), truncate: true)\n    1","ref":"Timex.Duration.html#to_seconds/1-example"},{"type":"function","title":"Timex.Duration.to_seconds/2","doc":"","ref":"Timex.Duration.html#to_seconds/2"},{"type":"function","title":"Timex.Duration.to_string/1","doc":"Converts a Duration to a string, using the ISO standard for formatting durations.","ref":"Timex.Duration.html#to_string/1"},{"type":"function","title":"Examples - Timex.Duration.to_string/1","doc":"iex> d = %Timex.Duration{megaseconds: 0, seconds: 3661, microseconds: 0}\n    ...> Timex.Duration.to_string(d)\n    \"PT1H1M1S\"\n\n    iex> d = %Timex.Duration{megaseconds: 102, seconds: 656013, microseconds: 33}\n    ...> Timex.Duration.to_string(d)\n    \"P3Y3M3DT3H33M33.000033S\"","ref":"Timex.Duration.html#to_string/1-examples"},{"type":"function","title":"Timex.Duration.to_time/1","doc":"Converts a Duration to a Time if the duration fits within a 24-hour clock.\nIf it does not, an error tuple is returned.","ref":"Timex.Duration.html#to_time/1"},{"type":"function","title":"Examples - Timex.Duration.to_time/1","doc":"iex> d = %Timex.Duration{megaseconds: 0, seconds: 4000, microseconds: 0}\n    ...> Timex.Duration.to_time(d)\n    {:ok, ~T[01:06:40]}\n\n    iex> d = %Timex.Duration{megaseconds: 1, seconds: 0, microseconds: 0}\n    ...> Timex.Duration.to_time(d)\n    {:error, :invalid_time}","ref":"Timex.Duration.html#to_time/1-examples"},{"type":"function","title":"Timex.Duration.to_time!/1","doc":"Same as to_time/1, but returns the Time directly. Raises an error if the\nduration does not fit within a 24-hour clock.","ref":"Timex.Duration.html#to_time!/1"},{"type":"function","title":"Examples - Timex.Duration.to_time!/1","doc":"iex> d = %Timex.Duration{megaseconds: 0, seconds: 4000, microseconds: 0}\n    ...> Timex.Duration.to_time!(d)\n    ~T[01:06:40]\n\n    iex> d = %Timex.Duration{megaseconds: 1, seconds: 0, microseconds: 0}\n    ...> Timex.Duration.to_time!(d)\n    ** (ArgumentError) cannot convert {277, 46, 40} to time, reason: :invalid_time","ref":"Timex.Duration.html#to_time!/1-examples"},{"type":"function","title":"Timex.Duration.to_weeks/1","doc":"Converts a Duration to its value in weeks","ref":"Timex.Duration.html#to_weeks/1"},{"type":"function","title":"Example - Timex.Duration.to_weeks/1","doc":"iex> Duration.to_weeks(Duration.from_days(14))\n    2.0\n    iex> Duration.to_weeks(Duration.from_days(13), truncate: true)\n    1","ref":"Timex.Duration.html#to_weeks/1-example"},{"type":"function","title":"Timex.Duration.to_weeks/2","doc":"","ref":"Timex.Duration.html#to_weeks/2"},{"type":"type","title":"Timex.Duration.units/0","doc":"","ref":"Timex.Duration.html#t:units/0"},{"type":"function","title":"Timex.Duration.zero/0","doc":"Return a timestamp representing a time lapse of length 0.\n\n    iex> Timex.Duration.zero |> Timex.Duration.to_seconds\n    0.0\n\nCan be useful for operations on collections of durations. For instance,\n\n    Enum.reduce(durations, Duration.zero, Duration.add(&1, &2))\n\nCan also be used to represent the timestamp of the start of the UNIX epoch,\nas all Erlang timestamps are relative to this point.","ref":"Timex.Duration.html#zero/0"},{"type":"behaviour","title":"Timex.Format.DateTime.Formatter","doc":"This module defines the behaviour for custom DateTime formatters.","ref":"Timex.Format.DateTime.Formatter.html"},{"type":"callback","title":"Timex.Format.DateTime.Formatter.format/2","doc":"","ref":"Timex.Format.DateTime.Formatter.html#c:format/2"},{"type":"function","title":"Timex.Format.DateTime.Formatter.format/3","doc":"Formats a Date, DateTime, or NaiveDateTime as a string, using the provided format\nstring and formatter. If a formatter is not provided, the formatter\nused is `Timex.Format.DateTime.Formatters.DefaultFormatter`.\n\nFormatting will use the configured default locale, \"en\" if no other default is given.","ref":"Timex.Format.DateTime.Formatter.html#format/3"},{"type":"callback","title":"Timex.Format.DateTime.Formatter.format!/2","doc":"","ref":"Timex.Format.DateTime.Formatter.html#c:format!/2"},{"type":"function","title":"Timex.Format.DateTime.Formatter.format!/3","doc":"Formats a Date, DateTime, or NaiveDateTime as a string, using the provided format\nstring and formatter. If a formatter is not provided, the formatter\nused is `Timex.Format.DateTime.Formatters.DefaultFormatter`.\n\nFormatting will use the configured default locale, \"en\" if no other default is given.\n\nIf an error is encountered during formatting, `format!` will raise.","ref":"Timex.Format.DateTime.Formatter.html#format!/3"},{"type":"function","title":"Timex.Format.DateTime.Formatter.format_token/5","doc":"Given a token (as found in `Timex.Parsers.Directive`), and a Date, DateTime, or NaiveDateTime struct,\nproduce a string representation of the token using values from the struct, using the default locale.","ref":"Timex.Format.DateTime.Formatter.html#format_token/5"},{"type":"function","title":"Timex.Format.DateTime.Formatter.format_token/6","doc":"Given a token (as found in `Timex.Parsers.Directive`), and a Date, DateTime, or NaiveDateTime struct,\nproduce a string representation of the token using values from the struct.","ref":"Timex.Format.DateTime.Formatter.html#format_token/6"},{"type":"callback","title":"Timex.Format.DateTime.Formatter.lformat/3","doc":"","ref":"Timex.Format.DateTime.Formatter.html#c:lformat/3"},{"type":"function","title":"Timex.Format.DateTime.Formatter.lformat/4","doc":"Formats a Date, DateTime, or NaiveDateTime as a string, using the provided format string,\nlocale, and formatter.\n\nIf the locale provided does not have translations, \"en\" is used by default.\n\nIf a formatter is not provided, the formatter used is `Timex.Format.DateTime.Formatters.DefaultFormatter`","ref":"Timex.Format.DateTime.Formatter.html#lformat/4"},{"type":"callback","title":"Timex.Format.DateTime.Formatter.lformat!/3","doc":"","ref":"Timex.Format.DateTime.Formatter.html#c:lformat!/3"},{"type":"function","title":"Timex.Format.DateTime.Formatter.lformat!/4","doc":"Formats a Date, DateTime, or NaiveDateTime as a string, using the provided format string,\nlocale, and formatter. If the locale does not have translations, \"en\" will be used by\ndefault.\n\nIf a formatter is not provided, the formatter used is `Timex.Format.DateTime.Formatters.DefaultFormatter`\n\nIf an error is encountered during formatting, `lformat!` will raise","ref":"Timex.Format.DateTime.Formatter.html#lformat!/4"},{"type":"callback","title":"Timex.Format.DateTime.Formatter.tokenize/1","doc":"","ref":"Timex.Format.DateTime.Formatter.html#c:tokenize/1"},{"type":"function","title":"Timex.Format.DateTime.Formatter.validate/2","doc":"Validates the provided format string, using the provided formatter,\nor if none is provided, the default formatter. Returns `:ok` when valid,\nor `{:error, reason}` if not valid.","ref":"Timex.Format.DateTime.Formatter.html#validate/2"},{"type":"module","title":"Timex.Format.DateTime.Formatters.Default","doc":"Date formatting language used by default by the formatting functions in Timex.\n\nThis is a novel formatting language introduced with `DateFormat`. Its main\nadvantage is simplicity and usage of mnemonics that are easy to memorize.","ref":"Timex.Format.DateTime.Formatters.Default.html"},{"type":"module","title":"Directive format - Timex.Format.DateTime.Formatters.Default","doc":"A directive is an optional _padding specifier_ followed by a _mnemonic_, all enclosed\nin braces (`{` and `}`):\n\n    {  }\n\nSupported padding specifiers:\n\n* `0` -- pads the number with zeros. Applicable to mnemonics that produce numerical result.\n* `_` -- pads the number with spaces. Applicable to mnemonics that produce numerical result.\n\nWhen padding specifier is omitted, numbers will not be padded.","ref":"Timex.Format.DateTime.Formatters.Default.html#module-directive-format"},{"type":"module","title":"List of all directives - Timex.Format.DateTime.Formatters.Default","doc":"","ref":"Timex.Format.DateTime.Formatters.Default.html#module-list-of-all-directives"},{"type":"module","title":"Years and centuries - Timex.Format.DateTime.Formatters.Default","doc":"* `{YYYY}`    - full year number (0..9999)\n* `{YY}`      - the last two digits of the year number (0.99)\n* `{C}`       - century number (0..99)\n* `{WYYYY}`   - year number (4 digits) corresponding to the date's ISO week (0000..9999)\n* `{WYY}`     - year number (2 digits) corresponding to the date's ISO week (00.99)","ref":"Timex.Format.DateTime.Formatters.Default.html#module-years-and-centuries"},{"type":"module","title":"Months - Timex.Format.DateTime.Formatters.Default","doc":"* `{M}`       - month number (1..12)\n* `{Mshort}`  - abbreviated month name (Jan..Dec, no padding)\n* `{Mfull}`   - full month name (January..December, no padding)","ref":"Timex.Format.DateTime.Formatters.Default.html#module-months"},{"type":"module","title":"Days and weekdays - Timex.Format.DateTime.Formatters.Default","doc":"* `{D}`       - day number (1..31)\n* `{Dord}`    - ordinal day of the year (1..366)\n* `{WDmon}`   - weekday, Monday first (1..7, no padding)\n* `{WDsun}`   - weekday, Sunday first (0..6, no padding)\n* `{WDshort}` - abbreviated weekday name (Mon..Sun, no padding)\n* `{WDfull}`  - full weekday name (Monday..Sunday, no padding)","ref":"Timex.Format.DateTime.Formatters.Default.html#module-days-and-weekdays"},{"type":"module","title":"Weeks - Timex.Format.DateTime.Formatters.Default","doc":"* `{Wiso}`    - ISO week number (01..53)\n* `{Wmon}`    - week number of the year, Monday first (01..53)\n* `{Wsun}`    - week number of the year, Sunday first (01..53)","ref":"Timex.Format.DateTime.Formatters.Default.html#module-weeks"},{"type":"module","title":"Time - Timex.Format.DateTime.Formatters.Default","doc":"* `{h24}`     - hour of the day (00..23)\n* `{h12}`     - hour of the day (1..12)\n* `{m}`       - minutes of the hour (00..59)\n* `{s}`       - seconds of the minute (00..60)\n* `{ss}`      - fractional second, based on precision of microseconds given (.xxx == ms, .xxxxxx == us)\n* `{s-epoch}` - number of seconds since UNIX epoch\n* `{am}`      - lowercase am or pm (no padding)\n* `{AM}`      - uppercase AM or PM (no padding)","ref":"Timex.Format.DateTime.Formatters.Default.html#module-time"},{"type":"module","title":"Time zones - Timex.Format.DateTime.Formatters.Default","doc":"* `{Zname}`   - time zone name, e.g. `UTC` (no padding)\n* `{Zabbr}`   - time zone abbreviation, e.g. `CST` (no padding)\n* `{Z}`       - time zone offset in the form `+0230` (no padding)\n* `{Z:}`      - time zone offset in the form `-07:30` (no padding)\n* `{Z::}`     - time zone offset in the form `-07:30:00` (no padding)","ref":"Timex.Format.DateTime.Formatters.Default.html#module-time-zones"},{"type":"module","title":"Compound directives - Timex.Format.DateTime.Formatters.Default","doc":"These are shortcut directives corresponding to parts of the ISO 8601\nspecification. The benefit of using these over manually constructed ISO\nformats is that these directives convert the date to UTC for you.\n\n* `{ISO:Basic}`      - ` T  `.\n\n  Full date and time specification without separators.\n\n* `{ISO:Basic:Z}`    - ` T Z`.\n\n  Full date and time in UTC without separators (e.g.\n  `20070813T134801Z`)\n\n* `{ISO:Extended}`   - ` T  `.\n\n  Full date and time specification with separators. (e.g.\n  `2007-08-13T16:48:01 +03:00`)\n\n* `{ISO:Extended:Z}` - ` T Z`.\n\n  Full date and time in UTC. (e.g. `2007-08-13T13:48:01Z`)\n\n* `{ISOdate}`        - `YYYY-MM-DD`.\n\n  That is, 4-digit year number, followed by 2-digit month and day\n  numbers (e.g. `2007-08-13`)\n\n* `{ISOtime}`        - `hh:mm:ss`.\n\n  That is, 2-digit hour, minute, and second, separated by colons\n  (e.g. `13:04:05`). Midnight is 00 hours.\n\n* `{ISOweek}`        - `YYYY-Www`.\n\n  That is, ISO week-based year, followed by ISO week number (e.g.\n  `2007-W09`)\n\n* `{ISOweek-day}`    - `YYYY-Www-D`.\n\n  That is, an `{ISOweek}`, additionally followed by weekday (e.g.\n  `2007-W09-1`)\n\n* `{ISOord}`         - `YYYY-DDD`.\n\n  That is, year number, followed by the ordinal day number (e.g.\n  `2007-113`)\n\n* `{ASN1:UTCtime}`    - `YYMMDD Z`.\n\n  Full 2-digit year date and time in UTC without separators (e.g.\n  `070813134801Z`)\n\n* `{ASN1:GeneralizedTime}` - `YYYYMMDD `.\n\n  Full 4-digit year date and time in local timezone without\n  separators and with optional fractional seconds (e.g.\n  `20070813134801.032`)\n\n* `{ASN1:GeneralizedTime:Z}` - `YYYYMMDD Z`.\n\n  Full 4-digit year date and time in UTC without separators and with\n  optional fractional seconds (e.g. `20070813134801.032Z`)\n\n* `{ASN1:GeneralizedTime:TZ}` - `YYYYMMDD  `.\n\n  Full 4-digit year date and time in UTC without separators and with\n  optional fractional seconds (e.g. `20070813134801.032-0500`)\n\nThese directives provide support for miscellaneous common formats:\n\n* `{RFC822}`                  - e.g. `Mon, 05 Jun 14 23:20:59 UT`\n* `{RFC822z}`                 - e.g. `Mon, 05 Jun 14 23:20:59 Z`\n* `{RFC1123}`                 - e.g. `Tue, 05 Mar 2013 23:25:19 +0200`\n* `{RFC1123z}`                - e.g. `Tue, 05 Mar 2013 23:25:19 Z`\n* `{RFC3339}`                 - e.g. `2013-03-05T23:25:19+02:00`\n* `{RFC3339z}`                - e.g. `2013-03-05T23:25:19Z`\n* `{ANSIC}`                   - e.g. `Tue Mar  5 23:25:19 2013`\n* `{UNIX}`                    - e.g. `Tue Mar  5 23:25:19 PST 2013`\n* `{ASN1:UTCtime}`            - e.g. `130305232519Z`\n* `{ASN1:GeneralizedTime}`    - e.g. `20130305232519.928`\n* `{ASN1:GeneralizedTime:Z}`  - e.g. `20130305232519.928Z`\n* `{ASN1:GeneralizedTime:TZ}` - e.g. `20130305232519.928-0500`\n* `{kitchen}`                 - e.g. `3:25PM`","ref":"Timex.Format.DateTime.Formatters.Default.html#module-compound-directives"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Default.format/2","doc":"Callback implementation for  Timex.Format.DateTime.Formatter.format/2 .","ref":"Timex.Format.DateTime.Formatters.Default.html#format/2"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Default.format/3","doc":"","ref":"Timex.Format.DateTime.Formatters.Default.html#format/3"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Default.format!/2","doc":"Callback implementation for  Timex.Format.DateTime.Formatter.format!/2 .","ref":"Timex.Format.DateTime.Formatters.Default.html#format!/2"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Default.lformat/3","doc":"Callback implementation for  Timex.Format.DateTime.Formatter.lformat/3 .","ref":"Timex.Format.DateTime.Formatters.Default.html#lformat/3"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Default.lformat/4","doc":"If one wants to use the default formatting semantics with a different\ntokenizer, this is the way.","ref":"Timex.Format.DateTime.Formatters.Default.html#lformat/4"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Default.lformat!/3","doc":"Callback implementation for  Timex.Format.DateTime.Formatter.lformat!/3 .","ref":"Timex.Format.DateTime.Formatters.Default.html#lformat!/3"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Default.tokenize/1","doc":"Callback implementation for  Timex.Format.DateTime.Formatter.tokenize/1 .","ref":"Timex.Format.DateTime.Formatters.Default.html#tokenize/1"},{"type":"module","title":"Timex.Format.DateTime.Formatters.Relative","doc":"Relative time, based on Moment.js\n\nUses localized strings.\n\nThe format string should contain {relative}, which is where the phrase will be injected.\n\n| Range\t                     | Sample Output\n---------------------------------------------------------------------\n| 0 seconds                  | now\n| 1 to 45 seconds\t           | a few seconds ago\n| 45 to 90 seconds\t         | a minute ago\n| 90 seconds to 45 minutes\t | 2 minutes ago ... 45 minutes ago\n| 45 to 90 minutes\t         | an hour ago\n| 90 minutes to 22 hours\t   | 2 hours ago ... 22 hours ago\n| 22 to 36 hours\t           | a day ago\n| 36 hours to 25 days\t       | 2 days ago ... 25 days ago\n| 25 to 45 days\t             | a month ago\n| 45 to 345 days\t           | 2 months ago ... 11 months ago\n| 345 to 545 days (1.5 years)  | a year ago\n| 546 days+\t                 | 2 years ago ... 20 years ago","ref":"Timex.Format.DateTime.Formatters.Relative.html"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Relative.format/2","doc":"Formats a date/time as a relative time formatted string","ref":"Timex.Format.DateTime.Formatters.Relative.html#format/2"},{"type":"function","title":"Examples - Timex.Format.DateTime.Formatters.Relative.format/2","doc":"iex> Elixir.Timex.Format.DateTime.Formatters.Relative.format(Timex.shift(Timex.now, minutes: -1), \"{relative}\")\n    {:ok, \"1 minute ago\"}","ref":"Timex.Format.DateTime.Formatters.Relative.html#format/2-examples"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Relative.format!/2","doc":"Callback implementation for  Timex.Format.DateTime.Formatter.format!/2 .","ref":"Timex.Format.DateTime.Formatters.Relative.html#format!/2"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Relative.lformat/3","doc":"Callback implementation for  Timex.Format.DateTime.Formatter.lformat/3 .","ref":"Timex.Format.DateTime.Formatters.Relative.html#lformat/3"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Relative.lformat!/3","doc":"Callback implementation for  Timex.Format.DateTime.Formatter.lformat!/3 .","ref":"Timex.Format.DateTime.Formatters.Relative.html#lformat!/3"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Relative.relative_to/3","doc":"","ref":"Timex.Format.DateTime.Formatters.Relative.html#relative_to/3"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Relative.relative_to/4","doc":"","ref":"Timex.Format.DateTime.Formatters.Relative.html#relative_to/4"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Relative.tokenize/1","doc":"Callback implementation for  Timex.Format.DateTime.Formatter.tokenize/1 .","ref":"Timex.Format.DateTime.Formatters.Relative.html#tokenize/1"},{"type":"module","title":"Timex.Format.DateTime.Formatters.Strftime","doc":"Date formatting language defined by the `strftime` function from the Standard\nC Library.\n\nThis implementation in Elixir is mostly compatible with `strftime`. The\nexception is the absence of locale-depended results. All directives that imply\ntextual result will produce English names and abbreviations.\n\nA complete reference of the directives implemented here is given below.","ref":"Timex.Format.DateTime.Formatters.Strftime.html"},{"type":"module","title":"Directive format - Timex.Format.DateTime.Formatters.Strftime","doc":"A directive is marked by the percent sign (`%`) followed by one character\n(` `). In addition, a few optional specifiers can be inserted\nin-between:\n\n    %    \n\nSupported flags:\n\n* `-`       - don't pad numerical results (overrides default padding if any)\n* `0`       - use zeros for padding\n* `_`       - use spaces for padding\n* `:`, `::` - used only in combination with `%z`; see description of `%:z`\n              and `%::z` below\n\n` ` is a non-negative decimal number specifying the minimum field\nwidth.\n\n` ` can be `E` or `O`. These are locale-sensitive modifiers, and as\nsuch they are currently ignored by this implementation.","ref":"Timex.Format.DateTime.Formatters.Strftime.html#module-directive-format"},{"type":"module","title":"List of all directives - Timex.Format.DateTime.Formatters.Strftime","doc":"* `%%` - produces a single `%` in the output","ref":"Timex.Format.DateTime.Formatters.Strftime.html#module-list-of-all-directives"},{"type":"module","title":"Years and centuries - Timex.Format.DateTime.Formatters.Strftime","doc":"* `%Y` - full year number (0..9999)\n* `%y` - the last two digits of the year number (0..99)\n* `%C` - century number (00..99)\n* `%G` - year number corresponding to the date's ISO week (0..9999)\n* `%g` - year number (2 digits) corresponding to the date's ISO week (0..99)","ref":"Timex.Format.DateTime.Formatters.Strftime.html#module-years-and-centuries"},{"type":"module","title":"Months - Timex.Format.DateTime.Formatters.Strftime","doc":"* `%m` - month number (1..12)\n* `%b` - abbreviated month name (Jan..Dec, no padding)\n* `%h` - same is `%b`\n* `%B` - full month name (January..December, no padding)","ref":"Timex.Format.DateTime.Formatters.Strftime.html#module-months"},{"type":"module","title":"Days, and days of week - Timex.Format.DateTime.Formatters.Strftime","doc":"* `%d` - day number (1..31)\n* `%e` - same as `%d`, but padded with spaces ( 1..31)\n* `%j` - ordinal day of the year (001..366)\n* `%u` - weekday, Monday first (1..7)\n* `%w` - weekday, Sunday first (0..6)\n* `%a` - abbreviated weekday name (Mon..Sun, no padding)\n* `%A` - full weekday name (Monday..Sunday, no padding)","ref":"Timex.Format.DateTime.Formatters.Strftime.html#module-days-and-days-of-week"},{"type":"module","title":"Weeks - Timex.Format.DateTime.Formatters.Strftime","doc":"* `%V` - ISO week number (01..53)\n* `%W` - week number of the year, Monday first (00..52)\n* `%U` - week number of the year, Sunday first (00..52)","ref":"Timex.Format.DateTime.Formatters.Strftime.html#module-weeks"},{"type":"module","title":"Time - Timex.Format.DateTime.Formatters.Strftime","doc":"* `%H` - hour of the day (00..23)\n* `%k` - same as `%H`, but padded with spaces ( 0..23)\n* `%I` - hour of the day (1..12)\n* `%l` - same as `%I`, but padded with spaces ( 1..12)\n* `%M` - minutes of the hour (00..59)\n* `%S` - seconds of the minute (00..60)\n* `%f` - microseconds in zero padded decimal form, i.e. 025000\n* `%L` - milliseconds (000..999)\n* `%s` - number of seconds since UNIX epoch\n* `%P` - lowercase am or pm (no padding)\n* `%p` - uppercase AM or PM (no padding)","ref":"Timex.Format.DateTime.Formatters.Strftime.html#module-time"},{"type":"module","title":"Time zones - Timex.Format.DateTime.Formatters.Strftime","doc":"* `%Z`   - time zone name, e.g. `UTC` (no padding)\n* `%z`   - time zone offset in the form `+0230` (no padding)\n* `%:z`  - time zone offset in the form `-07:30` (no padding)\n* `%::z` - time zone offset in the form `-07:30:00` (no padding)","ref":"Timex.Format.DateTime.Formatters.Strftime.html#module-time-zones"},{"type":"module","title":"Compound directives - Timex.Format.DateTime.Formatters.Strftime","doc":"* `%D` - same as `%m/%d/%y`\n* `%F` - same as `%Y-%m-%d`\n* `%R` - same as `%H:%M`\n* `%r` - same as `%I:%M:%S %p`\n* `%T` - same as `%H:%M:%S`\n* `%v` - same as `%e-%b-%Y`","ref":"Timex.Format.DateTime.Formatters.Strftime.html#module-compound-directives"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Strftime.format/2","doc":"Callback implementation for  Timex.Format.DateTime.Formatter.format/2 .","ref":"Timex.Format.DateTime.Formatters.Strftime.html#format/2"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Strftime.format!/2","doc":"Callback implementation for  Timex.Format.DateTime.Formatter.format!/2 .","ref":"Timex.Format.DateTime.Formatters.Strftime.html#format!/2"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Strftime.lformat/3","doc":"Callback implementation for  Timex.Format.DateTime.Formatter.lformat/3 .","ref":"Timex.Format.DateTime.Formatters.Strftime.html#lformat/3"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Strftime.lformat!/3","doc":"Callback implementation for  Timex.Format.DateTime.Formatter.lformat!/3 .","ref":"Timex.Format.DateTime.Formatters.Strftime.html#lformat!/3"},{"type":"function","title":"Timex.Format.DateTime.Formatters.Strftime.tokenize/1","doc":"Callback implementation for  Timex.Format.DateTime.Formatter.tokenize/1 .","ref":"Timex.Format.DateTime.Formatters.Strftime.html#tokenize/1"},{"type":"behaviour","title":"Timex.Format.Duration.Formatter","doc":"This module defines the behaviour for custom Time formatters","ref":"Timex.Format.Duration.Formatter.html"},{"type":"function","title":"Timex.Format.Duration.Formatter.format/1","doc":"Formats a Duration as a string, using the provided\nformatter. If a formatter is not provided, the formatter used is\n`Timex.Format.Duration.Formatters.Default`. As a handy shortcut, you can reference\nthe other built-in formatter (Humanized) via the :humanized atom as shown below.\n\n# Examples\n\n    iex> d = Timex.Duration.from_erl({1435, 180354, 590264})\n    ...> Elixir.Timex.Format.Duration.Formatter.format(d)\n    \"P45Y6M5DT21H12M34.590264S\"","ref":"Timex.Format.Duration.Formatter.html#format/1"},{"type":"callback","title":"Timex.Format.Duration.Formatter.format/1","doc":"","ref":"Timex.Format.Duration.Formatter.html#c:format/1"},{"type":"function","title":"Timex.Format.Duration.Formatter.format/2","doc":"Same as format/1, but takes a formatter name as an argument","ref":"Timex.Format.Duration.Formatter.html#format/2"},{"type":"function","title":"Examples - Timex.Format.Duration.Formatter.format/2","doc":"iex> d = Timex.Duration.from_erl({1435, 180354, 590264})\n    ...> Elixir.Timex.Format.Duration.Formatter.format(d, :humanized)\n    \"45 years, 6 months, 5 days, 21 hours, 12 minutes, 34 seconds, 590.264 milliseconds\"","ref":"Timex.Format.Duration.Formatter.html#format/2-examples"},{"type":"function","title":"Timex.Format.Duration.Formatter.lformat/2","doc":"Same as format/1, but takes a locale name as an argument, and translates the format string,\nif the locale has translations.","ref":"Timex.Format.Duration.Formatter.html#lformat/2"},{"type":"callback","title":"Timex.Format.Duration.Formatter.lformat/2","doc":"","ref":"Timex.Format.Duration.Formatter.html#c:lformat/2"},{"type":"function","title":"Timex.Format.Duration.Formatter.lformat/3","doc":"Same as lformat/2, but takes a formatter as an argument","ref":"Timex.Format.Duration.Formatter.html#lformat/3"},{"type":"module","title":"Timex.Format.Duration.Formatters.Default","doc":"Handles formatting Duration values as ISO 8601 durations as described below.\n\nDurations are represented by the format P[n]Y[n]M[n]DT[n]H[n]M[n]S.\nIn this representation, the [n] is replaced by the value for each of the\ndate and time elements that follow the [n]. Leading zeros are not required,\nbut the maximum number of digits for each element should be agreed to by the\ncommunicating parties. The capital letters P, Y, M, W, D, T, H, M, and S are\ndesignators for each of the date and time elements and are not replaced.\n\n- P is the duration designator (historically called \"period\") placed at the start of the duration representation.\n- Y is the year designator that follows the value for the number of years.\n- M is the month designator that follows the value for the number of months.\n- D is the day designator that follows the value for the number of days.\n- T is the time designator that precedes the time components of the representation.\n- H is the hour designator that follows the value for the number of hours.\n- M is the minute designator that follows the value for the number of minutes.\n- S is the second designator that follows the value for the number of seconds.","ref":"Timex.Format.Duration.Formatters.Default.html"},{"type":"function","title":"Timex.Format.Duration.Formatters.Default.format/1","doc":"Return a human readable string representing the absolute value of duration (i.e. would\nreturn the same output for both negative and positive representations of a given duration)","ref":"Timex.Format.Duration.Formatters.Default.html#format/1"},{"type":"function","title":"Examples - Timex.Format.Duration.Formatters.Default.format/1","doc":"iex> use Timex\n    ...> Duration.from_erl({0, 1, 1_000_000}) |> Elixir.Timex.Format.Duration.Formatters.Default.format\n    \"PT2S\"\n\n    iex> use Timex\n    ...> Duration.from_erl({0, 1, 1_000_100}) |> Elixir.Timex.Format.Duration.Formatters.Default.format\n    \"PT2.0001S\"\n\n    iex> use Timex\n    ...> Duration.from_erl({0, 65, 0}) |> Elixir.Timex.Format.Duration.Formatters.Default.format\n    \"PT1M5S\"\n\n    iex> use Timex\n    ...> Duration.from_erl({0, -65, 0}) |> Elixir.Timex.Format.Duration.Formatters.Default.format\n    \"PT1M5S\"\n\n    iex> use Timex\n    ...> Duration.from_erl({1435, 180354, 590264}) |> Elixir.Timex.Format.Duration.Formatters.Default.format\n    \"P45Y6M5DT21H12M34.590264S\"\n\n    iex> use Timex\n    ...> Duration.from_erl({0, 0, 0}) |> Elixir.Timex.Format.Duration.Formatters.Default.format\n    \"PT0S\"","ref":"Timex.Format.Duration.Formatters.Default.html#format/1-examples"},{"type":"function","title":"Timex.Format.Duration.Formatters.Default.lformat/2","doc":"Callback implementation for  Timex.Format.Duration.Formatter.lformat/2 .","ref":"Timex.Format.Duration.Formatters.Default.html#lformat/2"},{"type":"module","title":"Timex.Format.Duration.Formatters.Humanized","doc":"Handles formatting timestamp values as human readable strings.\nFor formatting timestamps as points in time rather than intervals,\nuse `Timex.format`","ref":"Timex.Format.Duration.Formatters.Humanized.html"},{"type":"function","title":"Timex.Format.Duration.Formatters.Humanized.format/1","doc":"Return a human readable string representing the absolute value of duration (i.e. would\nreturn the same output for both negative and positive representations of a given duration)","ref":"Timex.Format.Duration.Formatters.Humanized.html#format/1"},{"type":"function","title":"Examples - Timex.Format.Duration.Formatters.Humanized.format/1","doc":"iex> use Timex\n    ...> Duration.from_erl({0, 1, 1_000_000}) |> Elixir.Timex.Format.Duration.Formatters.Humanized.format\n    \"2 seconds\"\n\n    iex> use Timex\n    ...> Duration.from_erl({0, 1, 1_000_100}) |> Elixir.Timex.Format.Duration.Formatters.Humanized.format\n    \"2 seconds, 100 microseconds\"\n\n    iex> use Timex\n    ...> Duration.from_erl({0, 65, 0}) |> Elixir.Timex.Format.Duration.Formatters.Humanized.format\n    \"1 minute, 5 seconds\"\n\n    iex> use Timex\n    ...> Duration.from_erl({0, -65, 0}) |> Elixir.Timex.Format.Duration.Formatters.Humanized.format\n    \"1 minute, 5 seconds\"\n\n    iex> use Timex\n    ...> Duration.from_erl({1435, 180354, 590264}) |> Elixir.Timex.Format.Duration.Formatters.Humanized.format\n    \"45 years, 6 months, 5 days, 21 hours, 12 minutes, 34 seconds, 590.264 milliseconds\"","ref":"Timex.Format.Duration.Formatters.Humanized.html#format/1-examples"},{"type":"function","title":"Timex.Format.Duration.Formatters.Humanized.lformat/2","doc":"Return a human readable string representing the time interval, translated to the given locale","ref":"Timex.Format.Duration.Formatters.Humanized.html#lformat/2"},{"type":"function","title":"Examples - Timex.Format.Duration.Formatters.Humanized.lformat/2","doc":"iex> use Timex\n    ...> Duration.from_erl({0, 65, 0}) |> Elixir.Timex.Format.Duration.Formatters.Humanized.lformat(\"ru\")\n    \"1 минута, 5 секунд\"\n\n    iex> use Timex\n    ...> Duration.from_erl({1435, 180354, 590264}) |> Elixir.Timex.Format.Duration.Formatters.Humanized.lformat(\"ru\")\n    \"45 лет, 6 месяцев, 5 дней, 21 час, 12 минут, 34 секунды, 590.264 миллисекунд\"","ref":"Timex.Format.Duration.Formatters.Humanized.html#lformat/2-examples"},{"type":"module","title":"Timex.Gettext","doc":"","ref":"Timex.Gettext.html"},{"type":"macro","title":"Timex.Gettext.dgettext/3","doc":"","ref":"Timex.Gettext.html#dgettext/3"},{"type":"macro","title":"Timex.Gettext.dgettext_noop/2","doc":"","ref":"Timex.Gettext.html#dgettext_noop/2"},{"type":"macro","title":"Timex.Gettext.dngettext/5","doc":"","ref":"Timex.Gettext.html#dngettext/5"},{"type":"macro","title":"Timex.Gettext.dngettext_noop/3","doc":"","ref":"Timex.Gettext.html#dngettext_noop/3"},{"type":"macro","title":"Timex.Gettext.dpgettext/4","doc":"","ref":"Timex.Gettext.html#dpgettext/4"},{"type":"macro","title":"Timex.Gettext.dpgettext_noop/3","doc":"","ref":"Timex.Gettext.html#dpgettext_noop/3"},{"type":"macro","title":"Timex.Gettext.dpngettext/6","doc":"","ref":"Timex.Gettext.html#dpngettext/6"},{"type":"macro","title":"Timex.Gettext.dpngettext_noop/4","doc":"","ref":"Timex.Gettext.html#dpngettext_noop/4"},{"type":"macro","title":"Timex.Gettext.gettext/2","doc":"","ref":"Timex.Gettext.html#gettext/2"},{"type":"macro","title":"Timex.Gettext.gettext_comment/1","doc":"","ref":"Timex.Gettext.html#gettext_comment/1"},{"type":"macro","title":"Timex.Gettext.gettext_noop/1","doc":"","ref":"Timex.Gettext.html#gettext_noop/1"},{"type":"function","title":"Timex.Gettext.handle_missing_bindings/2","doc":"Callback implementation for  Gettext.Backend.handle_missing_bindings/2 .","ref":"Timex.Gettext.html#handle_missing_bindings/2"},{"type":"function","title":"Timex.Gettext.handle_missing_plural_translation/7","doc":"Callback implementation for  Gettext.Backend.handle_missing_plural_translation/7 .","ref":"Timex.Gettext.html#handle_missing_plural_translation/7"},{"type":"function","title":"Timex.Gettext.handle_missing_translation/5","doc":"Callback implementation for  Gettext.Backend.handle_missing_translation/5 .","ref":"Timex.Gettext.html#handle_missing_translation/5"},{"type":"macro","title":"Timex.Gettext.ngettext/4","doc":"","ref":"Timex.Gettext.html#ngettext/4"},{"type":"macro","title":"Timex.Gettext.ngettext_noop/2","doc":"","ref":"Timex.Gettext.html#ngettext_noop/2"},{"type":"macro","title":"Timex.Gettext.pgettext/3","doc":"","ref":"Timex.Gettext.html#pgettext/3"},{"type":"macro","title":"Timex.Gettext.pgettext_noop/2","doc":"","ref":"Timex.Gettext.html#pgettext_noop/2"},{"type":"macro","title":"Timex.Gettext.pngettext/5","doc":"","ref":"Timex.Gettext.html#pngettext/5"},{"type":"macro","title":"Timex.Gettext.pngettext_noop/3","doc":"","ref":"Timex.Gettext.html#pngettext_noop/3"},{"type":"module","title":"Timex.Interval","doc":"This module is used for creating and manipulating date/time intervals.","ref":"Timex.Interval.html"},{"type":"module","title":"Examples - Timex.Interval","doc":"iex> use Timex\n    ...> Interval.new(from: ~D[2016-03-03], until: [days: 3])\n    %Elixir.Timex.Interval{from: ~N[2016-03-03 00:00:00], left_open: false, right_open: true, step: [days: 1], until: ~N[2016-03-06 00:00:00]}\n\n    iex> use Timex\n    ...> Interval.new(from: ~D[2016-03-03], until: ~N[2016-03-10 01:23:45])\n    %Timex.Interval{from: ~N[2016-03-03 00:00:00], left_open: false, right_open: true, step: [days: 1], until: ~N[2016-03-10 01:23:45]}\n\n    iex> use Timex\n    ...> ~N[2016-03-04 12:34:56] in Interval.new(from: ~D[2016-03-03], until: [days: 3])\n    true\n\n    iex> use Timex\n    ...> ~D[2016-03-01] in Interval.new(from: ~D[2016-03-03], until: [days: 3])\n    false\n\n    iex> use Timex\n    ...> Interval.overlaps?(Interval.new(from: ~D[2016-03-01], until: [days: 5]),  Interval.new(from: ~D[2016-03-03], until: [days: 3]))\n    true\n\n    iex> use Timex\n    ...> Interval.overlaps?(Interval.new(from: ~D[2016-03-01], until: [days: 1]),  Interval.new(from: ~D[2016-03-03], until: [days: 3]))\n    false","ref":"Timex.Interval.html#module-examples"},{"type":"function","title":"Timex.Interval.contains?/2","doc":"Returns true if the first interval includes every point in time the second includes.","ref":"Timex.Interval.html#contains?/2"},{"type":"function","title":"Examples - Timex.Interval.contains?/2","doc":"iex> Elixir.Timex.Interval.contains?(Elixir.Timex.Interval.new(from: ~D[2018-01-01], until: ~D[2018-01-31]), Elixir.Timex.Interval.new(from: ~D[2018-01-01], until: ~D[2018-01-30]))\n    true\n\n    iex> Elixir.Timex.Interval.contains?(Elixir.Timex.Interval.new(from: ~D[2018-01-01], until: ~D[2018-01-30]), Elixir.Timex.Interval.new(from: ~D[2018-01-01], until: ~D[2018-01-31]))\n    false\n\n    iex> Elixir.Timex.Interval.contains?(Elixir.Timex.Interval.new(from: ~D[2018-01-01], until: ~D[2018-01-10]), Elixir.Timex.Interval.new(from: ~D[2018-01-05], until: ~D[2018-01-15]))\n    false","ref":"Timex.Interval.html#contains?/2-examples"},{"type":"function","title":"Timex.Interval.difference/2","doc":"Removes one interval from another which may reduce, split, or\neliminate the original interval. Returns a (possibly empty) list\nof intervals representing the remaining time.","ref":"Timex.Interval.html#difference/2"},{"type":"function","title":"Graphs - Timex.Interval.difference/2","doc":"The following textual graphs show all the ways that the original interval and\nthe removal can relate to each other, and the action that `difference/2` will\ntake in each case.\nThe original interval is drawn with `O`s and the removal interval with `X`s.\n\n    # return original\n    OO\n        XX\n\n    # trim end\n    OOO\n      XXX\n\n    # trim end\n    OOOOO\n      XXX\n\n    # split\n    OOOOOOO\n      XXX\n\n    # eliminate\n    OO\n    XX\n\n    # eliminate\n    OO\n    XXXX\n\n    # trim beginning\n    OOOO\n    XX\n\n    # eliminate\n      OO\n    XXXXXX\n\n    # eliminate\n        OO\n    XXXXXX\n\n    # trim beginning\n      OOO\n    XXX\n\n    # return original\n         OO\n    XX","ref":"Timex.Interval.html#difference/2-graphs"},{"type":"function","title":"Examples - Timex.Interval.difference/2","doc":"iex> Elixir.Timex.Interval.difference(Elixir.Timex.Interval.new(from: ~N[2018-01-01 02:00:00.000], until: ~N[2018-01-01 04:00:00.000]), Elixir.Timex.Interval.new(from: ~N[2018-01-01 03:00:00.000], until: ~N[2018-01-01 05:00:00.000]))\n    [%Elixir.Timex.Interval{from: ~N[2018-01-01 02:00:00.000], left_open: false, right_open: true, step: [days: 1], until: ~N[2018-01-01 03:00:00.000]}]\n\n    iex> Elixir.Timex.Interval.difference(Elixir.Timex.Interval.new(from: ~N[2018-01-01 01:00:00.000], until: ~N[2018-01-01 05:00:00.000]), Elixir.Timex.Interval.new(from: ~N[2018-01-01 02:00:00.000], until: ~N[2018-01-01 03:00:00.000]))\n    [%Elixir.Timex.Interval{from: ~N[2018-01-01 01:00:00.000], left_open: false, right_open: true, step: [days: 1], until: ~N[2018-01-01 02:00:00.000]}, %Elixir.Timex.Interval{from: ~N[2018-01-01 03:00:00.000], left_open: false, right_open: true, step: [days: 1], until: ~N[2018-01-01 05:00:00.000]}]\n\n    iex> Elixir.Timex.Interval.difference(Elixir.Timex.Interval.new(from: ~N[2018-01-01 02:00:00.000], until: ~N[2018-01-01 04:00:00.000]), Elixir.Timex.Interval.new(from: ~N[2018-01-01 01:00:00.000], until: ~N[2018-01-01 05:00:00.000]))\n    []","ref":"Timex.Interval.html#difference/2-examples"},{"type":"function","title":"Timex.Interval.duration/2","doc":"Return the interval duration, given a unit.\n\nWhen the unit is one of `:seconds`, `:minutes`, `:hours`, `:days`, `:weeks`, `:months`, `:years`, the result is an `integer`.\n\nWhen the unit is `:duration`, the result is a `Duration` struct.","ref":"Timex.Interval.html#duration/2"},{"type":"function","title":"Example - Timex.Interval.duration/2","doc":"iex> use Timex\n    ...> Interval.new(from: ~D[2014-09-22], until: [months: 5])\n    ...> |> Interval.duration(:months)\n    5\n\n    iex> use Timex\n    ...> Interval.new(from: ~N[2014-09-22T15:30:00], until: [minutes: 20])\n    ...> |> Interval.duration(:duration)\n    Duration.from_minutes(20)","ref":"Timex.Interval.html#duration/2-example"},{"type":"function","title":"Timex.Interval.format/3","doc":"Formats the interval as a human readable string.","ref":"Timex.Interval.html#format/3"},{"type":"function","title":"Examples - Timex.Interval.format/3","doc":"iex> use Timex\n    ...> Interval.new(from: ~D[2014-09-22], until: [days: 3])\n    ...> |> Interval.format!(\"%Y-%m-%d %H:%M\", :strftime)\n    \"[2014-09-22 00:00, 2014-09-25 00:00)\"\n\n    iex> use Timex\n    ...> Interval.new(from: ~D[2014-09-22], until: [days: 3])\n    ...> |> Interval.format!(\"%Y-%m-%d\", :strftime)\n    \"[2014-09-22, 2014-09-25)\"","ref":"Timex.Interval.html#format/3-examples"},{"type":"function","title":"Timex.Interval.format!/3","doc":"Same as `format/3`, but raises a `Timex.Interval.FormatError` on failure.","ref":"Timex.Interval.html#format!/3"},{"type":"function","title":"Timex.Interval.new/1","doc":"Create a new Interval struct.\n\n**Note:** By default intervals are left closed, i.e. they include the `from` date/time,\nand exclude the `until` date/time. Put another way, `from <= x < until`. This behavior\nmatches that of other popular date/time libraries, such as Joda Time, as well as the SQL\nbehavior of the `overlaps` keyword.\n\nOptions:\n\n- `from`: The date the interval starts at. Should be a `(Naive)DateTime`.\n- `until`: Either a `(Naive)DateTime`, or a time shift that will be applied to the `from` date.\n  This value _must_ be greater than `from`, otherwise an error will be returned.\n- `left_open`: Whether the interval is left open. See explanation below.\n- `right_open`: Whether the interval is right open. See explanation below.\n- `step`: The step to use when iterating the interval, defaults to `[days: 1]`\n\nThe terms `left_open` and `right_open` come from the mathematical concept of intervals. You\ncan see more detail on the theory [on Wikipedia](https://en.wikipedia.org/wiki/Interval_(mathematics)),\nbut it can be more intuitively thought of like so:\n\n- An \"open\" bound is exclusive, and a \"closed\" bound is inclusive\n- So a left-closed interval includes the `from` value, and a left-open interval does not.\n- Likewise, a right-closed interval includes the `until` value, and a right-open interval does not.\n- An open interval is both left and right open, conversely, a closed interval is both left and right closed.\n\n**Note:** `until` shifts delegate to `Timex.shift`, so the options provided should match its valid options.","ref":"Timex.Interval.html#new/1"},{"type":"function","title":"Examples - Timex.Interval.new/1","doc":"iex> use Timex\n    ...> Interval.new(from: ~D[2014-09-22], until: ~D[2014-09-29])\n    ...> |> Interval.format!(\"%Y-%m-%d\", :strftime)\n    \"[2014-09-22, 2014-09-29)\"\n\n    iex> use Timex\n    ...> Interval.new(from: ~D[2014-09-22], until: [days: 7])\n    ...> |> Interval.format!(\"%Y-%m-%d\", :strftime)\n    \"[2014-09-22, 2014-09-29)\"\n\n    iex> use Timex\n    ...> Interval.new(from: ~D[2014-09-22], until: [days: 7], left_open: true, right_open: false)\n    ...> |> Interval.format!(\"%Y-%m-%d\", :strftime)\n    \"(2014-09-22, 2014-09-29]\"\n\n    iex> use Timex\n    ...> Interval.new(from: ~N[2014-09-22T15:30:00], until: [minutes: 20], right_open: false)\n    ...> |> Interval.format!(\"%H:%M\", :strftime)\n    \"[15:30, 15:50]\"","ref":"Timex.Interval.html#new/1-examples"},{"type":"function","title":"Timex.Interval.overlaps?/2","doc":"Returns true if the first interval shares any point(s) in time with the second.","ref":"Timex.Interval.html#overlaps?/2"},{"type":"function","title":"Examples - Timex.Interval.overlaps?/2","doc":"iex> Elixir.Timex.Interval.overlaps?(Elixir.Timex.Interval.new(from: ~D[2016-03-04], until: [days: 1]), Elixir.Timex.Interval.new(from: ~D[2016-03-03], until: [days: 3]))\n    true\n\n    iex> Elixir.Timex.Interval.overlaps?(Elixir.Timex.Interval.new(from: ~D[2016-03-07], until: [days: 1]), Elixir.Timex.Interval.new(from: ~D[2016-03-03], until: [days: 3]))\n    false","ref":"Timex.Interval.html#overlaps?/2-examples"},{"type":"type","title":"Timex.Interval.t/0","doc":"","ref":"Timex.Interval.html#t:t/0"},{"type":"type","title":"Timex.Interval.valid_interval_step/0","doc":"","ref":"Timex.Interval.html#t:valid_interval_step/0"},{"type":"type","title":"Timex.Interval.valid_interval_steps/0","doc":"","ref":"Timex.Interval.html#t:valid_interval_steps/0"},{"type":"type","title":"Timex.Interval.valid_step_unit/0","doc":"","ref":"Timex.Interval.html#t:valid_step_unit/0"},{"type":"function","title":"Timex.Interval.with_step/2","doc":"Change the step value for the provided interval.\n\nThe step should be a keyword list valid for use with `Timex.Date.shift`.","ref":"Timex.Interval.html#with_step/2"},{"type":"function","title":"Examples - Timex.Interval.with_step/2","doc":"iex> use Timex\n    ...> Interval.new(from: ~D[2014-09-22], until: [days: 3], right_open: true)\n    ...> |> Interval.with_step([days: 1]) |> Enum.map(&Timex.format!(&1, \"%Y-%m-%d\", :strftime))\n    [\"2014-09-22\", \"2014-09-23\", \"2014-09-24\"]\n\n    iex> use Timex\n    ...> Interval.new(from: ~D[2014-09-22], until: [days: 3], right_open: false)\n    ...> |> Interval.with_step([days: 1]) |> Enum.map(&Timex.format!(&1, \"%Y-%m-%d\", :strftime))\n    [\"2014-09-22\", \"2014-09-23\", \"2014-09-24\", \"2014-09-25\"]\n\n    iex> use Timex\n    ...> Interval.new(from: ~D[2014-09-22], until: [days: 3], right_open: false)\n    ...> |> Interval.with_step([days: 2]) |> Enum.map(&Timex.format!(&1, \"%Y-%m-%d\", :strftime))\n    [\"2014-09-22\", \"2014-09-24\"]\n\n    iex> use Timex\n    ...> Interval.new(from: ~D[2014-09-22], until: [days: 3], right_open: false)\n    ...> |> Interval.with_step([days: 3]) |> Enum.map(&Timex.format!(&1, \"%Y-%m-%d\", :strftime))\n    [\"2014-09-22\", \"2014-09-25\"]","ref":"Timex.Interval.html#with_step/2-examples"},{"type":"module","title":"Timex.NaiveDateTime","doc":"","ref":"Timex.NaiveDateTime.html"},{"type":"module","title":"Timex.Parse.DateTime.Parser","doc":"This is the base plugin behavior for all Timex date/time string parsers.","ref":"Timex.Parse.DateTime.Parser.html"},{"type":"function","title":"Timex.Parse.DateTime.Parser.parse/2","doc":"Parses a date/time string using the default parser.","ref":"Timex.Parse.DateTime.Parser.html#parse/2"},{"type":"function","title":"Examples - Timex.Parse.DateTime.Parser.parse/2","doc":"iex> use Timex\n    ...> {:ok, dt} = Elixir.Timex.Parse.DateTime.Parser.parse(\"2014-07-29T00:20:41.196Z\", \"{ISO:Extended:Z}\")\n    ...> dt.year\n    2014\n    iex> dt.month\n    7\n    iex> dt.day\n    29\n    iex> dt.time_zone\n    \"Etc/UTC\"","ref":"Timex.Parse.DateTime.Parser.html#parse/2-examples"},{"type":"function","title":"Timex.Parse.DateTime.Parser.parse/3","doc":"Parses a date/time string using the provided tokenizer. Tokenizers must implement the\n`Timex.Parse.DateTime.Tokenizer` behaviour.","ref":"Timex.Parse.DateTime.Parser.html#parse/3"},{"type":"function","title":"Examples - Timex.Parse.DateTime.Parser.parse/3","doc":"iex> use Timex\n    ...> {:ok, dt} = Elixir.Timex.Parse.DateTime.Parser.parse(\"2014-07-29T00:30:41.196-02:00\", \"{ISO:Extended}\", Timex.Parse.DateTime.Tokenizers.Default)\n    ...> dt.year\n    2014\n    iex> dt.month\n    7\n    iex> dt.day\n    29\n    iex> dt.time_zone\n    \"Etc/UTC-2\"","ref":"Timex.Parse.DateTime.Parser.html#parse/3-examples"},{"type":"function","title":"Timex.Parse.DateTime.Parser.parse!/3","doc":"Same as `parse/2` and `parse/3`, but raises on error.","ref":"Timex.Parse.DateTime.Parser.html#parse!/3"},{"type":"module","title":"Timex.Parse.DateTime.Parsers.ISO8601Extended","doc":"","ref":"Timex.Parse.DateTime.Parsers.ISO8601Extended.html"},{"type":"function","title":"Timex.Parse.DateTime.Parsers.ISO8601Extended.parse/1","doc":"","ref":"Timex.Parse.DateTime.Parsers.ISO8601Extended.html#parse/1"},{"type":"function","title":"Timex.Parse.DateTime.Parsers.ISO8601Extended.parse_extended/1","doc":"","ref":"Timex.Parse.DateTime.Parsers.ISO8601Extended.html#parse_extended/1"},{"type":"function","title":"Timex.Parse.DateTime.Parsers.ISO8601Extended.parse_extended/4","doc":"","ref":"Timex.Parse.DateTime.Parsers.ISO8601Extended.html#parse_extended/4"},{"type":"function","title":"Timex.Parse.DateTime.Parsers.ISO8601Extended.parse_fractional_seconds/3","doc":"","ref":"Timex.Parse.DateTime.Parsers.ISO8601Extended.html#parse_fractional_seconds/3"},{"type":"function","title":"Timex.Parse.DateTime.Parsers.ISO8601Extended.parse_offset/3","doc":"","ref":"Timex.Parse.DateTime.Parsers.ISO8601Extended.html#parse_offset/3"},{"type":"function","title":"Timex.Parse.DateTime.Parsers.ISO8601Extended.parse_offset/4","doc":"","ref":"Timex.Parse.DateTime.Parsers.ISO8601Extended.html#parse_offset/4"},{"type":"type","title":"Timex.Parse.DateTime.Parsers.ISO8601Extended.parser/0","doc":"","ref":"Timex.Parse.DateTime.Parsers.ISO8601Extended.html#t:parser/0"},{"type":"type","title":"Timex.Parse.DateTime.Parsers.ISO8601Extended.previous_parser/0","doc":"","ref":"Timex.Parse.DateTime.Parsers.ISO8601Extended.html#t:previous_parser/0"},{"type":"behaviour","title":"Timex.Parse.DateTime.Tokenizer","doc":"Defines the API for a custom tokenizer which can extend Timex's datetime parsing facilities.","ref":"Timex.Parse.DateTime.Tokenizer.html"},{"type":"callback","title":"Timex.Parse.DateTime.Tokenizer.apply/3","doc":"","ref":"Timex.Parse.DateTime.Tokenizer.html#c:apply/3"},{"type":"callback","title":"Timex.Parse.DateTime.Tokenizer.tokenize/1","doc":"","ref":"Timex.Parse.DateTime.Tokenizer.html#c:tokenize/1"},{"type":"module","title":"Timex.Parse.DateTime.Tokenizers.Default","doc":"Implements the parser for the default DateTime format strings.","ref":"Timex.Parse.DateTime.Tokenizers.Default.html"},{"type":"function","title":"Timex.Parse.DateTime.Tokenizers.Default.apply/3","doc":"Applies a given token + value to the DateTime represented by the current input string.","ref":"Timex.Parse.DateTime.Tokenizers.Default.html#apply/3"},{"type":"function","title":"Timex.Parse.DateTime.Tokenizers.Default.tokenize/1","doc":"Tokenizes the given format string and returns an error or a list of directives.","ref":"Timex.Parse.DateTime.Tokenizers.Default.html#tokenize/1"},{"type":"module","title":"Timex.Parse.DateTime.Tokenizers.Strftime","doc":"Implements the parser for strftime-style datetime format strings.","ref":"Timex.Parse.DateTime.Tokenizers.Strftime.html"},{"type":"function","title":"Timex.Parse.DateTime.Tokenizers.Strftime.apply/3","doc":"Applies a given token + value to the DateTime represented by the current input string.","ref":"Timex.Parse.DateTime.Tokenizers.Strftime.html#apply/3"},{"type":"function","title":"Timex.Parse.DateTime.Tokenizers.Strftime.tokenize/1","doc":"Tokenizes the given format string and returns an error or a list of directives.","ref":"Timex.Parse.DateTime.Tokenizers.Strftime.html#tokenize/1"},{"type":"behaviour","title":"Timex.Parse.Duration.Parser","doc":"This module is responsible for parsing input strings into Duration structs.\nThe actual parsing is delegated to specific parser modules, but this module\nprovides a unified API for all of them.","ref":"Timex.Parse.Duration.Parser.html"},{"type":"function","title":"Timex.Parse.Duration.Parser.parse/1","doc":"Parses the given input using the ISO-8601 duration parser,\nand returns either an :ok, or :error tuple.","ref":"Timex.Parse.Duration.Parser.html#parse/1"},{"type":"callback","title":"Timex.Parse.Duration.Parser.parse/1","doc":"","ref":"Timex.Parse.Duration.Parser.html#c:parse/1"},{"type":"function","title":"Timex.Parse.Duration.Parser.parse/2","doc":"Parses the given input using the provided parser module,\nand returns either an :ok, or :error tuple.","ref":"Timex.Parse.Duration.Parser.html#parse/2"},{"type":"function","title":"Timex.Parse.Duration.Parser.parse!/1","doc":"Parses the given input using the ISO-8601 duration parser,\nand either returns a Duration, or raises an error.","ref":"Timex.Parse.Duration.Parser.html#parse!/1"},{"type":"function","title":"Timex.Parse.Duration.Parser.parse!/2","doc":"Parses the given input using the provided parser module,\nand either returns a Duration, or raises an error.","ref":"Timex.Parse.Duration.Parser.html#parse!/2"},{"type":"module","title":"Timex.Parse.Duration.Parsers.ISO8601Parser","doc":"This module parses ISO-8601 duration strings into Duration structs.","ref":"Timex.Parse.Duration.Parsers.ISO8601Parser.html"},{"type":"function","title":"Timex.Parse.Duration.Parsers.ISO8601Parser.parse/1","doc":"Parses an ISO-8601 formatted duration string into a Duration struct.\nThe parse result is wrapped in a :ok/:error tuple.","ref":"Timex.Parse.Duration.Parsers.ISO8601Parser.html#parse/1"},{"type":"function","title":"Examples - Timex.Parse.Duration.Parsers.ISO8601Parser.parse/1","doc":"iex> {:ok, d} = Elixir.Timex.Parse.Duration.Parsers.ISO8601Parser.parse(\"P15Y3M2DT1H14M37.25S\")\n    ...> Timex.Format.Duration.Formatter.format(d)\n    \"P15Y3M2DT1H14M37.25S\"\n\n    iex> {:ok, d} = Elixir.Timex.Parse.Duration.Parsers.ISO8601Parser.parse(\"P15Y3M2D\")\n    ...> Timex.Format.Duration.Formatter.format(d)\n    \"P15Y3M2D\"\n\n    iex> {:ok, d} = Elixir.Timex.Parse.Duration.Parsers.ISO8601Parser.parse(\"PT3H12M25.001S\")\n    ...> Timex.Format.Duration.Formatter.format(d)\n    \"PT3H12M25.001S\"\n\n    iex> {:ok, d} = Elixir.Timex.Parse.Duration.Parsers.ISO8601Parser.parse(\"P2W\")\n    ...> Timex.Format.Duration.Formatter.format(d)\n    \"P14D\"\n\n    iex> Elixir.Timex.Parse.Duration.Parsers.ISO8601Parser.parse(\"P15YT3D\")\n    {:error, \"invalid use of date component after time separator\"}","ref":"Timex.Parse.Duration.Parsers.ISO8601Parser.html#parse/1-examples"},{"type":"module","title":"Timex.Parse.Timezones.Posix","doc":"Parses POSIX-style timezones:","ref":"Timex.Parse.Timezones.Posix.html"},{"type":"module","title":"Format - Timex.Parse.Timezones.Posix","doc":"POSIX-style timezones are of the format: `stdoffset[dst[offset][,start[/time],end[/time]]]`\n\nWhere `std`/`dst` are dates in one of the following formats:\n\nThe `Mm.n.d` format, where:\n\n- `Mm` (1-12) for 12 months\n- `n` (1-5) 1 for the first week and 5 for the last week in the month\n- `d` (0-6) 0 for Sunday and 6 for Saturday\n\nThe `Jn` format, where `n` is the julian day and leap days are excluded.\n\nOr the `n` format, where `n` is the julian day, and leap days are included.\n\nOffsets are optional, except for the `std` offset, and can be preceded by a sign. The offset indicates\nthe time added to the local time to obtain UTC time. The offsets may be hours; hours and minutes;\nand hours, minutes, and seconds - colon separated between components. NOTE: The sign of the offset is\nopposite the usual expectation, positive numbers are west of GMT, and negative numbers are east of GMT,\nthis is because the offset is the time added to _local_ time to arrive at UTC, rather than the other way\naround.\n\nFor more info, see: https://pubs.opengroup.org/onlinepubs/9699919799/","ref":"Timex.Parse.Timezones.Posix.html#module-format"},{"type":"module","title":"Example - Timex.Parse.Timezones.Posix","doc":"TZ = `CST6CDT,M3.2.0/2:00:00,M11.1.0/2:00:00`\n\nThis would represents a change to daylight saving time at 2:00 AM on the second Sunday\nin March and change back at 2:00 AM on the first Sunday in November, and keep 6 hours time\noffset from GMT every year. The breakdown of the string is:\n\n- `CST6CDT` is the timezone name (constructed by concatenating the abbreviation and offset of std/dst)\n- `CST` is the standard abbreviation\n- `6` is the offset from `CST` to get `UTC`\n- `CDT` is the DST abbreviation\n- There is no offset from `CDT`, so the standard assumes the offset is one hour ahead of `CST`, or `5`\n- `,M3` is the third month\n- `.2` is second week of the month\n- `.0` is the day of the week (Sunday in this case)\n- `/2:00:00` is the time at which `CST` changes to `CDT`; defaults to `2:00:00` if not specified\n- `,M11` is the eleventh month\n- `.1` is the first week of the month\n- `.0` is the day of the week\n- `/2:00:00` is the time at which `CDT` changes back to `CST`; defaults to `2:00:00` if not specified","ref":"Timex.Parse.Timezones.Posix.html#module-example"},{"type":"function","title":"Timex.Parse.Timezones.Posix.parse/1","doc":"","ref":"Timex.Parse.Timezones.Posix.html#parse/1"},{"type":"module","title":"Timex.Parse.ZoneInfo.Parser","doc":"This module is responsible for parsing binary zoneinfo files,\nsuch as those found in /usr/local/zoneinfo.","ref":"Timex.Parse.ZoneInfo.Parser.html"},{"type":"function","title":"Timex.Parse.ZoneInfo.Parser.parse/1","doc":"Parses a binary representing a valid zoneinfo file.\n\nParses the timezone information inside, and returns it as a Zone struct.","ref":"Timex.Parse.ZoneInfo.Parser.html#parse/1"},{"type":"function","title":"Timex.Parse.ZoneInfo.Parser.parse_file/1","doc":"Like `parse/1`, but expects a file path to parse.","ref":"Timex.Parse.ZoneInfo.Parser.html#parse_file/1"},{"type":"module","title":"Timex.Parse.ZoneInfo.Parser.Zone","doc":"Represents the data retrieved from a binary tzfile.","ref":"Timex.Parse.ZoneInfo.Parser.Zone.html"},{"type":"module","title":"Timex.PosixTimezone","doc":"Used when parsing POSIX-TZ timezone rules.","ref":"Timex.PosixTimezone.html"},{"type":"function","title":"Timex.PosixTimezone.dst_end/2","doc":"Obtains a `NaiveDateTime` representing the end of DST for this zone.\n\nReturns nil if there is no DST period.","ref":"Timex.PosixTimezone.html#dst_end/2"},{"type":"function","title":"Timex.PosixTimezone.dst_start/2","doc":"Obtains a `NaiveDateTime` representing the start of DST for this zone.\n\nReturns nil if there is no DST period.","ref":"Timex.PosixTimezone.html#dst_start/2"},{"type":"function","title":"Timex.PosixTimezone.is_dst?/2","doc":"Returns a boolean indicating if the datetime provided occurs during DST of the given POSIX timezone.","ref":"Timex.PosixTimezone.html#is_dst?/2"},{"type":"type","title":"Timex.PosixTimezone.rule_bound/0","doc":"","ref":"Timex.PosixTimezone.html#t:rule_bound/0"},{"type":"type","title":"Timex.PosixTimezone.t/0","doc":"","ref":"Timex.PosixTimezone.html#t:t/0"},{"type":"function","title":"Timex.PosixTimezone.to_period_for_date/2","doc":"Returns a `Calendar.TimeZoneDatabase` compatible map, representing this timezone for the given datetime","ref":"Timex.PosixTimezone.html#to_period_for_date/2"},{"type":"function","title":"Timex.PosixTimezone.to_timezone_info/2","doc":"Returns a `TimezoneInfo` struct representing this timezone for the given datetime","ref":"Timex.PosixTimezone.html#to_timezone_info/2"},{"type":"protocol","title":"Timex.Protocol","doc":"This protocol defines the API for functions which take a `Date`,\n`NaiveDateTime`, or `DateTime` as input.","ref":"Timex.Protocol.html"},{"type":"function","title":"Timex.Protocol.beginning_of_day/1","doc":"Get a new version of the date/time value representing the beginning of the day","ref":"Timex.Protocol.html#beginning_of_day/1"},{"type":"function","title":"Timex.Protocol.beginning_of_month/1","doc":"Get a new version of the date/time value representing the beginning of it's month","ref":"Timex.Protocol.html#beginning_of_month/1"},{"type":"function","title":"Timex.Protocol.beginning_of_quarter/1","doc":"Get a new version of the date/time value representing the beginning of it's quarter","ref":"Timex.Protocol.html#beginning_of_quarter/1"},{"type":"function","title":"Timex.Protocol.beginning_of_week/2","doc":"Get a new version of the date/time value representing the beginning of it's week,\nproviding a weekday name (as an atom) for the day which starts the week, i.e. `:mon`.","ref":"Timex.Protocol.html#beginning_of_week/2"},{"type":"function","title":"Timex.Protocol.beginning_of_year/1","doc":"Get a new version of the date/time value representing the beginning of it's year","ref":"Timex.Protocol.html#beginning_of_year/1"},{"type":"function","title":"Timex.Protocol.century/1","doc":"Get the century a date/time value is in","ref":"Timex.Protocol.html#century/1"},{"type":"function","title":"Timex.Protocol.day/1","doc":"Get the ordinal day number of the given date/time value","ref":"Timex.Protocol.html#day/1"},{"type":"function","title":"Timex.Protocol.days_in_month/1","doc":"Get the number of days in the month for the given date/time value","ref":"Timex.Protocol.html#days_in_month/1"},{"type":"function","title":"Timex.Protocol.end_of_day/1","doc":"Get a new version of the date/time value representing the end of the day","ref":"Timex.Protocol.html#end_of_day/1"},{"type":"function","title":"Timex.Protocol.end_of_month/1","doc":"Get a new version of the date/time value representing the ending of it's month","ref":"Timex.Protocol.html#end_of_month/1"},{"type":"function","title":"Timex.Protocol.end_of_quarter/1","doc":"Get a new version of the date/time value representing the ending of it's quarter","ref":"Timex.Protocol.html#end_of_quarter/1"},{"type":"function","title":"Timex.Protocol.end_of_week/2","doc":"Get a new version of the date/time value representing the ending of it's week,\nproviding a weekday name (as an atom) for the day which starts the week, i.e. `:mon`.","ref":"Timex.Protocol.html#end_of_week/2"},{"type":"function","title":"Timex.Protocol.end_of_year/1","doc":"Get a new version of the date/time value representing the ending of it's year","ref":"Timex.Protocol.html#end_of_year/1"},{"type":"function","title":"Timex.Protocol.from_iso_day/2","doc":"Shifts the given date/time value to the ISO day given","ref":"Timex.Protocol.html#from_iso_day/2"},{"type":"function","title":"Timex.Protocol.is_leap?/1","doc":"Return a boolean indicating whether the date/time value is in a leap year","ref":"Timex.Protocol.html#is_leap?/1"},{"type":"function","title":"Timex.Protocol.is_valid?/1","doc":"Determine if the provided date/time value is valid.","ref":"Timex.Protocol.html#is_valid?/1"},{"type":"function","title":"Timex.Protocol.iso_week/1","doc":"Return a pair {year, week number} (as defined by ISO 8601) that the given date/time value falls on.","ref":"Timex.Protocol.html#iso_week/1"},{"type":"function","title":"Timex.Protocol.quarter/1","doc":"Get the quarter for the given date/time value","ref":"Timex.Protocol.html#quarter/1"},{"type":"function","title":"Timex.Protocol.set/2","doc":"Set fields on a date/time value using a list of unit/value pairs","ref":"Timex.Protocol.html#set/2"},{"type":"function","title":"Timex.Protocol.shift/2","doc":"Shift a date/time value using a list of shift unit/value pairs","ref":"Timex.Protocol.html#shift/2"},{"type":"type","title":"Timex.Protocol.t/0","doc":"All the types that implement this protocol.","ref":"Timex.Protocol.html#t:t/0"},{"type":"function","title":"Timex.Protocol.to_date/1","doc":"Convert a date/time value to a Date","ref":"Timex.Protocol.html#to_date/1"},{"type":"function","title":"Timex.Protocol.to_datetime/2","doc":"Convert a date/time value to a DateTime.\nAn optional timezone can be provided, UTC will be assumed if one is not provided.","ref":"Timex.Protocol.html#to_datetime/2"},{"type":"function","title":"Timex.Protocol.to_erl/1","doc":"Convert a date/time value to it's Erlang tuple variant\ni.e. Date becomes `{y,m,d}`, DateTime/NaiveDateTime become\n`{{y,m,d},{h,mm,s}}`","ref":"Timex.Protocol.html#to_erl/1"},{"type":"function","title":"Timex.Protocol.to_gregorian_microseconds/1","doc":"Convert a date/time value to gregorian microseconds (microseconds since the start of year zero)","ref":"Timex.Protocol.html#to_gregorian_microseconds/1"},{"type":"function","title":"Timex.Protocol.to_gregorian_seconds/1","doc":"Convert a date/time value to gregorian seconds (seconds since start of year zero)","ref":"Timex.Protocol.html#to_gregorian_seconds/1"},{"type":"function","title":"Timex.Protocol.to_julian/1","doc":"Convert a date/time value to a Julian calendar date number","ref":"Timex.Protocol.html#to_julian/1"},{"type":"function","title":"Timex.Protocol.to_naive_datetime/1","doc":"Convert a date/time value to a NaiveDateTime","ref":"Timex.Protocol.html#to_naive_datetime/1"},{"type":"function","title":"Timex.Protocol.to_unix/1","doc":"Convert a date/time value to seconds since the UNIX Epoch","ref":"Timex.Protocol.html#to_unix/1"},{"type":"function","title":"Timex.Protocol.week_of_month/1","doc":"Get the week number of the given date/time value, starting at 1","ref":"Timex.Protocol.html#week_of_month/1"},{"type":"function","title":"Timex.Protocol.weekday/1","doc":"Get the ordinal weekday number of the given date/time value","ref":"Timex.Protocol.html#weekday/1"},{"type":"function","title":"Timex.Protocol.weekday/2","doc":"Get the ordinal weekday number of the given date/time value and relative to the given weekstart","ref":"Timex.Protocol.html#weekday/2"},{"type":"module","title":"Timex.Time","doc":"This module provides helper functions for working with Times","ref":"Timex.Time.html"},{"type":"function","title":"Timex.Time.to_12hour_clock/1","doc":"Converts an hour between 0..24 to {1..12, :am/:pm}","ref":"Timex.Time.html#to_12hour_clock/1"},{"type":"function","title":"Examples - Timex.Time.to_12hour_clock/1","doc":"iex> Timex.Time.to_12hour_clock(23)\n    {11, :pm}","ref":"Timex.Time.html#to_12hour_clock/1-examples"},{"type":"function","title":"Timex.Time.to_24hour_clock/2","doc":"Converts an hour between 1..12 in either am or pm, to value between 0..24","ref":"Timex.Time.html#to_24hour_clock/2"},{"type":"function","title":"Examples - Timex.Time.to_24hour_clock/2","doc":"iex> Timex.Time.to_24hour_clock(7, :pm)\n    19","ref":"Timex.Time.html#to_24hour_clock/2-examples"},{"type":"module","title":"Timex.Timezone","doc":"This module is used for looking up the timezone information for\na given point in time, in the desired zone. Timezones are dependent\nnot only on locale, but the date and time for which you are querying.\nFor instance, the timezone offset from UTC for `Europe/Moscow` is different\nfor March 3rd of 2015, than it was in 2013. These differences are important,\nand as such, all functions in this module are date/time sensitive, and where\nomitted, the current date/time are assumed.\n\nIn addition to lookups, this module also does conversion of datetimes from one\ntimezone period to another, and determining the difference between a date in one\ntimezone period and the same date/time in another timezone period.","ref":"Timex.Timezone.html"},{"type":"function","title":"Timex.Timezone.beginning_of_day/1","doc":"Shifts the provided DateTime to the beginning of the day in it's timezone","ref":"Timex.Timezone.html#beginning_of_day/1"},{"type":"function","title":"Timex.Timezone.convert/2","doc":"Convert a date to the given timezone (either TimezoneInfo or a timezone name)","ref":"Timex.Timezone.html#convert/2"},{"type":"function","title":"Timex.Timezone.end_of_day/1","doc":"Shifts the provided DateTime to the end of the day in it's timezone","ref":"Timex.Timezone.html#end_of_day/1"},{"type":"function","title":"Timex.Timezone.exists?/1","doc":"Determines if a given zone name exists","ref":"Timex.Timezone.html#exists?/1"},{"type":"function","title":"Timex.Timezone.get/2","doc":"Gets timezone info for a given zone name and date. The date provided\ncan either be an Erlang datetime tuple, or a DateTime struct, and if one\nis not provided, then the current date and time is returned.","ref":"Timex.Timezone.html#get/2"},{"type":"function","title":"Timex.Timezone.get/3","doc":"Same as `get/2`, but allows specifying whether to obtain the TimezoneInfo based\non utc time or wall time manually (`:utc` or `:wall` respectively).","ref":"Timex.Timezone.html#get/3"},{"type":"function","title":"Timex.Timezone.local/0","doc":"Gets the local timezone configuration for the current date and time.","ref":"Timex.Timezone.html#local/0"},{"type":"function","title":"Timex.Timezone.local/1","doc":"Gets the local timezone configuration for the provided date and time.\nThe provided date and time can either be an Erlang datetime tuple, or a DateTime struct.","ref":"Timex.Timezone.html#local/1"},{"type":"function","title":"Timex.Timezone.name_of/1","doc":"This function takes one of the varying timezone representations:\n\n  - atoms\n  - offset integers\n  - shortcut names (i.e. :utc, :local, \"Z\", \"A\")\n\nand resolves the full name of the timezone if it's able.\n\nIf a string is provided which isn't recognized, it is returned untouched,\nonly when `get/2` is called will the timezone lookup fail.","ref":"Timex.Timezone.html#name_of/1"},{"type":"function","title":"Timex.Timezone.resolve/3","doc":"Given a timezone name as a string, and a date/time in the form of the number of seconds since year zero,\nattempt to resolve a TimezoneInfo for that date/time. If the time is ambiguous, AmbiguousTimezoneInfo will\nbe returned. If no result is found, an error will be returned.\n\nIf an invalid zone name is provided, an error will be returned","ref":"Timex.Timezone.html#resolve/3"},{"type":"function","title":"Timex.Timezone.total_offset/1","doc":"","ref":"Timex.Timezone.html#total_offset/1"},{"type":"function","title":"Timex.Timezone.total_offset/2","doc":"","ref":"Timex.Timezone.html#total_offset/2"},{"type":"function","title":"Timex.Timezone.tzdata_to_timezone/2","doc":"","ref":"Timex.Timezone.html#tzdata_to_timezone/2"},{"type":"module","title":"Timex.Timezone.Database","doc":"","ref":"Timex.Timezone.Database.html"},{"type":"module","title":"Timex.Timezone.Local","doc":"This module is responsible for determining the timezone configuration of the\nlocal machine. It determines this from a number of sources, depending on platform,\nbut the order of precedence is as follows:\n\nALL:\n- TZ environment variable. Ignored if nil/empty\n\nOSX:\n- /etc/localtime\n- systemsetup -gettimezone (if admin rights are present)\n\nUNIX:\n- /etc/timezone\n- /etc/sysconfig/clock\n- /etc/conf.d/clock\n- /etc/localtime\n- /usr/local/etc/localtime\n\nWindows:\n- SYSTEM registry for the currently configured TimeZoneInformation\n\nEach location is tried, and if an error is encountered, the next is attempted,\nuntil either a successful lookup is performed, or we run out of locations to check.","ref":"Timex.Timezone.Local.html"},{"type":"type","title":"Timex.Timezone.Local.gregorian_seconds/0","doc":"","ref":"Timex.Timezone.Local.html#t:gregorian_seconds/0"},{"type":"function","title":"Timex.Timezone.Local.lookup/0","doc":"Looks up the local timezone configuration. Returns the name of a timezone\nin the Olson database.\n\nIf no reference time is provided (in gregorian seconds), the current time in UTC will be used.\nIf one is provided, the reference time will be used to find the local timezone for that reference time,\nif it exists.","ref":"Timex.Timezone.Local.html#lookup/0"},{"type":"function","title":"Timex.Timezone.Local.parse_tzfile/1","doc":"Given a binary representing the data from a tzfile (not the source version),\nparses out the timezone for the current date/time in UTC.","ref":"Timex.Timezone.Local.html#parse_tzfile/1"},{"type":"module","title":"Timex.TimezoneInfo","doc":"All relevant timezone information for a given period, i.e. Europe/Moscow on March 3rd, 2013\n\nNotes:\n  - `full_name` is the name of the zone, but does not indicate anything about the current period (i.e. CST vs CDT)\n  - `abbreviation` is the abbreviated name for the zone in the current period, i.e. \"America/Chicago\" on 3/30/15 is \"CDT\"\n  - `offset_std` is the offset in seconds from standard time for this period\n  - `offset_utc` is the offset in seconds from UTC for this period\n\nSpec:\n  - `day_of_week`: :sunday, :monday, :tuesday, etc\n  - `datetime`:    {{year, month, day}, {hour, minute, second}}\n  - `from`:      :min | {day_of_week, datetime}, when this zone starts\n  - `until`:     :max | {day_of_week, datetime}, when this zone ends","ref":"Timex.TimezoneInfo.html"},{"type":"function","title":"Timex.TimezoneInfo.create/6","doc":"Create a custom timezone if a built-in one does not meet your needs.\n\nYou must provide the name, abbreviation, offset from UTC, daylight savings time offset,\nand the from/until reference points for when the zone takes effect and ends.\n\nTo clarify the two offsets, `offset_utc` is the absolute offset relative to UTC,\n`offset_std` is the offset to apply to `offset_utc` which gives us the offset from UTC\nduring daylight savings time for this timezone. If DST does not apply for this zone, simply\nset it to 0.\n\nThe `from`/`until` reference points must meet the following criteria:\n\n- Be set to `:min` for `from`, or `:max` for `until`, which represents\n  \"infinity\" for the start/end of the zone period\n- OR, be a tuple of `{day_of_week, datetime}`, where:\n  - `day_of_week` is an atom like `:sunday`\n  - `datetime` is an Erlang datetime tuple, e.g. `{{2016,10,8},{2,0,0}}`\n\n**IMPORTANT**: Offsets are in seconds, not minutes. If you do not ensure they\nare in the correct unit, runtime errors or incorrect results are probable.","ref":"Timex.TimezoneInfo.html#create/6"},{"type":"function","title":"Examples - Timex.TimezoneInfo.create/6","doc":"iex> Elixir.Timex.TimezoneInfo.create(\"Etc/Test\", \"TST\", 120*60, 0, :min, :max)\n    %TimezoneInfo{full_name: \"Etc/Test\", abbreviation: \"TST\", offset_std: 7200, offset_utc: 0, from: :min, until: :max}\n    ...> Elixir.Timex.TimezoneInfo.create(\"Etc/Test\", \"TST\", 24*60*60, 0, :min, :max)\n    {:error, \"invalid timezone offset '86400'\"}","ref":"Timex.TimezoneInfo.html#create/6-examples"},{"type":"type","title":"Timex.TimezoneInfo.datetime/0","doc":"","ref":"Timex.TimezoneInfo.html#t:datetime/0"},{"type":"type","title":"Timex.TimezoneInfo.day_of_week/0","doc":"","ref":"Timex.TimezoneInfo.html#t:day_of_week/0"},{"type":"function","title":"Timex.TimezoneInfo.format_offset/1","doc":"Formats the offset of a `Timex.TimezoneInfo` struct.","ref":"Timex.TimezoneInfo.html#format_offset/1"},{"type":"function","title":"Examples - Timex.TimezoneInfo.format_offset/1","doc":"iex> tzinfo = Timex.Timezone.get(\"Etc/Greenwich\", ~U[2022-01-01 00:00:00Z])\n    ...> Elixir.Timex.TimezoneInfo.format_offset(tzinfo)\n    \"+00:00:00\"\n\n    iex> tzinfo = Timex.Timezone.get(\"Africa/Nairobi\", ~U[2022-01-01 00:00:00Z])\n    ...> Elixir.Timex.TimezoneInfo.format_offset(tzinfo)\n    \"+03:00:00\"\n\n    iex> tzinfo = Timex.Timezone.get(\"America/New_York\", ~U[2022-01-01 00:00:00Z])\n    ...> Elixir.Timex.TimezoneInfo.format_offset(tzinfo)\n    \"-05:00:00\"","ref":"Timex.TimezoneInfo.html#format_offset/1-examples"},{"type":"type","title":"Timex.TimezoneInfo.from_constraint/0","doc":"","ref":"Timex.TimezoneInfo.html#t:from_constraint/0"},{"type":"function","title":"Timex.TimezoneInfo.from_datetime/1","doc":"","ref":"Timex.TimezoneInfo.html#from_datetime/1"},{"type":"type","title":"Timex.TimezoneInfo.offset/0","doc":"","ref":"Timex.TimezoneInfo.html#t:offset/0"},{"type":"type","title":"Timex.TimezoneInfo.t/0","doc":"","ref":"Timex.TimezoneInfo.html#t:t/0"},{"type":"type","title":"Timex.TimezoneInfo.until_constraint/0","doc":"","ref":"Timex.TimezoneInfo.html#t:until_constraint/0"},{"type":"module","title":"Timex.Translator","doc":"","ref":"Timex.Translator.html"},{"type":"function","title":"Timex.Translator.current_locale/0","doc":"Returns the active locale for the process in which this function is called","ref":"Timex.Translator.html#current_locale/0"},{"type":"function","title":"Timex.Translator.get_day_periods/1","doc":"Returns a map of day period types to translated day period names","ref":"Timex.Translator.html#get_day_periods/1"},{"type":"function","title":"Examples - Timex.Translator.get_day_periods/1","doc":"iex> day_periods = Timex.Translator.get_day_periods(\"en\")\n    ...> {day_periods[:am], day_periods[:AM]}\n    {\"am\", \"AM\"}","ref":"Timex.Translator.html#get_day_periods/1-examples"},{"type":"function","title":"Timex.Translator.get_months/1","doc":"Returns a map of ordinal months to month names","ref":"Timex.Translator.html#get_months/1"},{"type":"function","title":"Timex.Translator.get_months_abbreviated/1","doc":"Returns a map of ordinal months to month abbreviations","ref":"Timex.Translator.html#get_months_abbreviated/1"},{"type":"function","title":"Timex.Translator.get_weekdays/1","doc":"Returns a map of ordinal weekdays to weekday names, where Monday = 1,\ntranslated in the given locale","ref":"Timex.Translator.html#get_weekdays/1"},{"type":"function","title":"Timex.Translator.get_weekdays_abbreviated/1","doc":"Returns a map of ordinal weekdays to weekday abbreviations, where Mon = 1","ref":"Timex.Translator.html#get_weekdays_abbreviated/1"},{"type":"function","title":"Timex.Translator.translate/3","doc":"Translates a string for a given locale and domain.","ref":"Timex.Translator.html#translate/3"},{"type":"function","title":"Examples - Timex.Translator.translate/3","doc":"iex> Timex.Translator.translate(\"ru\", \"weekdays\", \"Saturday\")\n    \"суббота\"\n\n    iex> Timex.Translator.translate(\"it\", \"weekdays\", \"Saturday\")\n    \"Sabato\"\n\n    iex> Timex.Translator.translate(\"invalid_locale\", \"weekdays\", \"Saturday\")\n    \"Saturday\"","ref":"Timex.Translator.html#translate/3-examples"},{"type":"function","title":"Timex.Translator.translate_plural/5","doc":"Translates a string for a given locale and domain, following the pluralization rules of that\nlanguage.","ref":"Timex.Translator.html#translate_plural/5"},{"type":"function","title":"Examples - Timex.Translator.translate_plural/5","doc":"iex> Timex.Translator.translate_plural(\"ru\", \"relative_time\", \"in %{count} second\", \"in %{count} seconds\", 5)\n    \"через 5 секунд\"\n\n    iex> Timex.Translator.translate_plural(\"it\", \"relative_time\", \"in %{count} second\", \"in %{count} seconds\", 5)\n    \"in 5 secondi\"\n\n    iex> Timex.Translator.translate_plural(\"invalid_locale\", \"relative_time\", \"in %{count} second\", \"in %{count} seconds\", 5)\n    \"in 5 seconds\"","ref":"Timex.Translator.html#translate_plural/5-examples"},{"type":"macro","title":"Timex.Translator.with_locale/2","doc":"","ref":"Timex.Translator.html#with_locale/2"},{"type":"module","title":"Timex.Types","doc":"","ref":"Timex.Types.html"},{"type":"type","title":"Timex.Types.calendar_types/0","doc":"","ref":"Timex.Types.html#t:calendar_types/0"},{"type":"type","title":"Timex.Types.date/0","doc":"","ref":"Timex.Types.html#t:date/0"},{"type":"type","title":"Timex.Types.datetime/0","doc":"","ref":"Timex.Types.html#t:datetime/0"},{"type":"type","title":"Timex.Types.day/0","doc":"","ref":"Timex.Types.html#t:day/0"},{"type":"type","title":"Timex.Types.daynum/0","doc":"","ref":"Timex.Types.html#t:daynum/0"},{"type":"type","title":"Timex.Types.hour/0","doc":"","ref":"Timex.Types.html#t:hour/0"},{"type":"type","title":"Timex.Types.iso_triplet/0","doc":"","ref":"Timex.Types.html#t:iso_triplet/0"},{"type":"type","title":"Timex.Types.megaseconds/0","doc":"","ref":"Timex.Types.html#t:megaseconds/0"},{"type":"type","title":"Timex.Types.microsecond/0","doc":"","ref":"Timex.Types.html#t:microsecond/0"},{"type":"type","title":"Timex.Types.microsecond_datetime/0","doc":"","ref":"Timex.Types.html#t:microsecond_datetime/0"},{"type":"type","title":"Timex.Types.microsecond_time/0","doc":"","ref":"Timex.Types.html#t:microsecond_time/0"},{"type":"type","title":"Timex.Types.microseconds/0","doc":"","ref":"Timex.Types.html#t:microseconds/0"},{"type":"type","title":"Timex.Types.minute/0","doc":"","ref":"Timex.Types.html#t:minute/0"},{"type":"type","title":"Timex.Types.month/0","doc":"","ref":"Timex.Types.html#t:month/0"},{"type":"type","title":"Timex.Types.num_of_days/0","doc":"","ref":"Timex.Types.html#t:num_of_days/0"},{"type":"type","title":"Timex.Types.second/0","doc":"","ref":"Timex.Types.html#t:second/0"},{"type":"type","title":"Timex.Types.seconds/0","doc":"","ref":"Timex.Types.html#t:seconds/0"},{"type":"type","title":"Timex.Types.shift_units/0","doc":"","ref":"Timex.Types.html#t:shift_units/0"},{"type":"type","title":"Timex.Types.std_offset/0","doc":"","ref":"Timex.Types.html#t:std_offset/0"},{"type":"type","title":"Timex.Types.time/0","doc":"","ref":"Timex.Types.html#t:time/0"},{"type":"type","title":"Timex.Types.time_units/0","doc":"","ref":"Timex.Types.html#t:time_units/0"},{"type":"type","title":"Timex.Types.time_zone/0","doc":"","ref":"Timex.Types.html#t:time_zone/0"},{"type":"type","title":"Timex.Types.timestamp/0","doc":"","ref":"Timex.Types.html#t:timestamp/0"},{"type":"type","title":"Timex.Types.tz_offset/0","doc":"","ref":"Timex.Types.html#t:tz_offset/0"},{"type":"type","title":"Timex.Types.utc_offset/0","doc":"","ref":"Timex.Types.html#t:utc_offset/0"},{"type":"type","title":"Timex.Types.valid_date/0","doc":"","ref":"Timex.Types.html#t:valid_date/0"},{"type":"type","title":"Timex.Types.valid_datetime/0","doc":"","ref":"Timex.Types.html#t:valid_datetime/0"},{"type":"type","title":"Timex.Types.valid_time/0","doc":"","ref":"Timex.Types.html#t:valid_time/0"},{"type":"type","title":"Timex.Types.valid_timezone/0","doc":"","ref":"Timex.Types.html#t:valid_timezone/0"},{"type":"type","title":"Timex.Types.week_of_month/0","doc":"","ref":"Timex.Types.html#t:week_of_month/0"},{"type":"type","title":"Timex.Types.weekday/0","doc":"","ref":"Timex.Types.html#t:weekday/0"},{"type":"type","title":"Timex.Types.weekday_name/0","doc":"","ref":"Timex.Types.html#t:weekday_name/0"},{"type":"type","title":"Timex.Types.weeknum/0","doc":"","ref":"Timex.Types.html#t:weeknum/0"},{"type":"type","title":"Timex.Types.weekstart/0","doc":"","ref":"Timex.Types.html#t:weekstart/0"},{"type":"type","title":"Timex.Types.year/0","doc":"","ref":"Timex.Types.html#t:year/0"},{"type":"type","title":"Timex.Types.zone_abbr/0","doc":"","ref":"Timex.Types.html#t:zone_abbr/0"},{"type":"exception","title":"Timex.Format.FormatError","doc":"Used for errors encountered during string formatting.","ref":"Timex.Format.FormatError.html"},{"type":"exception","title":"Timex.Interval.FormatError","doc":"Thrown when an error occurs with formatting an Interval","ref":"Timex.Interval.FormatError.html"},{"type":"exception","title":"Timex.Parse.ParseError","doc":"Used for errors encountered during parsing.","ref":"Timex.Parse.ParseError.html"},{"type":"extras","title":"Getting Started","doc":"# Getting Started\n\n**Learn how to add timex to your Elixir project and start using it.**\n\nIf you are looking for a general reference of what functions are available to you, take a\nlook at the `Timex`, `Timex.Interval`, `Timex.Duration` modules, as they cover\nthe vast majority of functionality you will care about.","ref":"getting-started.html"},{"type":"extras","title":"Project Setup - Getting Started","doc":"To use Timex with your projects, edit your `mix.exs` file and add it as a dependency, as well as add `:timex` to your applications list.\n\n```elixir\ndefp deps do\n  [{:timex, \"~> 3.0\"}]\nend\n```\n\nTo use Timex modules without the Timex namespace, add `use Timex` to the top of each module you plan on referencing Timex from. You can then reference the modules directly, for example: `Duration.now`, versus `Timex.Duration.now`. You can also alias individual modules if that suits your needs better, but for purposes of this documentation, we'll assume that you're going the `use Timex` route.","ref":"getting-started.html#project-setup"},{"type":"extras","title":"What Is Timex - Getting Started","doc":"Timex aims to be the richest, most comprehensive date/time library for Elixir projects, with the ultimate goal of being merged into the standard library, if such functionality is ever considered for inclusion.\n\nA rough list of current features:\n\n- create datetimes in an arbitrary timezone\n- create datetimes from Erlang dates or datetimes\n- get dates/datetimes representing special points in time:\n  - end/beginning of year\n  - end/beginning of quarter\n  - end/beginning of month\n  - end/beginning of week\n  - end/beginning of day\n- convert to/from dates/datetimes in various units (seconds, minutes, hours, etc.) since year zero or UNIX epoch\n- convert to/from dates/datetimes in various standard ISO forms:\n  - ISO triplets\n  - ISO day\n  - ISO week\n- convert to/from dates/datetimes in various formats:\n  - gregorian\n  - gregorian_seconds\n  - Erlang dates or datetimes\n  - UNIX timestamps\n- shift datetimes across timezones\n- shift dates/datetimes through time using various units\n- format/parse datetime strings\n- compare and diff dates/datetimes\n- normalize dates/datetimes\n- create intervals between points in time which can be enumerated\n- create timestamps and convert them to other time units\n- compare and diff timestamps and various time units\n- measure execution time of a function\n- add and subtract time or datetimes\n- and more..","ref":"getting-started.html#what-is-timex"},{"type":"extras","title":"Change Log","doc":"# Change Log\n\nAll notable changes to this project will be documented in this file (at least to the extent possible, I am not infallible sadly).\nThis project adheres to [Semantic Versioning](http://semver.org/).","ref":"changelog.html"},{"type":"extras","title":"Unreleased - Change Log","doc":"","ref":"changelog.html#unreleased"},{"type":"extras","title":"Added/Changed - Change Log","doc":"- Changed `Timex.Duration.Parse` to be 2x faster\n- Fixed compilation warning from gettext\n- Added `cycled` option for `Timex.between?/4` to support time-range checks that pass through midnight\n- Add Croatian translation\n- Changed charlists from the deprecated `''` to `~c\"\"`\n- Changed negative range to pass the step of default value for suppressing deprecation warnings","ref":"changelog.html#added-changed"},{"type":"extras","title":"Fixed - Change Log","doc":"- Updated `Timex.now/1` typespec to remove the `AmbiguousDateTime`\n- Corrected pluralization rules for bg/cs/he/id/ro/ru\n- Fixed documentation formatting of `Timex.TimezoneInfo.create/6`\n- Updated tzdata to fix issues with 2024b\n\n---","ref":"changelog.html#fixed"},{"type":"extras","title":"3.7.8 - Change Log","doc":"","ref":"changelog.html#3-7-8"},{"type":"extras","title":"Added/Changed - Change Log","doc":"- Add Thai translations\n- Add Estonian translation\n- Added `TimezoneInfo.format_offset/1`","ref":"changelog.html#added-changed-1"},{"type":"extras","title":"Fixed - Change Log","doc":"- Fix incorrect `Timex.weekday/2` typespecs\n- Added timezone field to set_options type\n- Corrected type definition for Types.week_of_month to include possiblity of 6th week (see #703)\n- Added specs to parse function to account for AmbiguousDateTime return type\n\n---","ref":"changelog.html#fixed-1"},{"type":"extras","title":"3.7.6 - Change Log","doc":"","ref":"changelog.html#3-7-6"},{"type":"extras","title":"Changed - Change Log","doc":"- The documentation on weekday formatting via `%w` and `%u` strftime directives and `WDmon` and `WDsun`\ndefault directives did not match, and worse, the behaviour had regressed as well and did not match the\ndocs for either. The behaviour now matches between the two formatters, as does the documentation, and\naligns with the C strftime specification (i.e. Monday is 1..7, Sunday is 0..6)","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Change Log","doc":"- Clarify docs on comparison granularity for days/weeks\n- Fix incorrect weekday formatting (see #668)\n- Handled edge case where no locally-defined timezone is present (see #670)\n- Invalid validation of ambiguous date/times during parsing (see #674)\n\n---","ref":"changelog.html#fixed-2"},{"type":"extras","title":"3.7.5 - Change Log","doc":"","ref":"changelog.html#3-7-5"},{"type":"extras","title":"Added/Changed - Change Log","doc":"- Added `Timex.Timezone.get/3` to allow requesting timezones using utc or wall clock as desired","ref":"changelog.html#added-changed-2"},{"type":"extras","title":"Fixed - Change Log","doc":"- Addressed issues #652, #658, #659, #656, #654, #653","ref":"changelog.html#fixed-3"},{"type":"extras","title":"3.7.4 - Change Log","doc":"","ref":"changelog.html#3-7-4"},{"type":"extras","title":"Fixed - Change Log","doc":"- Addressed issues #647, #648, #649, #650","ref":"changelog.html#fixed-4"},{"type":"extras","title":"3.7.3 - Change Log","doc":"**NOTE:** The config of the Timex default locale is changed to:\n```ex\nconfig :your_app, Timex.Gettext, default_locale: \"en\"\n```\nThis follows the standard set by Gettext, see: [the Gettext docs](https://hexdocs.pm/gettext/Gettext.html#module-default-locale)\n\nNow when the Gettext locale is being changed on runtime with:\n```ex\nGettext.put_locale(\"nl\")\n```\nThe Gettext backend for Timex will follow suit. If for some reason you want Timex, and just Timex, to change its locale to something else you should target the Timex.Gettext backend with:\n```ex\nTimex.Gettext.put_locale(\"de\")\n```","ref":"changelog.html#3-7-3"},{"type":"extras","title":"Potentially Breaking - Change Log","doc":"- Fixed handling of `Etc/GMT` vs `GMT` timezones. The former must be POSIX compatible, which inverts the meaning of the sign, whereas the latter have no such restriction and are equivalent to `UTC(+/-)HH:MM`,\nwhile this is fixing incorrect behavior, it could potentially break users relying on the incorrect behavior.","ref":"changelog.html#potentially-breaking"},{"type":"extras","title":"Fixed - Change Log","doc":"- #494, incorrect handling of parsing week numbers\n- Improve parsing of timezones\n- Incorrect stringification of error values returned in some circumstances\n- Let Timex follow the locale set by the global Gettext. See #501","ref":"changelog.html#fixed-5"},{"type":"extras","title":"Added/Changed - Change Log","doc":"- Removed `Timex.Timezone.diff`, as it is no longer used in Timex\n- Added support for obtaining the Julian day of year via `Calendar.Julian.date_for_day_of_year/3`","ref":"changelog.html#added-changed-3"},{"type":"extras","title":"Fixed - Change Log","doc":"","ref":"changelog.html#fixed-6"},{"type":"extras","title":"3.7.1 - Change Log","doc":"","ref":"changelog.html#3-7-1"},{"type":"extras","title":"Fixed - Change Log","doc":"- `local/0` and `local/1` were incorrectly returning TimezoneInfo structs due to a bad match","ref":"changelog.html#fixed-7"},{"type":"extras","title":"3.7.0 - Change Log","doc":"","ref":"changelog.html#3-7-0"},{"type":"extras","title":"Potentially Breaking - Change Log","doc":"- Elixir 1.8+ is now required\n- Tzdata 1.0+ is now required\n- If you were previously relying on `?` suffixed functions to return\n`{:error, reason}` if given invalid date/time inputs (other than\n`is_valid?`), these functions now always return booleans and raise if an\nerror with the input is encountered","ref":"changelog.html#potentially-breaking-1"},{"type":"extras","title":"Added/Changed - Change Log","doc":"- Refactored much of the library to delegate to the Calendar API where\nappropriate, we now make more of an effort to avoid duplication of the\nstandard library functionality\n- Functions with the `?` suffix now correctly raise on invalid inputs,\nand always return booleans. This was implicitly broken before, we need\nto follow convention here.\n- Local timezone handling no longer requires parsing the zoneinfo files,\ninstead we attempt to observe the timezone name that is active and feed\nthat into the timezone database directly. We were just using the\nabbreviations before, but that wasn't correct behavior at all. In the\nfuture we may want to support the system timezone database as a proper\nimplementation of `Calendar.TimeZoneDatabase`, but for now we've just\nremoved the unnecessary parsing work that was going on here.\n- `Timex.today/1` which returns today's date in the provided timezone","ref":"changelog.html#added-changed-4"},{"type":"extras","title":"Fixed - Change Log","doc":"- Handling of timezones across DST. More generally we now handle gaps/ambiguity\nmuch more consistently\n- ZoneInfo parser was refactored, now properly supports version 2/3\nfiles, addresses some small bugs in previous code\n- Some incorrect/redundant typespecs were removed/fixed\n- We now support alternative timezone databases for API operations that\ndo not need to interact with the `Timex.Timezone` module directly. That\nmodule is still tied to tzdata for now, but in the future may be\nmodified to remove the direct dependency.","ref":"changelog.html#fixed-8"},{"type":"extras","title":"3.6.4 - Change Log","doc":"","ref":"changelog.html#3-6-4"},{"type":"extras","title":"Potentially Breaking - Change Log","doc":"- `Timex.set/2` now sets microseconds when setting `:time` from a `%Time{}` struct\n- `Timex.Duration.to_string/1` now returns `PT0S` instead of `P` for zero-length durations with the default formatter","ref":"changelog.html#potentially-breaking-2"},{"type":"extras","title":"Added - Change Log","doc":"- `Timex.set/2` now also accepts setting the `:date` from a `%Date{}` and `:time` from a `%Time{}` struct for NaiveDateTime","ref":"changelog.html#added"},{"type":"extras","title":"Fixes - Change Log","doc":"- Loosen `tzdata` dependency to allow `1.x` releases","ref":"changelog.html#fixes"},{"type":"extras","title":"3.6.3 - Change Log","doc":"","ref":"changelog.html#3-6-3"},{"type":"extras","title":"Added - Change Log","doc":"- Switched to GitHub Actions for CI\n- Finnish translations\n- Enumerable implementation for Timex.Interval","ref":"changelog.html#added-1"},{"type":"extras","title":"Fixed - Change Log","doc":"- Czech translation fixes\n- #616\n- #615","ref":"changelog.html#fixed-9"},{"type":"extras","title":"3.6.2 - Change Log","doc":"","ref":"changelog.html#3-6-2"},{"type":"extras","title":"Added - Change Log","doc":"- Updated tzdata to 1.0.1\n- Vietnamese/Czech/Hebrew/Bosnian translations\n- Formatter settings, and ran the formatter on the codebase","ref":"changelog.html#added-2"},{"type":"extras","title":"Fixed - Change Log","doc":"- Romanian translation fixes\n- Various documentation/typespec fixes\n- Parser for ISOweek\n- #559\n- #577","ref":"changelog.html#fixed-10"},{"type":"extras","title":"3.6.1 - Change Log","doc":"","ref":"changelog.html#3-6-1"},{"type":"extras","title":"Potentially Breaking - Change Log","doc":"- Require Elixir v1.6+","ref":"changelog.html#potentially-breaking-3"},{"type":"extras","title":"Added - Change Log","doc":"- Setup property based test framework and add sample tests (#480)\n- Turkish translation (#534)\n- Add details to parsing documentation (#540)\n- Support time units in singular (#509)\n- #538 documentation of default formatting directives\n- Support for tzdata 1.0.0 (#536)","ref":"changelog.html#added-3"},{"type":"extras","title":"Fixed - Change Log","doc":"- Address handling of ambiguity in timezone conversions by using UTC clock time, where possible. See #488\n- #491 gracefully handle errors resolving a timezone using wall clock time\n- #514 gracefully handle converting date to datetime on tz boundary\n- #531 address some issues with shifting over timezone boundaries\n- #507 unnecessary tz conversion during logical shifts results in erroneous results\n- #532 shift priority incorrectly inverted\n- #537 precision not preserved in some situations\n- Elixir 1.8 deprecations\n- `Timex.diff/2` spec\n- `Timex.Timezone.convert/2` when using custom time zones\n- Letter encoding on PT translation\n- Swedish translation id for March","ref":"changelog.html#fixed-11"},{"type":"extras","title":"3.5.0 - Change Log","doc":"","ref":"changelog.html#3-5-0"},{"type":"extras","title":"Added - Change Log","doc":"- `Timex.set/2` now also accepts setting the `:date` from a `%Date{}` struct.\n- `Interval.difference/2` removes one interval from another","ref":"changelog.html#added-4"},{"type":"extras","title":"3.4.1 - Change Log","doc":"","ref":"changelog.html#3-4-1"},{"type":"extras","title":"Added - Change Log","doc":"- Afrikaans translations (Julian Dicks)\n- The :inclusive option for Timex.between?/4 :start and :end in addition to true","ref":"changelog.html#added-5"},{"type":"extras","title":"Fixed - Change Log","doc":"- strftime_iso_kitchen no longer discards dates","ref":"changelog.html#fixed-12"},{"type":"extras","title":"3.4.0 - Change Log","doc":"**NOTE:** There are breaking changes in this release. This is not going to result in a major\nversion bump, as the old behavior did not match the docs, and was incorrect to boot. In other words, the\nbreaking changes only affect you if you relied on the incorrect behavior, if you were expecting the\ndocumented behavior, then these are _not_ breaking changes.","ref":"changelog.html#3-4-0"},{"type":"extras","title":"Added - Change Log","doc":"- Interval.contains?/2 to test if one interval contains another","ref":"changelog.html#added-6"},{"type":"extras","title":"Fixed - Change Log","doc":"- Interval overlap was being improperly calculated\n- Interval behavior with respect to open/closed bounds was incorrect (open bounds were being treated as closed and vice versa)\n- Intervals could be created with invalid from/until (i.e. creating an interval with an until before the from)\n- Interval documentation improvements for clarity","ref":"changelog.html#fixed-13"},{"type":"extras","title":"3.1.13 - Change Log","doc":"","ref":"changelog.html#3-1-13"},{"type":"extras","title":"Added - Change Log","doc":"- Romanian translations (Cezar Halmagean)","ref":"changelog.html#added-7"},{"type":"extras","title":"Fixed - Change Log","doc":"- #280 - formatting of non-ISO week numbers","ref":"changelog.html#fixed-14"},{"type":"extras","title":"3.1.6-12 - Change Log","doc":"Sorry I didn't keep this up to date, please review the commits in git for these versions.","ref":"changelog.html#3-1-6-12"},{"type":"extras","title":"3.1.6 - Change Log","doc":"","ref":"changelog.html#3-1-6"},{"type":"extras","title":"Added - Change Log","doc":"- Translations for zh_CN (Chinese)\n- Translations for pl (Polish)\n- #244 - Support for fractional offsets","ref":"changelog.html#added-8"},{"type":"extras","title":"Fixed - Change Log","doc":"- Various documentation fixes\n- Fix #262 - Day of week calculation in Julian calendar - Mark Meeus\n- Fix #260 - Duration formatting edge case - Slava Kisel\n- Fix #257 - Fix from_iso_triplet logic - Mathew Bramson\n- Fix #252 - Formatting/parsing of fractional seconds was not round-trippable\n- Fix #248 - Make fractional second formatting consistent with standard library\n- Add application callback so we can provide better errors if :tzdata isn't started\n- Enable fallback_to_any in Timex.Protocol","ref":"changelog.html#fixed-15"},{"type":"extras","title":"3.1.5 - Change Log","doc":"","ref":"changelog.html#3-1-5"},{"type":"extras","title":"Fixed - Change Log","doc":"- Fix #218 - Bug with `Timex.from_iso_triplet`\n- Zone abbreviations produced by parsing did not always match those in tzdata","ref":"changelog.html#fixed-16"},{"type":"extras","title":"3.1 - Change Log","doc":"","ref":"changelog.html#3-1"},{"type":"extras","title":"Fixed - Change Log","doc":"- Fix #214 - Permit any valid datetime type in formatting API\n- Fix #215 - Properly validate 2-digit years","ref":"changelog.html#fixed-17"},{"type":"extras","title":"3.0.8 - Change Log","doc":"","ref":"changelog.html#3-0-8"},{"type":"extras","title":"Changed - Change Log","doc":"- Duration.scale/2 now works with float coefficients","ref":"changelog.html#changed-1"},{"type":"extras","title":"3.0.7 - Change Log","doc":"","ref":"changelog.html#3-0-7"},{"type":"extras","title":"Added - Change Log","doc":"- Implementation of Timex.Protocol for Map. This is primarily useful (and intended)\n  for dealing with deserialized date/time structs.","ref":"changelog.html#added-9"},{"type":"extras","title":"Fixed - Change Log","doc":"- Precision calculation for microseconds was sometimes incorrect.","ref":"changelog.html#fixed-18"},{"type":"extras","title":"3.0.6 - Change Log","doc":"","ref":"changelog.html#3-0-6"},{"type":"extras","title":"Added - Change Log","doc":"- Added parsing for ISO-8601 durations to the Duration API","ref":"changelog.html#added-10"},{"type":"extras","title":"Fixed - Change Log","doc":"- #206 - Bug in shifting DateTimes","ref":"changelog.html#fixed-19"},{"type":"extras","title":"3.0.5 - Change Log","doc":"","ref":"changelog.html#3-0-5"},{"type":"extras","title":"Fixed - Change Log","doc":"- #199 - Handling of timezone names with `-` was broken.","ref":"changelog.html#fixed-20"},{"type":"extras","title":"3.0.3 - Change Log","doc":"","ref":"changelog.html#3-0-3"},{"type":"extras","title":"Added - Change Log","doc":"- Add Duration.to_time/1, to_time!/1, from_time/1 for conversions to/from Time","ref":"changelog.html#added-11"},{"type":"extras","title":"3.0.2 - Change Log","doc":"","ref":"changelog.html#3-0-2"},{"type":"extras","title":"Fixed - Change Log","doc":"- Converting a NaiveDateTime with to_datetime did not include microseconds\n- now/0, now/1, local/0 were not microsecond precise","ref":"changelog.html#fixed-21"},{"type":"extras","title":"3.0.1 - Change Log","doc":"","ref":"changelog.html#3-0-1"},{"type":"extras","title":"Added - Change Log","doc":"- `Duration.to_clock/1` - convert a Duration to a `{hour,min,sec,usec}` tuple\n- `Duration.from_clock/1` - convert a `{hour,min,sec,usec}` tuple to a Duration","ref":"changelog.html#added-12"},{"type":"extras","title":"3.0.0 - Change Log","doc":"**IMPORTANT**: This release is a significant rewrite of Timex's internals as well as API. Many things have remained unchanged,\nbut there are many things that have as well. Mostly the removal of prior deprecations, and the removal (without deprecation) of\nthings incompatible with, or now redundant due to, the introduction of calendar types in Elixir 1.3 and their impact on Timex.\nThe list of these changes will be comprehensively spelled out below, along with recommendations for alternatives in the cases\nof removals.","ref":"changelog.html#3-0-0"},{"type":"extras","title":"Fixed - Change Log","doc":"- [#185](https://github.com/bitwalker/timex/issues/185)\n- [#137](https://github.com/bitwalker/timex/issues/137)","ref":"changelog.html#fixed-22"},{"type":"extras","title":"Added - Change Log","doc":"- `Timex.Protocol` (defines the API all calendar types must implement to be used with Timex)\n- `compare/3`, `diff/3` `shift/2`, now allow the use of `:milliseconds` and `:microseconds`\n- `set/2` now allow the use of `:microsecond`\n- `Timex.Duration`\n- `to_gregorian_microseconds/1`, converts a date/time value to microseconds since year zero","ref":"changelog.html#added-13"},{"type":"extras","title":"Changed - Change Log","doc":"- Timex's old Date/DateTime types are replaced by Elixir 1.3's new calendar types,\n  NaiveDateTime is now used where appropriate, and AmbiguousDateTime remains in order to\n  handle timezone ambiguities.\n- `Timex.diff/3` now returns to it's old behaviour of returning a signed integer for values, so\n  that diffing/comparing can be done on a single value.\n- Renamed `Timex.Time` to `Timex.Duration` to better reflect it's purpose and prevent conflicts with\n  Elixir's built-in `Time` type.\n- Renamed `Timex.Format.Time.*` to `Timex.Format.Duration.*`\n- Renamed `:timestamp` options to `:duration`\n- Renamed `*_timestamp` functions to `*_duration`\n- Changed `Timex.Duration` to operate on and return `Duration` structs rather than Erlang timestamp tuples\n- Changed `Duration.from/2`, to `Duration.from_*/1`, moving the unit into the name.\n- Renamed `to_erlang_datetime` to `to_erl`","ref":"changelog.html#changed-2"},{"type":"extras","title":"Removed - Change Log","doc":"- Timex.Date (use `Timex` now)\n- Timex.DateTime (use `Timex` now)\n- Timex.Convertable (no longer makes sense in the face of differentiating NaiveDateTime/DateTime)\n- `set/2` no longer allow the use of `:millisecond`\n- Removed `Timex.date`\n- Deprecated `Timex.datetime`\n- Removed `from_timestamp` functions\n- Removed `to_gregorian`\n- Removed `to_seconds/2` in favor of `to_gregorian_seconds/1` and `to_unix/1`\n- Removed `normalize/1`, it no longer is necessary. `normalize/2` still exists however","ref":"changelog.html#removed"},{"type":"extras","title":"2.1.3 - Change Log","doc":"","ref":"changelog.html#2-1-3"},{"type":"extras","title":"Fixed - Change Log","doc":"- Some behaviour around shifting across DST boundaries was behaving incorrectly (#142)","ref":"changelog.html#fixed-23"},{"type":"extras","title":"2.1.2 - Change Log","doc":"This release adds the base for locale-awareness in Timex, including one locale (\"ru\"), support for formatting datetimes\nin another locale, and functions which return names of things will now use the default locale. To configure Timex's default\nlocale, put the following in config.exs:\n\n```elixir\nconfig :timex, default_locale: \"ru\" # or whatever locale you want\n```","ref":"changelog.html#2-1-2"},{"type":"extras","title":"Added - Change Log","doc":"- The ability to configure a default locale (the default is \"en\" if no config is provided) for formatting/translation of strings\n- The ability to format a string using a given locale, otherwise the default locale is used\n- Translations for the \"ru\" locale, more to come\n- Locale awareness throughout the core API, so functions such as `day_name` will return the day name in the configured locale,\n  if translations for that locale were provided\n- `Timex.lformat`, and `Timex.lformat!` variants of the formatting functions, which take a locale to use in formatting\n- Added a relative time formatter, which functions very similarly to Moment.js's relative time formatting\n  You can use it with `Timex.format!` or `Timex.format`, by providing :relative as the formatter, and using the `{relative}` token in your\n  format string. NOTE: The relative formatter does not support other tokens, only `{relative}` for now, if it seems like there\n  is a use case where `{relative}` should support other tokens, I'll consider adding that.\n- Added `Timex.from_now`, which takes:\n  - A single Convertable, which returns the relative time between that date/time value and now\n  - Two Convertables, which returns the relative time between the first date/time value, and the reference date (provided as the 2nd)\n  - Two variants of the above which also take a locale as the last argument, and results in the string being translated to that locale\n- Added ASN.1 parsing/formatting support","ref":"changelog.html#added-14"},{"type":"extras","title":"Changed - Change Log","doc":"- All functions which return strings, and all formatting functions, will use the default locale for translation, which is \"en\" unless another was configured, or one was provided if the function takes a locale as an argument.","ref":"changelog.html#changed-3"},{"type":"extras","title":"Fixed - Change Log","doc":"- Milliseconds should be able to be fractional - the is_millisecond guard was only allowing integers","ref":"changelog.html#fixed-24"},{"type":"extras","title":"2.1.1 - Change Log","doc":"","ref":"changelog.html#2-1-1"},{"type":"extras","title":"Added - Change Log","doc":"- Implementations of the Inspect protocol for Date, DateTime, AmbiguousDateTime, TimezoneInfo, and AmbiguousTimezoneInfo","ref":"changelog.html#added-15"},{"type":"extras","title":"Changed - Change Log","doc":"- When inspecting any Timex types, the compact view will be used, pass structs: false to view the raw data structures if needed.","ref":"changelog.html#changed-4"},{"type":"extras","title":"2.1.0 - Change Log","doc":"","ref":"changelog.html#2-1-0"},{"type":"extras","title":"Added - Change Log","doc":"- Two new protocols, `Timex.Comparable` and `Timex.Convertable`, implementing these two for your own date/time types\n  will allow you to use the Timex API with your own types, just be aware that only Dates, DateTimes, or AmbiguousDateTimes\n  will be returned as date/time representations, but it should be trivial to add a function in your implementation to\n  convert back.\n- Basic Julian calendar implementation, which allows you to get the Julian date for a given Convertable, see\n  `Timex.to_julian/1`, you can also get the day of the week number for a Julian date, via `Timex.Calendar.Julian`\n- `to_julian` function to the `Timex.Convertable` protocol\n- `Timex.timezones` to get a list of all valid timezones","ref":"changelog.html#added-16"},{"type":"extras","title":"Changed - Change Log","doc":"- **POTENTIALLY BREAKING** The `{Zname}` format token was formatting with the abbreviation, which is incorrect. It\n  has been changed to format with the full name, use `{Zabbr}` if you want the abbreviation.\n- Moved comparison and diffing behaviour into a new protocol, `Timex.Comparable`, which allows you to now\n  provide your own implementations for comparing other date or datetime types against Timex ones. This\n  makes the API more flexible, and also cleaned up the code quite a bit.\n- Modified Timex API to accept Comparables for just about all functions\n- Added implementations of `Timex.Comparable` for `Tuple`, `Date`, `DateTime`, `AmbiguousDateTime`\n- Added implementations of `Timex.Convertable` for `Map` and `Atom`. The former will accept any map with either\n  DateTime-like keys (i.e. year/month/day/hour/minute/etc.) as strings or atoms, or any Date-like keys (year/month/day),\n  as strings or atoms. The latter will accept only two atoms which represent Dates/DateTimes right now, :epoch, and :zero.\n- Modified `Timex.Comparable` to take any `Timex.Convertable`","ref":"changelog.html#changed-5"},{"type":"extras","title":"Fixed - Change Log","doc":"- A number of performance enhancements due to refactoring for `Convertable` and `Comparable`, particularly with diffing\n- The `%Z` strftime format token was formatting timezones as abbreviations, which is not round-trippable due to timezone\n  ambiguity. This token now formats using the full timezone name, which is valid according to the strftime standard.\n- The `{Zname}` token had the same problem as above, and has been fixed to use the full name","ref":"changelog.html#fixed-25"},{"type":"extras","title":"2.0.0 - Change Log","doc":"**READ THIS**: This release contains breaking changes from the previous API. The changes are easy to make,\nand the compiler will catch almost all of them. See the Migrating section of the README for details on migrating\nto 2.0","ref":"changelog.html#2-0-0"},{"type":"extras","title":"Added - Change Log","doc":"- New `Date` type, which is basically the same as `DateTime`, but without time/timezone, which works with\n  most all API functions that work with DateTimes, except those which are specific to time or timezones.\n  Functions which take a Date or DateTime and options which can manipulate both date and time properties,\n  like `set` or `shift` will work as you'd expect with Date values and time-based properties (setting a time\n  property will change nothing, shifting will work for values which represent at least a day, sub-day values will not\n  change the Date).\n- New `AmbiguousDateTime` type which is returned instead of `DateTime` when the datetime in question falls in\n  an ambiguously defined timezone period. This type contains two fields, `:before` and `:after` which contain\n  the `DateTime` values to choose from. This handles cases where previously an error would likely have been thrown,\n  or the behaviour would've been undefined.\n- Timex.date and Timex.datetime, which are the equivalent of the old Date.from, except produce a Date or DateTime respectively.\n  The `from` API still exists in the Date and DateTime modules, and is present in the Timex API for easier migration, but will\n  be deprecated in the future.\n- New `from_erl`, `from_timestamp`, `from_microseconds`, `from_milliseconds`, `from_seconds`, `from_days` functions to\n  replace the old `from` API, and to match the `Time` API more closely.\n- to_date/to_datetime/to_unix/to_timestamp/to_gregorian_seconds conversions in Timex.Convertable (old Timex.Date.Convert protocol)\n- before?/after?/between? functions to Timex module\n- format/format!/format_time/format_time!/parse/parse! API to Timex module\n- week_of_month/1 and /3 to get the week index of the month a date occurs in\n- `Timex.diff(this, other, :calendar_weeks)` - get the diff between two dates in terms of weeks on the calendar,\n  in other words, the diff is done based on the start of the earliest date's week, and the end of the latest date's week","ref":"changelog.html#added-17"},{"type":"extras","title":"Changed - Change Log","doc":"- **BREAKING** All non-bang functions in the API now return error tuples of the form `{:error, term}` instead of raising exceptions\n- **BREAKING** All DateTime-related APIs can now return an `AmbiguousDateTime`, which must be handled by choosing which DateTime to use.\n- **BREAKING** All Timezone lookups can now return an `AmbiguousTimezoneInfo` struct, which must be handled by choosing which TimezoneInfo to use.\n- **BREAKING** DateTime.ms is now DateTime.millisecond\n- **BREAKING** Date module API has moved to Timex module\n- Date and DateTime modules now contain their respective implementations of the Timex API, all shared functions\n  have moved to the Timex module. You can work with Date or DateTimes either through the Timex API, or through the\n  API exposed in the Date and DateTime modules. It is recommended to use Timex though.\n- **BREAKING** Renamed Timex.Date.Convert to Timex.Convertable\n- **BREAKING** `diff/3` now returns the same value no matter which order the arguments are given. Use `compare/3` to get the ordering","ref":"changelog.html#changed-6"},{"type":"extras","title":"Deprecated - Change Log","doc":"- `Timex.from` (old `Date.from`) variants. Use `Timex.date`, `Timex.datetime`, `Date.from_ `, or `DateTime.from_ ` instead.\n- `DateTime.from`. Use `Timex.datetime`, `DateTime.from_erl`, `DateTime.from_ `\n- `to_usecs`, `to_msecs`, `to_secs`, and `to_mins` in favor of `to_microseconds`, `to_milliseconds`, `to_seconds`, and `to_minutes`\n- Abbreviated unit names like `secs` or `mins`, `sec` or `min`, in favor of their full names (i.e. `seconds`, `minutes`, etc.)","ref":"changelog.html#deprecated"},{"type":"extras","title":"Removed - Change Log","doc":"- DateConvert/DateFormat aliases","ref":"changelog.html#removed-1"},{"type":"extras","title":"Fixed - Change Log","doc":"- Shifting datetimes is now far more accurate than it was previously, and handles timezone changes, ambiguous timezone periods, and non-existent time periods (such as those during a timezone change like DST).\n- Diffing by weeks, months, and years is now much more precise\n- Humanized Time formatter now pluralizes units correctly","ref":"changelog.html#fixed-26"},{"type":"extras","title":"1.0.2 - Change Log","doc":"**BREAKING**: If you previously depended on parsing of timezone abbreviations for non-POSIX zones,\nfor example, CEST, you will need to update your code to manually map that abbreviation to a valid zone\nname. Timezone abbreviations are only supported if they are POSIX timezones in the Olson timezone database.","ref":"changelog.html#1-0-2"},{"type":"extras","title":"Added - Change Log","doc":"- Added CHANGELOG\n- Add Date.from clause to handle Phoenix datetime_select changeset","ref":"changelog.html#added-18"},{"type":"extras","title":"Changed - Change Log","doc":"- Timezone abbreviation handling is now only valid for POSIX/Olson timezone names.\n- Some small optimizations","ref":"changelog.html#changed-7"},{"type":"extras","title":"Deprecated - Change Log","doc":"- N/A","ref":"changelog.html#deprecated-1"},{"type":"extras","title":"Removed - Change Log","doc":"- Timezone abbreviation handling for non-POSIX/Olson timezone names","ref":"changelog.html#removed-2"},{"type":"extras","title":"Fixed - Change Log","doc":"- Timezone abbreviation handling (was previously non-deterministic/incorrect)\n- Disable tzdata's auto-update during compilation\n- Usage of imperative if","ref":"changelog.html#fixed-27"},{"type":"extras","title":"Basic Usage","doc":"# Basic Usage\n\n**Some common scenarios with examples**","ref":"basic-usage.html"},{"type":"extras","title":"Getting the date/time - Basic Usage","doc":"","ref":"basic-usage.html#getting-the-date-time"},{"type":"extras","title":"Getting the current datetime in UTC - Basic Usage","doc":"```elixir\niex> Timex.now\n# \n\niex> Timex.today\n~D[2016-07-12]\n```","ref":"basic-usage.html#getting-the-current-datetime-in-utc"},{"type":"extras","title":"Getting the current datetime in the local timezone - Basic Usage","doc":"```elixir\niex> Timex.local\n# \n```","ref":"basic-usage.html#getting-the-current-datetime-in-the-local-timezone"},{"type":"extras","title":"Getting the current datetime in an arbitrary timezone - Basic Usage","doc":"```elixir\niex> Timex.now(\"Europe/Copenhagen\")\n# \n```","ref":"basic-usage.html#getting-the-current-datetime-in-an-arbitrary-timezone"},{"type":"extras","title":"Construction - Basic Usage","doc":"```elixir\niex> Timex.to_date({2015, 6, 24})\n~D[2015-06-24]\n\niex> Timex.to_datetime({{2015, 6, 24}, {4, 50, 34}}, \"America/Chicago\")\n# \n\niex> Timex.to_datetime({{2015, 6, 24}, {4, 50, 34}}, :local)\n# \n```","ref":"basic-usage.html#construction"},{"type":"extras","title":"Parsing date/time strings - Basic Usage","doc":"","ref":"basic-usage.html#parsing-date-time-strings"},{"type":"extras","title":"Parsing an ISO 8601-formatted DateTime string - Basic Usage","doc":"```elixir\n# With timezone offset\niex> Timex.parse!(\"2015-06-24T04:50:34-05:00\", \"{ISO:Extended}\")\n# \n\n# Without timezone offset\niex> Timex.parse!(\"2015-06-24T04:50:34Z\", \"{ISO:Extended:Z}\")\n# \n```","ref":"basic-usage.html#parsing-an-iso-8601-formatted-datetime-string"},{"type":"extras","title":"Formatting DateTimes - Basic Usage","doc":"","ref":"basic-usage.html#formatting-datetimes"},{"type":"extras","title":"Formatting a DateTime as an ISO 8601 string - Basic Usage","doc":"```elixir\niex> Timex.format!(Timex.to_datetime(~N[2015-06-24T00:04:09.293], \"America/Chicago\"), \"{ISO:Extended}\")\n\"2015-06-24T00:04:09.293-05:00\"\niex> Timex.format!(Timex.to_datetime(~N[2015-06-24T00:04:09.293], \"America/Chicago\"), \"{ISO:Extended:Z}\")\n\"2015-06-24T05:04:13.293Z\"\n```","ref":"basic-usage.html#formatting-a-datetime-as-an-iso-8601-string"},{"type":"extras","title":"Testing if one event occurs in an interval - Basic Usage","doc":"```elixir\niex> use Timex\n...> event = Timex.to_datetime({{2016, 6, 24}, {0, 0, 0}})\n...> other_event = Timex.to_datetime({{2010, 1, 1}, {0, 0, 0}})\n...> from = Timex.to_datetime({{2015, 1, 1}, {0, 0, 0}})\n...> until = Timex.to_datetime({{2018, 1, 1}, {0, 0, 0}})\n...> interval = Timex.Interval.new(from: from, until: until)\n...> event in interval\ntrue\n...> other_event in interval\nfalse\n```","ref":"basic-usage.html#testing-if-one-event-occurs-in-an-interval"},{"type":"extras","title":"Erlang Interop","doc":"# Erlang Interop","ref":"erlang-interop.html"},{"type":"extras","title":"Erlang Dates and Times - Erlang Interop","doc":"","ref":"erlang-interop.html#erlang-dates-and-times"},{"type":"extras","title":"How to work with Erlang datetime and time representations - Erlang Interop","doc":"Without Timex, you've probably been working with Erlang's standard library `:calendar` module and/or `:os.timestamp` function, you may have code which already works on them, or need to consume them from another library, etc. The two most common representations of time in Erlang are the datetime and timestamp tuples, `{{year, month, day}, {hour, minute, second}}`, and `{megaseconds, seconds, microseconds}` respectively. The former is of course used for representing dates and times in a familiar format, the latter is used for representing precise moments in time, down to the microsecond.","ref":"erlang-interop.html#how-to-work-with-erlang-datetime-and-time-representations"},{"type":"extras","title":"Converting from Erlang datetime tuples - Erlang Interop","doc":"```elixir\n# To bring the aliases for Timex's modules into scope, we need to \"use\" Timex\niex> use Timex\n\n# Our input datetime\niex> date = :calendar.universal_time\n{{2015, 6, 24}, {3, 59, 5}}\n\n# Conversions to various Elixir types\niex> Timex.to_datetime(date, \"Etc/UTC\")\n...\niex> Timex.to_naive_datetime(date)\n...\niex> Timex.to_date(date)\n...\n```","ref":"erlang-interop.html#converting-from-erlang-datetime-tuples"},{"type":"extras","title":"Converting from Erlang timestamp tuples - Erlang Interop","doc":"```elixir\n# The simplest case, converting from a timestamp to a DateTime, using the highest precision\niex> Duration.from_erl(:os.timestamp())\n# \n\n# Alternatively if you want control over the precision (in this example, we only care about up-to-the-second precision):\niex> time |> Duration.to_seconds |> Timex.from_unix\n# \n```","ref":"erlang-interop.html#converting-from-erlang-timestamp-tuples"},{"type":"extras","title":"Converting DateTimes to Erlang datetime tuples - Erlang Interop","doc":"`Timex.to_erl/1` converts any valid Timex date/datetime to an erlang date or\ndatetime tuple.\n\n```elixir\niex> date = Timex.now\n...> Timex.to_erl(date)\n{{2015, 6, 24}, {4, 18, 33}}\n```","ref":"erlang-interop.html#converting-datetimes-to-erlang-datetime-tuples"},{"type":"extras","title":"Formatting","doc":"# Formatting\n\nHow to format DateTimes as strings with Timex's DateFormat module, and time intervals with TimeFormatter","ref":"formatting.html"},{"type":"extras","title":"Formatting DateTimes - Formatting","doc":"Formatting DateTimes in Timex is done via the `Timex` module. There are two built in formatters, :default and :strftime. The details of how to construct format strings can be found in the docs for [`Timex.Format.DateTime.Formatters.Default`](http://hexdocs.pm/timex/Timex.Format.DateTime.Formatters.Default.html) and [`Timex.Format.DateTime.Formatters.Strftime`](http://hexdocs.pm/timex/Timex.Format.DateTime.Formatters.Strftime.html), so this document will be a brief overview of the DateFormat API and how you use it typically.\n\n```elixir\n# By default the :default formatter is used\niex> Timex.format({2013,8,18}, \"{YYYY}-{M}-{D}\")\n{:ok, \"2013-8-18\"}\n\n# But you can use the :strftime formatter very easily\niex> Timex.format({2013,8,18}, \"%Y-%m-%d\", :strftime)\n{:ok, \"2013-08-18\"}\n\n# If you create your own formatter, you can use it easily as well\niex> Timex.format({2013,8,18}, format_str, MyApp.MyDateFormatter)\n\n# If formatting fails for some reason you will get an `{:error, reason}` tuple, so it's\n# recommended to use `format/1` or `format/2`; however you can use the \"bang\"\n# versions of these two, `format!/1` or `format!/2` which will return the result directly,\n# or raise on failure\niex> Timex.format!({2013,8,18}, \"%Y-%m-%d\", :strftime)\n\"2013-08-18\"\n```","ref":"formatting.html#formatting-datetimes"},{"type":"extras","title":"Formatting durations - Formatting","doc":"Formatting durations (or timestamps really) is done via the `Timex.Format.Duration.Formatter` module, or more commonly via `Timex.format_duration`. It is extensible like date/time formatting as well.\n\n```elixir\n# Time since the epoch\niex> Duration.now |> Timex.format_duration\n\"P45Y7M25DT18H13M10.966072S\"\niex> Duration.now |> Timex.format_duration(:humanized)\n\"45 years, 7 months, 3 weeks, 4 days, 18 hours, 13 minutes, 16 seconds, 141.422 milliseconds\"\n\n# Time it took to execute some code\niex> {interval, _} = Duration.measure(fn -> 1..10000 |> Enum.reverse end)\n# \niex> interval |> Timex.format_duration\n\"PT0.002614S\"\niex> interval |> Timex.format_duration(:humanized)\n\"2.614 milliseconds\"\n```","ref":"formatting.html#formatting-durations"},{"type":"extras","title":"Parsing","doc":"# Parsing\n\n**NOTE:** While Timex is strict about handling user input in general, it makes no guarantees that you will be protected from malicious input, as there are some limitations when considering user-provided input to parsers. A few parsers in Timex accept unbounded input, such as `{s-epoch}`, because there is no defined limit on the number of seconds since UNIX epoch (you may want to represent a date far in the future for example). It's important that you do your own validation of user input before passing it to Timex for parsing as a second line of defense - for example, limiting the length of input strings to some reasonable max length. It's also highly recommended that you take care to be as restrictive with your format strings as possible.","ref":"parsing.html"},{"type":"extras","title":"How to use Timex for parsing DateTimes from strings - Parsing","doc":"Parsing a DateTime from an input string is very similar to formatting them, and is quite simple:\n\n```elixir\n# Simple date format, default parser\niex> Timex.parse(\"2013-03-05\", \"{YYYY}-{0M}-{0D}\")\n\n# Simple date format, strftime parser\niex> Timex.parse(\"2013-03-05\", \"%Y-%m-%d\", :strftime)\n\n# Parse a date using the default parser and the shortcut directive for RFC 1123\niex> Timex.parse!(\"Tue, 05 Mar 2013 23:25:19 Z\", \"{RFC1123z}\")\n# \n\n# Or you can use the :strftime parser (note how without timezone information, a NaiveDateTime is returned)\niex> Timex.parse!(\"2013-03-05\", \"%Y-%m-%d\", :strftime)\n~N[2013-03-05T00:00:00]\n\n# Any preformatted directive ending in `z` will shift the date to UTC/Zulu\niex> Timex.parse(\"Tue, 06 Mar 2013 01:25:19 +0200\", \"{RFC1123}\")\n{:ok, # }\n```\n\n,You can also use \"bang\" versions (i.e. `parse!`), which will raise on failure rather than returning an `{:error, reason}` tuple (`parse!/1` and `parse!/2` respectively).","ref":"parsing.html#how-to-use-timex-for-parsing-datetimes-from-strings"},{"type":"extras","title":"Supported Standards and Common Formats - Parsing","doc":"#### RFC822\n```elixir\n# RFC822\niex> Timex.parse(\"Mon, 05 Jun 14 23:20:59 UTC\", \"{RFC822}\")\n{:ok, #DateTime<2014-06-05 23:20:59Z>}\n\n# RFC822z\niex> Timex.parse(\"Mon, 05 Jun 14 23:20:59 +00:00\", \"{RFC822z}\")\n{:ok, #DateTime<2014-06-05 23:20:59Z>}\n```\n#### RFC3339\n```elixir\n# RFC3339\niex> Timex.parse(\"2013-03-05T23:25:19+02:00\", \"{RFC3339}\")\n{:ok, #DateTime<2013-03-05 23:25:19+02:00 +02 Etc/GMT-2>}\n\n# RFC3339z\niex> Timex.parse(\"2013-03-05T23:25:19Z\", \"{RFC3339z}\")\n{:ok, #DateTime<2013-03-05 23:25:19Z>}\n```\n#### RFC1123\n```elixir\n# RFC1123\niex> Timex.parse(\"Tue, 05 Mar 2013 23:25:19 EST\", \"{RFC1123}\")\n{:ok, #DateTime<2013-03-05 23:25:19-05:00 EST EST>}\n\n# RFC1123z\niex> Timex.parse(\"Tue, 06 Mar 2013 01:25:19 Z\", \"{RFC1123z}\")\n{:ok, #DateTime<2013-03-06 01:25:19Z>}\n```\n#### ASN1:GeneralizedTime\n```elixir\n\n# ASN1:GeneralizedTime\niex> Timex.parse(\"20090305232519\", \"{ASN1:GeneralizedTime}\")\n{:ok, ~N[2009-03-05 23:25:19]}\n\n# ASN1:GeneralizedTime:Z\niex> Timex.parse(\"20090305232519.456Z\", \"{ASN1:GeneralizedTime:Z}\")\n{:ok, #DateTime<2009-03-05 23:25:19.456Z>}\n\n# ASN1:GeneralizedTime:TZ\niex> Timex.parse(\"20090305232519.000-0700\", \"{ASN1:GeneralizedTime:TZ}\")\n{:ok, #DateTime<2009-03-05 23:25:19-07:00 -07 Etc/GMT+7>}\n```\n\n#### ASN1:UTCtime\n```elixir\n\n# ASN1: UTCtime\niex(26)> Timex.parse(\"130305232519Z\", \"{ASN1:UTCtime}\")\n{:ok, #DateTime<2013-03-05 23:25:19Z>}\n```\n#### ISO:Extended\n\n```elixir\n# ISO8601 (Extended)\niex> Timex.parse(\"2014-08-14T12:34:33+00:00\", \"{ISO:Extended}\")\n{:ok, #DateTime<2014-08-14 12:34:33Z>}\n\niex> Timex.parse(\"2014-08-14T12:34:33+0000\", \"{ISO:Extended}\")\n{:ok, #DateTime<2014-08-14 12:34:33Z>}\n\niex> Timex.parse(\"2014-08-14T12:34:33Z\", \"{ISO:Extended:Z}\")\n{:ok, #DateTime<2014-08-14 12:34:33Z>}\n\n# ISO8601 (Basic)\niex> Timex.parse(\"20140814T123433-0000\", \"{ISO:Basic}\")\n{:ok, #DateTime<2014-08-14 12:34:33+00:00 GMT Etc/GMT+0>}\n\niex> Timex.parse(\"20140814T123433Z\", \"{ISO:Basic:Z}\")\n{:ok, #DateTime<2014-08-14 12:34:33Z>}\n\n```\n\n#### ISOdate\n```elixir\niex> Timex.parse(\"2007-08-13\", \"{ISOdate}\")\n{:ok, ~N[2007-08-13 00:00:00]}\n```","ref":"parsing.html#supported-standards-and-common-formats"},{"type":"extras","title":"Default Directive Format - Parsing","doc":"This is a formatting language designed specifically alongside Timex, and its primary\npurpose and advantage is that it is simple and easy to memorize and read in comparison\nto the standard C stftime format.\n\nThe full documentation on the set of directives and formatting options can be found\n[here](https://hexdocs.pm/timex/Timex.Format.DateTime.Formatters.Default.html).","ref":"parsing.html#default-directive-format"},{"type":"extras","title":"Strftime Directive Format - Parsing","doc":"This is the standard C library formatting language used with the `stftime` function in C.\nTimex supports this as a familiar alternative to its native \"default\" formatting language\nas described above.\n\nThis implementation in Elixir is mostly compatible with `strftime`. The\nexception is the absence of locale-depended results. All directives that imply\ntextual result will produce English names and abbreviations.\n\nYou can find the full documentation on this format and its options\n[here](https://hexdocs.pm/timex/Timex.Format.DateTime.Formatters.Strftime.html).","ref":"parsing.html#strftime-directive-format"},{"type":"extras","title":"Relative Format - Parsing","doc":"This is a human readable relative date/time format that consists of a single\ndirective, `{relative}`, and produces values like \"a few seconds ago\", or\n\"2 days ago\".\n\nYou can find the full chart of mappings from ranges to values [here](https://hexdocs.pm/timex/Timex.Format.DateTime.Formatters.Relative.html).","ref":"parsing.html#relative-format"},{"type":"extras","title":"Frequently Asked Questions","doc":"# Frequently Asked Questions\n\nThese are questions asked at one point or another.\n\n**How is Timex licensed?**\n\nTimex is made available under the MIT license. See the GitHub repo for details.\n\n**Why can't I compare dates and times with <, >, etc.?**\n\nIt is not possible to override the comparison operators to properly\ncompare arbitrary structs. Use `Timex.compare/2 or /3` to compare them instead.\n\n**Which functions provide microsecond precision?**\n\nAll of them. Unless you convert to something with lower precision.\n\n**How do I find the time interval between two dates?**\n\nUse `Timex.diff` to obtain the number of microseconds, milliseconds, seconds, minutes, hours, days, months, weeks, or years between two dates.\n\n**What is the support for timezones?**\n\nFull support for retrieving local timezone configuration on OSX, *NIX, and Windows, conversion to any timezone in the Olson timezone database, and full support for timezone transitions.\n\nTimezone support is also exposed via the `Timezone`, and `Timezone.Local` modules. Their functionality is also exposed via the `Date` module's API, and most common use cases shouldn't need to access the `Timezone` namespace directly, but it's there if needed.","ref":"faq.html"},{"type":"extras","title":"Using with Ecto","doc":"# Using with Ecto\n\nHow to use Timex DateTimes with Ecto.","ref":"using-with-ecto.html"},{"type":"extras","title":"Getting Started - Using with Ecto","doc":"Timex has can be integrated with Ecto via the `timex_ecto` plugin which is available on hex.pm:\n\n```elixir\ndefp deps do\n  [{:timex, \"~> x.x.x\"},\n   {:timex_ecto, \"~> x.x.x\"}]\nend\n```","ref":"using-with-ecto.html#getting-started"},{"type":"extras","title":"Available Types - Using with Ecto","doc":"Timex-Ecto exposes a few different types for you to use:\n\n- `Timex.Ecto.Date`: An ISO date (`YYYY-MM-DD`)\n- `Timex.Ecto.Time`: An ISO time (`hh:mm:ss.sss`)\n- `Timex.Ecto.DateTime`: An ISO 8601 datetime in UTC\n- `Timex.Ecto.DateTimeWithTimezone`: Same as DateTime, but contains the timezone, i.e. `America/Chicago` as well. **NOTE** currently this is only supported with PostgreSQL, as it relies on complex types which are not currently supported in MySQL, and SQL Server user defined types require CLR types backing them which I have not explored in depth as of yet. See the section below titled [Using DateTimeWithTimezone](doc:using-with-ecto#section-using-datetimewithtimezone) for details.","ref":"using-with-ecto.html#available-types"},{"type":"extras","title":"Model Definition - Using with Ecto","doc":"In order to use the Timex DateTime type instead of the Ecto DateTime type, your model should look something like the following:\n\n```elixir\ndefmodule User do\n  use Ecto.Model\n\n  schema \"users\" do\n    field :name, :string\n    field :a_date,       Timex.Ecto.Date # Timex version of :date, will reify as a Date\n    field :a_time,       Timex.Ecto.Time # Timex version of :time, will reify as a Time\n    field :a_datetime,   Timex.Ecto.DateTime # Timex version of :datetime, will reify as a NaiveDateTime\n    field :a_datetimetz, Timex.Ecto.DateTimeWithTimezone # A custom datatype (:datetimetz) implemented by Timex, will reify as a DateTime\n  end\nend\n```","ref":"using-with-ecto.html#model-definition"},{"type":"extras","title":"Using Timex with Ecto's timestamps macro - Using with Ecto","doc":"Super simple! Your timestamps will now be `DateTime` structs instead of `Ecto.DateTime` structs.\n\n```elixir\ndefmodule User do\n  use Ecto.Model\n  use Timex.Ecto.Timestamps\n\n  schema \"users\" do\n    field :name, :string\n    timestamps\n  end\nend\n```","ref":"using-with-ecto.html#using-timex-with-ecto-s-timestamps-macro"},{"type":"extras","title":"Using with Phoenix - Using with Ecto","doc":"Phoenix allows you to apply defaults globally to Ecto models via `web/web.ex` by changing the `model` function like so:\n\n```elixir\ndef model do\n  quote do\n    use Ecto.Model\n    use Timex.Ecto.Timestamps\n  end\nend\n```\n\nBy doing this, you bring the Timex timestamps into scope in all your models.","ref":"using-with-ecto.html#using-with-phoenix"},{"type":"extras","title":"Using DateTimeWithTimezone - Using with Ecto","doc":"NOTE: This currently only applies to PostgreSQL.\n\nYou must run the following SQL against the database you plan on using this type with:\n\n```sql\nCREATE TYPE datetimetz AS (\n    dt timestamptz,\n    tz varchar\n);\n```\n\nYou can then use this type like so:\n\n```sql\nCREATE TABLE example (\n  id integer,\n  created_at datetimetz\n);\n```\n\nThat's it!","ref":"using-with-ecto.html#using-datetimewithtimezone"},{"type":"extras","title":"Full Example - Using with Ecto","doc":"The following is a simple test app I built for vetting this plugin:\n\n```elixir\ndefmodule EctoTest.Repo do\n  use Ecto.Repo, otp_app: :timex_ecto_test\nend\n\ndefmodule EctoTest.User do\n  use Ecto.Model\n  use Timex.Ecto.Timestamps\n\n  schema \"users\" do\n    field :name, :string\n    field :date_test,       Timex.Ecto.Date\n    field :time_test,       Timex.Ecto.Time\n    field :datetime_test,   Timex.Ecto.DateTime\n    field :datetimetz_test, Timex.Ecto.DateTimeWithTimezone\n  end\nend\n\ndefmodule EctoTest do\n  import Ecto.Query\n  use Timex\n\n  alias EctoTest.User\n  alias EctoTest.Repo\n\n  def seed do\n    time       = Time.now\n    date       = Timex.today\n    datetime   = Timex.now\n    datetimetz = Timezone.convert(datetime, \"Europe/Copenhagen\")\n    u = %User{name: \"Paul\", date_test: date, time_test: time, datetime_test: datetime, datetimetz_test: datetimetz}\n    Repo.insert!(u)\n  end\n\n  def all do\n    query = from u in User,\n            select: u\n    Repo.all(query)\n  end\nend\n\ndefmodule EctoTest.App do\n  use Application\n\n  def start(_type, _args) do\n    import Supervisor.Spec\n    tree = [worker(EctoTest.Repo, [])]\n    opts = [name: EctoTest.Sup, strategy: :one_for_one]\n    Supervisor.start_link(tree, opts)\n  end\nend\n```\n\nAnd the results:\n\n```elixir\niex(1)> EctoTest.seed\n\n14:45:43.461 [debug] INSERT INTO \"users\" (\"date_test\", \"datetime_test\", \"datetimetz_test\", \"name\", \"time_test\") VALUES ($1, $2, $3, $4, $5) RETURNING \"id\" [{2015, 6, 25}, {{2015, 6, 25}, {19, 45, 43, 457000}}, {{{2015, 6, 25}, {21, 45, 43, 457000}}, \"Europe/Copenhagen\"}, \"Paul\", {19, 45, 43, 457000}] OK query=3.9ms\n%EctoTest.User{__meta__: %Ecto.Schema.Metadata{source: \"users\",\n  state: :loaded},\n date_test: ~D[2015-06-25],\n datetime_test: # ,\n datetimetz_test: # ,\n name: \"Paul\", time_test: # \niex(2)> EctoTest.all\n\n14:45:46.721 [debug] SELECT u0.\"id\", u0.\"name\", u0.\"date_test\", u0.\"time_test\", u0.\"datetime_test\", u0.\"datetimetz_test\" FROM \"users\" AS u0 [] OK query=0.7ms\n[%EctoTest.User{__meta__: %Ecto.Schema.Metadata{source: \"users\",\n   state: :loaded},\n  date_test: ~D[2015-06-25],\n  datetime_test: # ,\n  datetimetz_test: # ,\n  name: \"Paul\", time_test: # }]\niex(3)>\n```\n\nAnd that's all there is to it!","ref":"using-with-ecto.html#full-example"},{"type":"extras","title":"Custom Parsers","doc":"# Custom Parsers","ref":"custom-parsers.html"},{"type":"extras","title":"How to add custom DateTime parsers to Timex - Custom Parsers","doc":"It is unlikely you will need to write a custom parser for Timex, but should you be in such a position, you can easily plug in your own without much trouble.","ref":"custom-parsers.html#how-to-add-custom-datetime-parsers-to-timex"},{"type":"extras","title":"Getting Started - Custom Parsers","doc":"In brief, all you need to know is the following:\n\n- Extend the `Tokenizer` behavior, by adding `use Timex.Parse.DateTime.Tokenizer` to the top of your module.\n- Implement `tokenize/1` callback.\n- Implement `apply/3` callback.\n\nWhat we are doing with the above is implementing a tokenizer for the format strings your custom parser will use. Incidentally this also is a prerequisite for implementing a custom formatter (you need to tokenize the format strings). Your best reference is to look at the two built-in tokenizers in Timex, as they are robust and complete implementations, but for the sake of an arbitrary example, let's walk through implementing a very simple parser for humanized strings like \"5 days before the fifth of July, 2015\", where the following tokens are allowed:\n\n- \"{shift}\" which should be in the form of \"     \"\n- \"{day}\" of the form \"first\", \"second\", \"third\", etc.\n- \"{month}\" which is the full name of a month, i.e. \"July\"\n- \"{year}\" which is the full four digit year","ref":"custom-parsers.html#getting-started"},{"type":"extras","title":"Tokenizer Implementation - Custom Parsers","doc":"","ref":"custom-parsers.html#tokenizer-implementation"},{"type":"extras","title":"Implementing the Humanized tokenizer - Custom Parsers","doc":"We start by defining our empty module:\n\n```elixir\ndefmodule MyApp.DateTimeTokenizers.Humanized do\n  use Timex.Parse.DateTime.Tokenizer\nend\n```\n\nCompiling with this will produce the following errors:\n\n```\n../humanized.ex:1: warning: undefined behaviour function tokenize/1 (for behaviour Timex.Parse.DateTime.Tokenizer)\n../humanized.ex:1: warning: undefined behaviour function apply/3 (for behaviour Timex.Parse.DateTime.Tokenizer)\n```\n\nSo we need to implement the `tokenize` function which takes a format string and produces a list of `Directive` structs (or `{:error, term}`). The following implementation makes use of Combine, a dependency pulled in by Timex for parsing tasks, and while you do not need to implement your tokenizer using Combine, the parser function given to each Directive must take a single argument of `%Combine.ParserState{}`, and return it, updated with the status and results from parsing. See [the Combine repo](https://github.com/bitwalker/combine) for examples on how to implement these parsers (it is really rather trivial). My recommendation is to simply use Combine, as it is well suited for these tasks, but now you know how to work around it if so desired.\n\n```elixir\ndefmodule MyApp.DateTimeTokenizers.Humanized do\n  use Timex.Parse.DateTime.Tokenizer\n  use Combine\n\n  @days [\n    \"first\", \"second\", \"third\", \"fourth\", \"fifth\",\n    \"sixth\", \"seventh\", \"eighth\", \"ninth\", \"tenth\",\n    \"eleventh\", \"twelfth\", \"thirteenth\", \"fourteenth\", \"fifteenth\",\n    \"sixteenth\", \"seventeenth\", \"eighteenth\", \"nineteenth\", \"twentieth\",\n    \"twenty-first\", \"twenty-second\", \"twenty-third\", \"twenty-fourth\", \"twenty-fifth\",\n    \"twenty-sixth\", \"twenty-seventh\", \"twenty-eighth\", \"twenty-ninth\", \"thirtieth\",\n    \"thirty-first\"\n  ]\n\n  def tokenize(s) do\n    case Combine.parse(s, parser) do\n      results when is_list(results) ->\n        directives = results |> List.flatten |> Enum.filter(fn x -> x !== nil end)\n        case Enum.any?(directives, fn %Directive{type: type} -> type != :literal end) do\n          false -> {:error, \"Invalid format string, must contain at least one directive.\"}\n          true  -> {:ok, directives}\n        end\n      {:error, _} = err -> err\n    end\n  end\n\n  # Token parser\n  defp parser do\n    many1(choice([\n      between(char(?{), map(one_of(word, [\"shift\", \"day\", \"month\", \"year\"]), &map_directive/1), char(?})),\n      map(none_of(char, [\"{\", \"}\"]), &map_literal/1)\n    ]))\n  end\n\n  # Gets/builds the Directives for a given token\n  defp map_directive(\"year\"), do: Directive.get(:year4, \"year\")\n  defp map_directive(\"month\"), do: Directive.get(:mfull, \"month\")\n  defp map_directive(\"day\"),\n    do: %Directive{type: :oday_phonetic, value: \"day\", parser: oday_phoenetic_parser()}\n  defp map_directive(\"shift\"),\n    do: %Directive{type: :date_shift, value: \"shift\", parser: date_shift_parser(), weight: 99}\n\n  # Generates directives for literals\n  defp map_literal([]),        do: nil\n  defp map_literal(literals)\n    when is_list(literals),    do: Enum.map(literals, &map_literal/1)\n  defp map_literal(literal),   do: %Directive{type: :literal, value: literal, parser: char(literal)}\n\n  # Parses a phonetic ordinal day string, i.e. third\n  defp oday_phoenetic_parser() do\n    map(one_of(word_of(~r/[\\w\\-]/), @days), fn day -> [day: to_day(day)] end)\n  end\n\n  # Parses a date shift expression, i.e. 3 days after\n  defp date_shift_parser() do\n    map(sequence([\n      integer,\n      skip(spaces),\n      one_of(word, [\"seconds\", \"minutes\", \"hours\", \"days\", \"weeks\", \"months\", \"years\"]),\n      skip(spaces),\n      one_of(word, [\"before\", \"after\"])\n    ]), fn\n      [n, shift, \"before\"] -> [date_shift: [{to_shift(shift), -n}]]\n      [n, shift, \"after\"]  -> [date_shift: [{to_shift(shift), n}]]\n    end)\n  end\n  defp to_shift(shift), do: String.to_atom(shift)\n\n  # Get the ordinal day value based on the ordinal day name\n  defp to_day(name), do: Enum.find_index(@days, fn (n) -> n == name end) + 1\nend\n```","ref":"custom-parsers.html#implementing-the-humanized-tokenizer"},{"type":"extras","title":"Implementation Notes - Custom Parsers","doc":"A couple of things to notice.\n\n1. Many parsing directives are already built in to Timex, you can see which ones exist by looking at the `Directive` module. Rather than re-implement parsing of month names and 4 digit years, we're using `Directive.get` to pull the predefined Directives for those.\n2. However we also have two custom directives to handle the phonetic ordinal names and the date shift expressions, we're defining those directives (and their associated parsers) by hand. This is also the reason why you must implement `apply/3`. The built-in directives are applied via the parser, but custom tokens have to be applied by the tokenizer. I could have split out the tokenize and apply functions into two behaviours (say Tokenizer and Parser), but rather than force that upon you, this is a decision you can make in your own tokenizer (by using defdelegate to keep your `apply/3` code separated).\n3. We're creating Directive structs for literal characters. This is important both for parsing and formatting, as it allows your parser to ignore context (i.e. skipping spaces, etc.) and focus on parsing the precise thing it needs to parse. When formatting it's also important, as it makes sure that we output a string which matches the format string precisely.\n4. The parsers for the directives return a keyword list of `token: value` as their result. This is a requirement, as the parser will take the input string and parse out a flattened list of `{token, value}` tuples. If your directive parsers do not produce values in this form, they will be ignored, and thus your parser will not work properly (and will likely produce an error).\n5. We're setting the `weight` key of the Directive for the shift expression. This will ensure that it is applied last. Consider the input string \"3 days after July fourth, 2015\", if we try to apply the shift expression to the DateTime we get in `apply/3` (which starts at `0/1/1T00:00:00`), we will get an error for trying to shift the date out of the gregorian calendar, when really we want to apply the shift to the date specified later in the input string. By weighting the directive to be last, we will first apply the month, then the day, then the year to the initial DateTime, then apply the shift to the date we actually wanted it applied to. You can set the weight for all your directives to have them applied in a specific order, so keep it in mind for situations like this.\n\nWe are left now with the responsibility of implementing `apply/3`, leaving our tokenizer implementation looking like the following:\n\n```elixir\ndefmodule MyApp.DateTimeTokenizers.Humanized do\n  use Timex.Parse.DateTime.Tokenizer\n  use Combine\n  alias Timex.Date\n\n  ...snip...\n\n  @doc \"\"\"\n  Applies a token to the DateTime representing the current input string\n  Only unrecognized tokens are applied via this function, standard tokens,\n  such as :year4 will be handled by the parser itself.\n\n  You can return {:ok, date}, {:error, reason}, or :unrecognized (if you don't\n  know what to do with the provided token).\n  \"\"\"\n  def apply(%DateTime{} = date, token, value) do\n    case token do\n      :oday_phonetic ->\n        {:ok, %{date | :day => value}}\n      :date_shift ->\n        case value do\n          [{shift, n}] when is_integer(n) ->\n            {:ok, Timex.shift(date, [{shift, n}])}\n          shift ->\n            {:error, \"Unrecognized shift operation: #{Macro.to_string(shift)}\"}\n        end\n      _ ->\n        {:error, \"Unrecognized token: #{token}.\"}\n    end\n  end\n\n  ...snip...\nend\n```","ref":"custom-parsers.html#implementation-notes"},{"type":"extras","title":"Usage - Custom Parsers","doc":"After all this, we're now ready to use our custom parser!\n\n```elixir\n> alias MyApp.DateTimeTokenizers.Humanized\n> phrase = \"3 days before the second of July, 2015\"\n> format = \"{shift} the {day} of {month}, {year}\"\n> Timex.parse!(phrase, format, Humanized)\n# \n```","ref":"custom-parsers.html#usage"},{"type":"extras","title":"Custom Formatters","doc":"# Custom Formatters","ref":"custom-formatters.html"},{"type":"extras","title":"How to implement a custom formatter for use with Timex - Custom Formatters","doc":"Implementing your own custom formatter is pretty straightforward if you plan to use one of the built-in format string tokenizers (default or strftime). The following example will use a custom tokenizer, and implement the formatter over the top of that.\n\nThe tokenizer is implemented as described in the [Custom Parsers](doc:custom-parsers) section, and the source code can be found in the Timex repo [here](https://github.com/bitwalker/timex/blob/master/examples/tokenizer/humanized.exs).","ref":"custom-formatters.html#how-to-implement-a-custom-formatter-for-use-with-timex"},{"type":"extras","title":"Getting Started - Custom Formatters","doc":"In brief, all you need to know is the following:\n\n- Extend the `Formatter` behavior, by adding `use Timex.Format.DateTime.Formatter` to the top of your module.\n- Implement `tokenize/1` callback.\n- Implement `format/2` callback.\n- Implement `format!/2` callback.\n\nThe `tokenize/1` callback can simply be delegated to the tokenizer you wish to use, while the implementation of `format/2` and `format!/2` are what we really are interested in here.","ref":"custom-formatters.html#getting-started"},{"type":"extras","title":"Implementing the Humanized formatter - Custom Formatters","doc":"The implementation of the formatter for our \"humanized\" date format would like something like the following:\n\n```elixir\ndefmodule MyApp.DateTimeFormatters.Humanized do\n  use Timex.Format.DateTime.Formatter\n\n  alias Timex.Format.FormatError\n  alias MyApp.DateTimeTokenizers.Humanized, as: Tokenizer\n\n  @days [\n    \"first\", \"second\", \"third\", \"fourth\", \"fifth\",\n    \"sixth\", \"seventh\", \"eighth\", \"ninth\", \"tenth\",\n    \"eleventh\", \"twelfth\", \"thirteenth\", \"fourteenth\", \"fifteenth\",\n    \"sixteenth\", \"seventeenth\", \"eighteenth\", \"nineteenth\", \"twentieth\",\n    \"twenty-first\", \"twenty-second\", \"twenty-third\", \"twenty-fourth\", \"twenty-fifth\",\n    \"twenty-sixth\", \"twenty-seventh\", \"twenty-eighth\", \"twenty-ninth\", \"thirtieth\",\n    \"thirty-first\"\n  ]\n\n  defdelegate tokenize(format_string), to: Tokenizer\n\n  def format!(date, format_string) do\n    case format(date, format_string) do\n      {:ok, result}    -> result\n      {:error, reason} -> raise FormatError, message: reason\n    end\n  end\n\n  def format(date, format_string) do\n    case tokenize(format_string) do\n      {:ok, []} ->\n        {:error, \"There were no formatting directives in the provided string.\"}\n      {:ok, dirs} when is_list(dirs) ->\n        do_format(Timex.to_naive_datetime(date), dirs, <<>>)\n      {:error, reason} -> {:error, {:format, reason}}\n    end\n  end\n\n  defp do_format(_date, [], result),             do: {:ok, result}\n  defp do_format(_date, _, {:error, _} = error), do: error\n  defp do_format(date, [%Directive{type: :literal, value: char} | dirs], result) when is_binary(char) do\n    do_format(date, dirs, < >)\n  end\n  defp do_format(%NaiveDateTime{day: day} = date, [%Directive{type: :oday_phonetic} | dirs], result) do\n    phonetic = Enum.at(@days, day - 1)\n    do_format(date, dirs, < >)\n  end\n  defp do_format(date, [%Directive{type: :date_shift} | dirs], result) do\n    do_format(date, dirs, < >)\n  end\n  defp do_format(date, [%Directive{type: type, modifiers: mods, flags: flags, width: width} | dirs], result) do\n    case format_token(type, date, mods, flags, width) do\n      {:error, _} = err -> err\n      formatted         -> do_format(date, dirs, < >)\n    end\n  end\n\nend\n```\n\nAs you can see the implementation is pretty straightforward. You'll notice that the last `do_format` implementation calls an imported function `format_token/5`, this allows you to delegate the formatting of known directives to the formatter, which will use standard formatting rules. You can of course override the formatting of directives using the style above (pattern matching on the directive type and handling the formatting directly).\n\nTo use our new formatter with `Timex.format`:\n\n```elixir\niex> use Timex\niex> alias MyApp.DateTimeFormatters.Humanized, as: HumanFormat\niex> alias MyApp.DateTimeTokenizers.Humanized\niex> format = \"{shift} the {day} of {month}, {year}\"\niex> Timex.format(Timex.now, format, HumanFormat)\n{:ok, \"currently the eleventh of August, 2015\"}\n```","ref":"custom-formatters.html#implementing-the-humanized-formatter"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}